# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "ha8180"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||^^^    |||||||||20130715141912
    P|1
    O|1|123456||^^^A\\^^^B|R||||||||||||||00000000^00000000
    L|1"""
    assert message == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&|||HA-8180V^10900001^V01.00|||||||||20130911223344
            Q|1|SAMPLE1^0001^01||||||||||O
            L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&|||^^^    |||||||||20130715141912
    P|1
    O|1|SAMPLE1^0001^01|||R||||||||||NULL||||00000000^00000000
    L|1"""
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|$^&|||HA-8180V^11208020^V01.21    |||||||||201310211931
    Q|1|2494408562--------^0001^08||||||||||O
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "2494408562"}],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||HA-8180V^10900001^V01.00|||||||||20130911223344
    P|1
    O|1|0123456789012345--^0001^01||^^^HbA1c|C||||||||||H||||00000000^00000000^0^V^0A1101^^0C1112^2011-03^0D3331
    R|1|^^^ValueHbA1c|3.5|%||||F|||20130915120055
    R|2|^^^ValueIFCC|20|mmol/mol||||F
    R|3|^^^ValueHbF|0.5|%||||F
    R|4|^^^AreaTotal|38897|count||||F<
    R|5|^^^PeakHbA1ab|4^895^2.3|sec^count^%||||F
    R|6|^^^PeakHbA1ab|6^934^2.4|sec^count^%||||F
    R|7|^^^PeakHbF|8^194^0.5|sec^count^%||||F
    R|8|^^^PeakLA1c|13^467^1.2|sec^count^%||||F
    R|9|^^^PeakSA1c|19^1361^3.5|sec^count^%||||F
    R|10|^^^PeakA0|36^35046^90.1|sec^count^%||||F
    R|11|^^^PeakS|47^4844^16.5|sec^count^%||||F
    R|12|^^^PeakC|66^4513^15.1|sec^count^%||||F
    R|13|^^^TimeBottom|1^5^8^10^16^31^48|sec||||F
    R|14|^^^TimeBase|0^29|sec||||F
    R|15|^^^TimeSA1c|16^29|sec||||F
    R|16|^^^TimeHbF|9^11|sec||||F
    R|17|^^^TimeHbS|46^48|sec||||F
    R|18|^^^TimeHbC|65^67|sec||||F
    R|19|^^^TimeGain|32|sec||||F
    R|20|^^^ValueGain|10^350|mOD||||F
    L|1|N"""
    )
    date = datetime.datetime(2013, 9, 15, 12, 0, 55)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "0123456789012345",
                "control_lot": "0123456789012345",
                "rack": "0001-01",
                "results": [
                    {"code": "ValueHbA1c", "date": date, "value": "3.5"},
                    {"code": "ValueIFCC", "date": date, "value": "20"},
                    {"code": "ValueHbF", "date": date, "value": "0.5"},
                    {"code": "PeakHbA1ab_sec", "date": date, "value": "4"},
                    {"code": "PeakHbA1ab_count", "date": date, "value": "895"},
                    {"code": "PeakHbA1ab_%", "date": date, "value": "2.3"},
                    {"code": "PeakHbA1ab2_sec", "date": date, "value": "6"},
                    {"code": "PeakHbA1ab2_count", "date": date, "value": "934"},
                    {"code": "PeakHbA1ab2_%", "date": date, "value": "2.4"},
                    {"code": "PeakHbF_sec", "date": date, "value": "8"},
                    {"code": "PeakHbF_count", "date": date, "value": "194"},
                    {"code": "PeakHbF_%", "date": date, "value": "0.5"},
                    {"code": "PeakLA1c_sec", "date": date, "value": "13"},
                    {"code": "PeakLA1c_count", "date": date, "value": "467"},
                    {"code": "PeakLA1c_%", "date": date, "value": "1.2"},
                    {"code": "PeakSA1c_sec", "date": date, "value": "19"},
                    {"code": "PeakSA1c_count", "date": date, "value": "1361"},
                    {"code": "PeakSA1c_%", "date": date, "value": "3.5"},
                    {"code": "PeakA0_sec", "date": date, "value": "36"},
                    {"code": "PeakA0_count", "date": date, "value": "35046"},
                    {"code": "PeakA0_%", "date": date, "value": "90.1"},
                    {"code": "PeakS_sec", "date": date, "value": "47"},
                    {"code": "PeakS_count", "date": date, "value": "4844"},
                    {"code": "PeakS_%", "date": date, "value": "16.5"},
                    {"code": "PeakC_sec", "date": date, "value": "66"},
                    {"code": "PeakC_count", "date": date, "value": "4513"},
                    {"code": "PeakC_%", "date": date, "value": "15.1"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|$^&|||HA-8180V^11208020^V01.21    |||||||||201411141456
    P|1
    O|1|7718776862--------^0013^01|0155|^^^HbA1c|R||||||||||||||00000000^00000000^0^V^4E1101^2015-05^4E1111^2015-05^4C1401^2015-03^4E1121^2015-05^CA83D27^2015-02
    R|1|^^^ValueHbA1c|5.4|%||||F|||201411141455
    R|2|^^^ValueIFCC|35|mmol/mol||||F
    R|3|^^^ValueHbF|0.5|%||||F
    R|4|^^^AreaTotal|38085|count||||F
    R|5|^^^PeakHbA1ab|5^205^0.5|sec^count^%||||F
    R|6|^^^PeakHbA1ab|6^341^0.9|sec^count^%||||F
    R|7|^^^PeakHbF|9^171^0.5|sec^count^%||||F
    R|8|^^^PeakLA1c|12^626^1.7|sec^count^%||||F
    R|9|^^^PeakSA1c|18^2055^5.4|sec^count^%||||F
    R|10|^^^PeakA0|38^34687^91.1|sec^count^%||||F
    R|11|^^^TimeBottom|1^5^8^10^15^33^43|sec||||F
    R|12|^^^TimeBase|2^90|sec||||F
    R|13|^^^TimeSA1c|15^33|sec||||F
    R|14|^^^TimeHbF|8^10|sec||||F
    R|15|^^^TimeHbS||sec||||F
    R|16|^^^TimeHbC||sec||||F
    R|17|^^^TimeGain|33|sec||||F
    R|18|^^^ValueGain|23^412|mOD||||F
    R|19|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0003^0003^0004^0006^0008^000B|count||||F
    R|20|^^^ADCount2|000D^0010^0015^0018^001D^0020^0025^0028^002D^0030^0032^0035^0037^0037^0038^0038^0038^0037^0037^0037^0035^0037^0038^0038^003A^003A^003C^003D^003F^003F|count||||F
    R|21|^^^ADCount3|003F^003F^003C^0038^0035^0032^0030^002B^0027^0023^001E^001B^001A^0015^0011^0010^000D^000B^000D^0010^0013^0015^001A^001D^0022^0025^002A^002D^0032^0035|count||||F
    R|22|^^^ADCount4|0038^003C^003C^003D^003D^003D^003D^003D^003F^003F^003F^0041^0042^0045^0049^004C^004F^0052^0056^005B^005E^0061^0064^0066^0068^0069^006B^0069^0069^0066|count||||F
    R|23|^^^ADCount5|0064^005F^005E^0059^0056^0051^004E^0047^0044^003F^003C^0037^0034^002F^002D^0028^0027^0022^0020^001D^001B^0018^0016^0013^0013^0010^0010^000E^000D^000D|count||||F
    R|24|^^^ADCount6|000E^000E^0011^0011^0015^0016^001A^001B^0020^0023^0028^002B^0030^0034^003A^003F^0042^0049^004F^0056^0059^0061^0066^006B^0070^0076^0079^007E^0082^0085|count||||F
    R|25|^^^ADCount7|0086^008A^008B^008B^008A^0088^0085^0083^0080^007D^0078^0075^0071^006B^0068^0063^005E^005B^0056^0051^004C^0047^0042^003F^003C^0038^0035^0032^002F^002B|count||||F
    R|26|^^^ADCount8|0028^0027^0023^0022^001E^001D^001B^001A^001A^0018^0016^0016^0015^0013^0013^0011^0011^0010^0010^0010^000E^000E^000E^000D^000D^000D^000D^000D^000D^000B|count||||F
    R|27|^^^ADCount9|000B^000B^000B^000B^000B^000B^000B^0009^0009^0009^0009^0009^0009^0009^0008^0008^0008^0008^0008^0008^0008^0008^0006^0006^0006^0006^0006^0006^0006^0006|count||||F
    R|28|^^^ADCount0|0006^0006^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003|count||||F
    R|29|^^^ADCount1|0003^0003^0003^0003^0003^0003^0003^0003^0001^0001^0001^0001^0001^0001^0001^0001^0001^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|30|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0001^0001^0003^0003^0003^0003^0004^0004^0004^0006^0006^0008^0008^0009^000B^000D^000E^0010|count||||F
    R|31|^^^ADCount3|0011^0015^001A^0020^0028^0037^0049^0063^0080^00A4^00CC^00FA^0127^0155^017F^01A4^01C0^01D0^01D8^01D7^01CB^01B8^01A0^0182^0163^0145^0127^010C^00F5^00E0|count||||F
    R|32|^^^ADCount4|00D0^00C1^00B4^00AA^00A0^0098^0090^0088^0080^0078^0071^0069^0061^0059^0051^0049^0041^0038^0032^002B^0027^0020^001D^0018^0015^0011^0010^000E^000D^000B|count||||F
    R|33|^^^ADCount5|0009^0008^0008^0006^0006^0006^0004^0004^0004^0004^0003^0001^0001^0001^0001^0001^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|34|^^^ADCount6|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|35|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|36|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|37|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|38|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|39|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|40|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|41|^^^ADCount3|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|42|^^^ADCount4|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|43|^^^ADCount5|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|44|^^^ADCount6|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|45|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|46|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|47|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|48|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    L|1|N"""
    )
    lots = [
        {"type": "reagent", "lot": "ELUANT 80A: 4E1101 2015-05"},
        {"type": "reagent", "lot": "ELUANT 80B: 4E1111 2015-05"},
        {"type": "reagent", "lot": "ELUANT 80CV: 4C1401 2015-03"},
        {"type": "reagent", "lot": "SOLUTION HEMOLYSANTE 80H: 4E1121 2015-05"},
        {"type": "reagent", "lot": "CALIBRATOR KIT 80: CA83D27 2015-02"},
    ]
    points = [
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        1,
        1,
        3,
        3,
        4,
        6,
        8,
        11,
        13,
        16,
        21,
        24,
        29,
        32,
        37,
        40,
        45,
        48,
        50,
        53,
        55,
        55,
        56,
        56,
        56,
        55,
        55,
        55,
        53,
        55,
        56,
        56,
        58,
        58,
        60,
        61,
        63,
        63,
        63,
        63,
        60,
        56,
        53,
        50,
        48,
        43,
        39,
        35,
        30,
        27,
        26,
        21,
        17,
        16,
        13,
        11,
        13,
        16,
        19,
        21,
        26,
        29,
        34,
        37,
        42,
        45,
        50,
        53,
        56,
        60,
        60,
        61,
        61,
        61,
        61,
        61,
        63,
        63,
        63,
        65,
        66,
        69,
        73,
        76,
        79,
        82,
        86,
        91,
        94,
        97,
        100,
        102,
        104,
        105,
        107,
        105,
        105,
        102,
        100,
        95,
        94,
        89,
        86,
        81,
        78,
        71,
        68,
        63,
        60,
        55,
        52,
        47,
        45,
        40,
        39,
        34,
        32,
        29,
        27,
        24,
        22,
        19,
        19,
        16,
        16,
        14,
        13,
        13,
        14,
        14,
        17,
        17,
        21,
        22,
        26,
        27,
        32,
        35,
        40,
        43,
        48,
        52,
        58,
        63,
        66,
        73,
        79,
        86,
        89,
        97,
        102,
        107,
        112,
        118,
        121,
        126,
        130,
        133,
        134,
        138,
        139,
        139,
        138,
        136,
        133,
        131,
        128,
        125,
        120,
        117,
        113,
        107,
        104,
        99,
        94,
        91,
        86,
        81,
        76,
        71,
        66,
        63,
        60,
        56,
        53,
        50,
        47,
        43,
        40,
        39,
        35,
        34,
        30,
        29,
        27,
        26,
        26,
        24,
        22,
        22,
        21,
        19,
        19,
        17,
        17,
        16,
        16,
        16,
        14,
        14,
        14,
        13,
        13,
        13,
        13,
        13,
        13,
        11,
        11,
        11,
        11,
        11,
        11,
        11,
        11,
        9,
        9,
        9,
        9,
        9,
        9,
        9,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        1,
        1,
        1,
        1,
        3,
        3,
        3,
        3,
        4,
        4,
        4,
        6,
        6,
        8,
        8,
        9,
        11,
        13,
        14,
        16,
        17,
        21,
        26,
        32,
        40,
        55,
        73,
        99,
        128,
        164,
        204,
        250,
        295,
        341,
        383,
        420,
        448,
        464,
        472,
        471,
        459,
        440,
        416,
        386,
        355,
        325,
        295,
        268,
        245,
        224,
        208,
        193,
        180,
        170,
        160,
        152,
        144,
        136,
        128,
        120,
        113,
        105,
        97,
        89,
        81,
        73,
        65,
        56,
        50,
        43,
        39,
        32,
        29,
        24,
        21,
        17,
        16,
        14,
        13,
        11,
        9,
        8,
        8,
        6,
        6,
        6,
        4,
        4,
        4,
        4,
        3,
        1,
        1,
        1,
        1,
        1,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
    ]
    date = datetime.datetime(2014, 11, 14, 14, 55)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "7718776862",
                "rack": "0013-01",
                "results": [
                    {"date": date, "lots": lots, "code": "ValueHbA1c", "value": "5.4"},
                    {"date": date, "lots": lots, "code": "ValueIFCC", "value": "35"},
                    {"date": date, "lots": lots, "code": "ValueHbF", "value": "0.5"},
                    {"date": date, "lots": lots, "code": "AreaTotal", "value": "38085"},
                    {"code": "PeakHbA1ab_sec", "date": date, "value": "5"},
                    {"code": "PeakHbA1ab_count", "date": date, "value": "205"},
                    {"code": "PeakHbA1ab_%", "date": date, "value": "0.5"},
                    {"code": "PeakHbA1ab2_sec", "date": date, "value": "6"},
                    {"code": "PeakHbA1ab2_count", "date": date, "value": "341"},
                    {"code": "PeakHbA1ab2_%", "date": date, "value": "0.9"},
                    {"code": "PeakHbF_sec", "date": date, "value": "9"},
                    {"code": "PeakHbF_count", "date": date, "value": "171"},
                    {"code": "PeakHbF_%", "date": date, "value": "0.5"},
                    {"code": "PeakLA1c_sec", "date": date, "value": "12"},
                    {"code": "PeakLA1c_count", "date": date, "value": "626"},
                    {"code": "PeakLA1c_%", "date": date, "value": "1.7"},
                    {"code": "PeakSA1c_sec", "date": date, "value": "18"},
                    {"code": "PeakSA1c_count", "date": date, "value": "2055"},
                    {"code": "PeakSA1c_%", "date": date, "value": "5.4"},
                    {"code": "PeakA0_sec", "date": date, "value": "38"},
                    {"code": "PeakA0_count", "date": date, "value": "34687"},
                    {"code": "PeakA0_%", "date": date, "value": "91.1"},
                    {
                        "code": "ADCount",
                        "date": date,
                        "value": "GRAPHE",
                        "graph": {"graph_type": "area", "points": points},
                        "value": "GRAPHE",
                    },
                    {
                        "code": "GRAPHE_A1C",
                        "date": date,
                        "value": "GRAPHE",
                        "graph": {
                            "graph_type": "a1c",
                            "points": points,
                            "peaks": [
                                {
                                    "name": "HbA1ab",
                                    "area": 205.0,
                                    "area_percent": 0.5,
                                    "start": 0,
                                    "top": 54,
                                    "end": 54,
                                },
                                {
                                    "name": "HbA1ab",
                                    "area": 341.0,
                                    "area_percent": 0.9,
                                    "start": 54,
                                    "top": 58,
                                    "end": 77,
                                },
                                {
                                    "name": "HbF",
                                    "area": 171.0,
                                    "area_percent": 0.5,
                                    "start": 77,
                                    "top": 93,
                                    "end": 93,
                                },
                                {
                                    "name": "LA1c",
                                    "area": 626.0,
                                    "area_percent": 1.7,
                                    "start": 93,
                                    "top": 116,
                                    "end": 148,
                                },
                                {
                                    "name": "SA1c",
                                    "area": 2055.0,
                                    "area_percent": 5.4,
                                    "start": 148,
                                    "top": 182,
                                    "end": 317,
                                },
                                {
                                    "name": "A0",
                                    "area": 34687.0,
                                    "area_percent": 91.1,
                                    "start": 317,
                                    "top": 378,
                                    "end": 455,
                                },
                            ],
                        },
                    },
                    {"code": "SAMPLE_TYPE", "date": date, "value": "WB"},
                    {"code": "MEASUREMENT_NUMBER", "date": date, "value": "0155"},
                    {"code": "DEGRADATION_INFO", "date": date, "value": "0"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_measurement_error(self):
    worklist = self.decode(
        """
    H|$^&|||HA-8180V^11206016^V01.21    |||||||||201412161200
    P|1
    O|1|123456--------^0020^01|0096|^^^HbA1c|R||||||||||||||00000040^00000000^1^V^4F1101^2015-06^4F1111^2015-06^4C1401^2015-03^4F1121^2015-06^CA83D27^2015-02
    R|1|^^^ValueHbA1c|--.-|%||||F|||201412161159
    R|2|^^^ValueIFCC|---|mmol/mol||||F
    R|3|^^^ValueHbF|--.-|%||||F
    R|4|^^^AreaTotal|48246|count||||F
    R|5|^^^Peak|5^250^1.1|sec^count^%||||F
    R|6|^^^Peak|6^449^1.9|sec^count^%||||F
    R|7|^^^Peak|9^221^0.5|sec^count^%||||F
    R|8|^^^Peak|12^510^2.2|sec^count^%||||F
    R|9|^^^Peak|18^1434^6.2|sec^count^%||||F
    R|10|^^^Peak|25^308^0.6|sec^count^%||||F
    R|11|^^^Peak|38^20216^41.9|sec^count^%||||F
    R|12|^^^Peak|40^24858^51.5|sec^count^%||||F
    R|13|^^^TimeBottom||sec||ERR.||F
    R|14|^^^TimeBase||sec||ERR.||F
    R|15|^^^TimeSA1c|15^33|sec||||F
    R|16|^^^TimeHbF|8^10|sec||||F
    R|17|^^^TimeHbS||sec||||F
    R|18|^^^TimeHbC||sec||||F
    R|19|^^^TimeGain|33|sec||||F
    R|20|^^^ValueGain|18^680|mOD||||F
    R|21|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0001^0003^0004^0006^0008|count||||F
    R|22|^^^ADCount2|000B^000D^0011^0015^001A^001E^0025^002A^0030^0035^003C^0041^0044^0047^004A^004C^004E^004E^004E^004E^004E^004E^004E^004E^004F^0051^0052^0054^0056^0057|count||||F
    R|23|^^^ADCount3|0057^0057^0057^0057^0056^0054^0052^004F^004C^0049^0045^0044^0041^003F^003D^003C^003A^003A^003C^003C^003D^0041^0044^0047^004C^004F^0054^0057^005C^005F|count||||F
    R|24|^^^ADCount4|0063^0064^0066^0066^0066^0066^0064^0063^0061^005F^005F^005F^005F^005F^0061^0063^0066^0068^006B^006E^0071^0073^0076^0078^0078^0079^0078^0078^0076^0075|count||||F
    R|25|^^^ADCount5|0071^006E^006B^0068^0064^005F^005C^0059^0056^0052^004F^004C^004A^0047^0045^0044^0041^0041^003F^003D^003D^003C^003C^003C^003C^003D^003D^003D^003F^0041|count||||F
    R|26|^^^ADCount6|0041^0042^0044^0045^0047^004A^004C^004F^0051^0054^0057^005B^005F^0063^0068^006C^0070^0075^0079^007E^0083^0088^008D^0090^0093^0097^009A^009C^009F^009F|count||||F
    R|27|^^^ADCount7|00A0^009F^009C^009C^0097^0095^0090^008D^008A^0083^0080^007B^0075^0070^006B^0066^0061^005C^0057^0052^004E^0049^0045^0041^003D^003A^0037^0034^0030^002D|count||||F
    R|28|^^^ADCount8|002A^0028^0027^0025^0022^0020^0020^001E^001D^001D^001B^001B^001A^001A^0018^0018^0018^0016^0016^0016^0016^0016^0016^0015^0015^0015^0015^0015^0013^0013|count||||F
    R|29|^^^ADCount9|0013^0013^0013^0013^0013^0011^0011^0011^0011^0011^0011^0010^0010^0010^0010^000E^000E^000E^000E^000E^000D^000D^000D^000D^000D^000B^000B^000B^000B^000B|count||||F
    R|30|^^^ADCount0|000B^0009^0009^0009^0009^0009^0009^0009^0008^0008^0008^0008^0008^0008^0008^0008^0008^0008^0008^0008^0008^0008^0006^0006^0006^0006^0006^0006^0006^0006|count||||F
    R|31|^^^ADCount1|0006^0006^0006^0006^0006^0006^0006^0006^0006^0006^0004^0004^0004^0004^0004^0004^0004^0004^0003^0004^0003^0003^0003^0003^0003^0003^0003^0003^0001^0001|count||||F
    R|32|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0001^0003^0003^0004^0006^0008^0008^0009^000B^000D^000E^0010^0011^0011^0013^0013^0015^0015|count||||F
    R|33|^^^ADCount3|0015^0015^0015^0016^0016^0018^001B^0022^0028^0032^003F^004E^005E^0071^0085^009A^00AC^00BC^00CB^00D3^00D8^00D9^00D6^00D0^00C9^00C3^00BC^00B7^00B4^00B4|count||||F
    R|34|^^^ADCount4|00B7^00BE^00C4^00CC^00D3^00D8^00D9^00D9^00D6^00CE^00C6^00B9^00AC^009D^008F^0082^0075^0068^005C^0052^004A^0044^003D^0037^0032^002F^002A^0027^0023^0020|count||||F
    R|35|^^^ADCount5|001E^001B^001A^0016^0015^0013^0011^0010^000E^000D^000B^000B^0009^0008^0008^0006^0006^0006^0004^0004^0004^0003^0003^0003^0003^0003^0003^0003^0003^0001|count||||F
    R|36|^^^ADCount6|0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|37|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|38|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|39|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|40|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|41|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|42|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|43|^^^ADCount3|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|44|^^^ADCount4|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|45|^^^ADCount5|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|46|^^^ADCount6|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|47|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|48|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|49|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|50|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    L|1|N"""
    )
    points = [
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        1,
        1,
        1,
        3,
        4,
        6,
        8,
        11,
        13,
        17,
        21,
        26,
        30,
        37,
        42,
        48,
        53,
        60,
        65,
        68,
        71,
        74,
        76,
        78,
        78,
        78,
        78,
        78,
        78,
        78,
        78,
        79,
        81,
        82,
        84,
        86,
        87,
        87,
        87,
        87,
        87,
        86,
        84,
        82,
        79,
        76,
        73,
        69,
        68,
        65,
        63,
        61,
        60,
        58,
        58,
        60,
        60,
        61,
        65,
        68,
        71,
        76,
        79,
        84,
        87,
        92,
        95,
        99,
        100,
        102,
        102,
        102,
        102,
        100,
        99,
        97,
        95,
        95,
        95,
        95,
        95,
        97,
        99,
        102,
        104,
        107,
        110,
        113,
        115,
        118,
        120,
        120,
        121,
        120,
        120,
        118,
        117,
        113,
        110,
        107,
        104,
        100,
        95,
        92,
        89,
        86,
        82,
        79,
        76,
        74,
        71,
        69,
        68,
        65,
        65,
        63,
        61,
        61,
        60,
        60,
        60,
        60,
        61,
        61,
        61,
        63,
        65,
        65,
        66,
        68,
        69,
        71,
        74,
        76,
        79,
        81,
        84,
        87,
        91,
        95,
        99,
        104,
        108,
        112,
        117,
        121,
        126,
        131,
        136,
        141,
        144,
        147,
        151,
        154,
        156,
        159,
        159,
        160,
        159,
        156,
        156,
        151,
        149,
        144,
        141,
        138,
        131,
        128,
        123,
        117,
        112,
        107,
        102,
        97,
        92,
        87,
        82,
        78,
        73,
        69,
        65,
        61,
        58,
        55,
        52,
        48,
        45,
        42,
        40,
        39,
        37,
        34,
        32,
        32,
        30,
        29,
        29,
        27,
        27,
        26,
        26,
        24,
        24,
        24,
        22,
        22,
        22,
        22,
        22,
        22,
        21,
        21,
        21,
        21,
        21,
        19,
        19,
        19,
        19,
        19,
        19,
        19,
        17,
        17,
        17,
        17,
        17,
        17,
        16,
        16,
        16,
        16,
        14,
        14,
        14,
        14,
        14,
        13,
        13,
        13,
        13,
        13,
        11,
        11,
        11,
        11,
        11,
        11,
        9,
        9,
        9,
        9,
        9,
        9,
        9,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        8,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        6,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        4,
        3,
        4,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        1,
        1,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        1,
        1,
        1,
        3,
        3,
        4,
        6,
        8,
        8,
        9,
        11,
        13,
        14,
        16,
        17,
        17,
        19,
        19,
        21,
        21,
        21,
        21,
        21,
        22,
        22,
        24,
        27,
        34,
        40,
        50,
        63,
        78,
        94,
        113,
        133,
        154,
        172,
        188,
        203,
        211,
        216,
        217,
        214,
        208,
        201,
        195,
        188,
        183,
        180,
        180,
        183,
        190,
        196,
        204,
        211,
        216,
        217,
        217,
        214,
        206,
        198,
        185,
        172,
        157,
        143,
        130,
        117,
        104,
        92,
        82,
        74,
        68,
        61,
        55,
        50,
        47,
        42,
        39,
        35,
        32,
        30,
        27,
        26,
        22,
        21,
        19,
        17,
        16,
        14,
        13,
        11,
        11,
        9,
        8,
        8,
        6,
        6,
        6,
        4,
        4,
        4,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        3,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        1,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
    ]
    date = datetime.datetime(2014, 12, 16, 11, 59)
    lots = [
        {"type": "reagent", "lot": "ELUANT 80A: 4F1101 2015-06"},
        {"type": "reagent", "lot": "ELUANT 80B: 4F1111 2015-06"},
        {"type": "reagent", "lot": "ELUANT 80CV: 4C1401 2015-03"},
        {"type": "reagent", "lot": "SOLUTION HEMOLYSANTE 80H: 4F1121 2015-06"},
        {"type": "reagent", "lot": "CALIBRATOR KIT 80: CA83D27 2015-02"},
    ]
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "rack": "0020-01",
                "sample_id": "123456",
                "results": [
                    {"date": date, "lots": lots, "code": "ValueHbA1c", "value": "--.-"},
                    {"date": date, "lots": lots, "code": "ValueIFCC", "value": "---"},
                    {"date": date, "lots": lots, "code": "ValueHbF", "value": "--.-"},
                    {"date": date, "lots": lots, "code": "AreaTotal", "value": "48246"},
                    {"code": "Peak1_sec", "date": date, "value": "5"},
                    {"code": "Peak1_count", "date": date, "value": "250"},
                    {"code": "Peak1_%", "date": date, "value": "1.1"},
                    {"code": "Peak2_sec", "date": date, "value": "6"},
                    {"code": "Peak2_count", "date": date, "value": "449"},
                    {"code": "Peak2_%", "date": date, "value": "1.9"},
                    {"code": "Peak3_sec", "date": date, "value": "9"},
                    {"code": "Peak3_count", "date": date, "value": "221"},
                    {"code": "Peak3_%", "date": date, "value": "0.5"},
                    {"code": "Peak4_sec", "date": date, "value": "12"},
                    {"code": "Peak4_count", "date": date, "value": "510"},
                    {"code": "Peak4_%", "date": date, "value": "2.2"},
                    {"code": "Peak5_sec", "date": date, "value": "18"},
                    {"code": "Peak5_count", "date": date, "value": "1434"},
                    {"code": "Peak5_%", "date": date, "value": "6.2"},
                    {"code": "Peak6_sec", "date": date, "value": "25"},
                    {"code": "Peak6_count", "date": date, "value": "308"},
                    {"code": "Peak6_%", "date": date, "value": "0.6"},
                    {"code": "Peak7_sec", "date": date, "value": "38"},
                    {"code": "Peak7_count", "date": date, "value": "20216"},
                    {"code": "Peak7_%", "date": date, "value": "41.9"},
                    {"code": "Peak8_sec", "date": date, "value": "40"},
                    {"code": "Peak8_count", "date": date, "value": "24858"},
                    {"code": "Peak8_%", "date": date, "value": "51.5"},
                    {
                        "date": date,
                        "graph": {"graph_type": "area", "points": points},
                        "code": "ADCount",
                        "value": "GRAPHE",
                    },
                    {
                        "date": date,
                        "graph": {
                            "graph_type": "a1c",
                            "points": points,
                            "peaks": [
                                {
                                    "end": 54,
                                    "name": "",
                                    "area": 250.0,
                                    "top": 54,
                                    "area_percent": 1.1,
                                    "start": 0,
                                },
                                {
                                    "end": 76,
                                    "name": "",
                                    "area": 449.0,
                                    "top": 59,
                                    "area_percent": 1.9,
                                    "start": 54,
                                },
                                {
                                    "end": 99,
                                    "name": "",
                                    "area": 221.0,
                                    "top": 92,
                                    "area_percent": 0.5,
                                    "start": 76,
                                },
                                {
                                    "end": 141,
                                    "name": "",
                                    "area": 510.0,
                                    "top": 115,
                                    "area_percent": 2.2,
                                    "start": 99,
                                },
                                {
                                    "end": 238,
                                    "name": "",
                                    "area": 1434.0,
                                    "top": 180,
                                    "area_percent": 6.2,
                                    "start": 141,
                                },
                                {
                                    "end": 330,
                                    "name": "",
                                    "area": 308.0,
                                    "top": 245,
                                    "area_percent": 0.6,
                                    "start": 238,
                                },
                                {
                                    "end": 388,
                                    "name": "",
                                    "area": 20216.0,
                                    "top": 381,
                                    "area_percent": 41.9,
                                    "start": 330,
                                },
                                {
                                    "end": 480,
                                    "name": "",
                                    "area": 24858.0,
                                    "top": 396,
                                    "area_percent": 51.5,
                                    "start": 388,
                                },
                            ],
                        },
                        "code": "GRAPHE_A1C",
                        "value": "GRAPHE",
                    },
                    {"date": date, "code": "SAMPLE_TYPE", "value": "WB"},
                    {"date": date, "code": "MEASUREMENT_NUMBER", "value": "0096"},
                    {"date": date, "code": "DEGRADATION_INFO", "value": "1"},
                    {
                        "date": date,
                        "code": "HB_ERR",
                        "value": "Peak D",
                        "flags": ["Peak D"],
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_graphe_erreur(self):
    # Ne dois pas planter
    self.decode(
        """
    H|$^&|||HA-8180V^11208020^V01.33    |||||||||201504290905
    P|1
    O|1|1019104562--------^0016^01|0006|^^^HbA1c|R||||||||||||||00000000^00000000^0^V^4I1101^2015-09^4I1111^2015-09^4G1402^2015-07^4I1121^2015-09^CA83G30^2015-10
    R|1|^^^ValueHbA1c|5.6|%||||F|||201504290904
    R|2|^^^ValueIFCC|38|mmol/mol||||F
    R|3|^^^ValueHbF|0.1|%||||F
    R|4|^^^AreaTotal|50511|count||||F
    R|5|^^^PeakHbA1ab|4^246^0.5|sec^count^%||||F
    R|6|^^^PeakHbA1ab|6^486^1.0|sec^count^%||||F
    R|7|^^^PeakHbF|10^71^0.1|sec^count^%||||F
    R|8|^^^PeakLA1c|12^807^1.6|sec^count^%||||F
    R|9|^^^PeakSA1c|19^2832^5.7|sec^count^%||||F
    R|10|^^^PeakA0|38^45751^90.6|sec^count^%||||F
    R|11|^^^Peak|55^318^0.6|sec^count^%||||F
    R|12|^^^TimeBottom|1^5^8^10^16^33^47^64|sec||||F
    R|13|^^^TimeBase|2^84|sec||||F
    R|14|^^^TimeSA1c|16^33|sec||||F
    R|15|^^^TimeHbF|8^10|sec||||F
    R|16|^^^TimeHbS||sec||||F
    R|17|^^^TimeHbC||sec||||F
    R|18|^^^TimeGain|33|sec||||F
    R|19|^^^ValueGain|31^595|mOD||||F
    R|20|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0001^0003^0004^0006^0008|count||||F
    R|21|^^^ADCount2|000B^000E^0011^0015^0018^001D^0020^0023^0028^002A^002D^002F^0030^0030^0032^0030^0030^002F^002D^002D^002B^002D^002F^0030^0032^0034^0037^003A^003C^003D|count||||F
    R|22|^^^ADCount3|003F^003F^003F^003F^003C^003A^0037^0032^002F^002A^0027^0025^0020^001D^001B^0018^0016^0013^0011^0010^000E^000E^000D^000E^000E^0010^0010^0013^0013^0016|count||||F
    R|23|^^^ADCount4|0016^0018^001A^001A^001D^001D^0020^0020^0023^0023^0025^0027^0028^002B^002D^0030^0034^0038^003C^0041^0045^004A^004E^0052^0056^0059^005B^005C^005E^005E|count||||F
    R|24|^^^ADCount5|005E^005E^005B^0059^0056^0052^004F^004A^0047^0044^003F^003D^0038^0035^0032^002F^002B^0028^0025^0023^0020^001E^001B^0018^0018^0015^0013^0013^0010^0010|count||||F
    R|25|^^^ADCount6|000D^000D^000D^000B^000B^0009^000B^000D^000E^0010^0010^0015^0016^001A^001D^001E^0023^0027^002D^0032^0035^003C^0041^0049^004E^0054^005B^0061^0068^006C|count||||F
    R|26|^^^ADCount7|0073^0079^007E^0083^0086^008A^008F^0090^0092^0093^0093^0090^008D^008B^0088^0085^0082^007D^0078^0073^006E^0069^0064^005F^0059^0056^0051^004C^0047^0042|count||||F
    R|27|^^^ADCount8|003F^003A^0037^0032^002F^002D^002A^0028^0025^0022^0020^001E^001B^001A^0018^0018^0016^0015^0015^0013^0011^0011^0010^0010^000E^000E^000E^000D^000D^000D|count||||F
    R|28|^^^ADCount9|000D^000D^000B^000B^000B^000B^000B^000B^000B^0009^0009^0009^0009^0009^0009^0009^0009^0008^0008^0008^0008^0008^0008^0008^0008^0006^0006^0006^0006^0006|count||||F
    R|29|^^^ADCount0|0006^0006^0006^0006^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0004^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003^0003|count||||F
    R|30|^^^ADCount1|0003^0003^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|31|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0001^0001^0001^0003^0003^0003^0004^0004^0004^0006^0006^0006^0008^0008^0008^0009^0009^000B^000B^000D^000E^0010|count||||F
    R|32|^^^ADCount3|0011^0015^0018^001D^0023^002F^003D^0051^006B^008A^00AD^00D6^0102^012F^015B^0184^01A6^01C0^01D0^01D5^01D2^01C7^01B1^0199^017A^015B^013B^011A^00FD^00E1|count||||F
    R|33|^^^ADCount4|00C9^00B4^00A0^008F^007E^0071^0064^005B^0051^0047^0041^0038^0034^002D^0028^0023^0020^001D^001A^0016^0013^0011^000E^000D^000B^000B^0009^0008^0008^0006|count||||F
    R|34|^^^ADCount5|0006^0006^0004^0004^0004^0004^0003^0003^0003^0003^0003^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0001^0000^0000^0000^0000^0000^0000|count||||F
    R|35|^^^ADCount6|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|36|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|37|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|38|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|39|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|40|^^^ADCount1|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|41|^^^ADCount2|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|42|^^^ADCount3|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|43|^^^ADCount4|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|44|^^^ADCount5|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|45|^^^ADCount6|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|46|^^^ADCount7|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|47|^^^ADCount8|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|48|^^^ADCount9|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    R|49|^^^ADCount0|0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000^0000|count||||F
    L|1|N"""
    )
