# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "kx21"


def test_decode_result(self):
    worklist = self.decode(
        "D1U1511160-62120078126120024C100102002130032400425005060060700700801001100052000110012000070002200099000880000214000300"
    )
    date = datetime.datetime(2015, 11, 16)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "62120078126",
                "results": [
                    {"code": "WBC", "value": "100.1", "date": date},
                    {"code": "RBC", "value": "20.02", "flags": ["1"], "date": date},
                    {"code": "HGB", "value": "300.3", "flags": ["2"], "date": date},
                    {"code": "HCT", "value": "400.4", "flags": ["2"], "date": date},
                    {"code": "MCV", "value": "500.5", "date": date},
                    {"code": "MCH", "value": "600.6", "date": date},
                    {"code": "MCHC", "value": "700.7", "date": date},
                    {"code": "PLT", "value": "0801", "date": date},
                    {"code": "LYM%", "value": "011.0", "date": date},
                    {"code": "MXD%", "value": "052.0", "date": date},
                    {"code": "NEUT%", "value": "011.0", "date": date},
                    {"code": "LYM#", "value": "120.0", "date": date},
                    {"code": "MXD#", "value": "070.0", "date": date},
                    {"code": "NEUT#", "value": "220.0", "date": date},
                    {"code": "RDW", "value": "990.0", "date": date},
                    {"code": "PDW", "value": "880.0", "date": date},
                    {"code": "MPV", "value": "021.4", "date": date},
                    {"code": "P-LCR", "value": "003.0", "date": date},
                    {"code": "ALARME", "value": "WBC2;PLT4", "date": date},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        "D1CX151116123150C10012002300340045005600670070080100110005200101001200007000220009900088000021003"
    )
    date = datetime.datetime(2015, 11, 16, 12, 31)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "5",
                "sample_id": "5",
                "results": [
                    {"code": "WBC", "value": "100.1", "date": date},
                    {"code": "LYM%", "value": "200.2", "date": date},
                    {"code": "MXD%", "value": "300.3", "date": date},
                    {"code": "NEUT%", "value": "400.4", "date": date},
                    {"code": "LYM#", "value": "500.5", "date": date},
                    {"code": "MXD#", "value": "600.6", "date": date},
                    {"code": "NEUT#", "value": "700.7", "date": date},
                    {"code": "RBC", "value": "00.80", "date": date},
                    {"code": "HGB", "value": "100.1", "date": date},
                    {"code": "HCT", "value": "100.0", "date": date},
                    {"code": "MCV", "value": "520.0", "date": date},
                    {"code": "MCH", "value": "101.0", "date": date},
                    {"code": "MCHC", "value": "012.0", "date": date},
                    {"code": "RDW", "value": "000.7", "date": date},
                    {"code": "PLT", "value": "0002", "date": date},
                    {"code": "PDW", "value": "200.0", "date": date},
                    {"code": "MPV", "value": "990.0", "date": date},
                    {"code": "P-LCR", "value": "088.0", "date": date},
                    {"code": "W-SMV", "value": "000.2", "date": date},
                    {"code": "W-LMV", "value": "100.3", "date": date},
                ],
            }
        ],
    }
    assert worklist == expected
