# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "lotus_vircom"


def test_encode_order(self):
    self.configure(
        lotus_vircom_entete_order="LEGIO.PN.1 IgM|HSV-1 IgG|M.PNEUMONIAE IgM|PARAINFLUENZA3 IgG|R. CONORII IgM|HYDATIDOSIS IgG"
    )
    _order = """LEGIO.PN.1 IgM|HSV-1 IgG|M.PNEUMONIAE IgM|PARAINFLUENZA3 IgG|R. CONORII IgM|HYDATIDOSIS IgG

    123456|A|B
    """
    message = self.order()
    assert message == _order


def test_decode_result(self):
    worklist = self.decode(
        """LEGIO.PN.1 IgM|2014P000125|3,333|0,512|ng/ml|,||||N||S|"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "2014P000125",
                "type": "patient",
                "results": [
                    {
                        "code": "LEGIO.PN.1 IgM MEASUREMENT",
                        "flags": ["S"],
                        "value": "3.333",
                    },
                    {
                        "code": "LEGIO.PN.1 IgM NUMERICAL",
                        "flags": ["S"],
                        "value": "0.512",
                    },
                    {
                        "code": "LEGIO.PN.1 IgM INTERPRETATION",
                        "flags": ["S"],
                        "value": "N",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_extent_result(self):
    worklist = self.decode(
        """TETANUS IgG|2351514|0.00222409586|0.00968525652||.||7||Negative <0.1 UI/ml (EXTRAPOLATED)||N|0|0|cal1|cal0_1|0.0151238516|0.008718456|CAL1 > 10|CAL0_1 > 2 and CAL0_1 < 7|17C004102|2012/05|1.519|MANUAL ENTER OF SAMPLE ID
        PARVOVIRUS IgM|PEMCON2CAL2PARMPOS51||3.811||.||18||Positive||S|1|1|RLU_Cal|RLU_NC|6.479|1.565|(RLU_Cal>2) AND (RLU_Cal<7)|RLU_NC<2|19C076105|2020/11|24.69|Z-MAX IN SAMPLE"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "2351514",
                "type": "patient",
                "results": [
                    {
                        "code": "TETANUS IgG MEASUREMENT",
                        "flags": ["N"],
                        "value": "0.00222409586",
                        "comments": ["MANUAL ENTER OF SAMPLE ID"],
                    },
                    {
                        "code": "TETANUS IgG NUMERICAL",
                        "flags": ["N"],
                        "value": "0.00968525652",
                        "comments": ["MANUAL ENTER OF SAMPLE ID"],
                    },
                    {
                        "code": "TETANUS IgG INTERPRETATION",
                        "flags": ["N"],
                        "value": "Negative <0.1 UI/ml (EXTRAPOLATED)",
                        "comments": ["MANUAL ENTER OF SAMPLE ID"],
                    },
                ],
            },
            {
                "sample_id": "PEMCON2CAL2PARMPOS51",
                "type": "patient",
                "results": [
                    {
                        "code": "PARVOVIRUS IgM NUMERICAL",
                        "flags": ["S"],
                        "value": "3.811",
                        "comments": ["Z-MAX IN SAMPLE"],
                    },
                    {
                        "code": "PARVOVIRUS IgM INTERPRETATION",
                        "flags": ["S"],
                        "value": "Positive",
                        "comments": ["Z-MAX IN SAMPLE"],
                    },
                ],
            },
        ],
    }
    assert worklist == expected


def test_queries(self):
    result = self.decode("""123458|456789|98756\r\n""")
    expected = {
        "context": "query",
        "samples": [
            {"sample_id": "123458", "type": "patient"},
            {"sample_id": "456789", "type": "patient"},
            {"sample_id": "98756", "type": "patient"},
        ],
    }
    assert result == expected


def test_twelve_queries(self):
    result = self.decode(
        """123|456|789|0123|459|8555|14456|4455|9856|74142|12222|25436\r\n"""
    )
    expected = {
        "context": "query",
        "samples": [
            {"sample_id": "123", "type": "patient"},
            {"sample_id": "456", "type": "patient"},
            {"sample_id": "789", "type": "patient"},
            {"sample_id": "0123", "type": "patient"},
            {"sample_id": "459", "type": "patient"},
            {"sample_id": "8555", "type": "patient"},
            {"sample_id": "14456", "type": "patient"},
            {"sample_id": "4455", "type": "patient"},
            {"sample_id": "9856", "type": "patient"},
            {"sample_id": "74142", "type": "patient"},
            {"sample_id": "12222", "type": "patient"},
            {"sample_id": "25436", "type": "patient"},
        ],
    }
    assert result == expected
