# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "midisya"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|~^&||||||||||||20130715141912
    P|1|L036666666|||NYME^ANO|NJF|20110513|F|||||PRESCRIBER^Prescriber||||||||||20130511103030||LAB^^^^^LOC
    C|1|H||G
    O|1|123456|78910|A~B|S||20130603110342^20130513114242||||N||||Serum
    C|1|H|Sample commentaire|G
    R|1|A|42
    R|2|B|201302131516
    O|2|123456|78910|C|S||20130603110342^20130513114242||||C||||Serum
    C|1|H|Sample commentaire|G
    L|1|N
    """
    assert message == expected


def test_decode_result_maquette(self):
    worklist = self.decode(
        """
    H|~^&|||Midisya|||||ADLAB|||||
    P|1|00011303|||DUPONT^MARCEL||19700411|M|||||ABADI^Dr ABADIE Gérard^||||||||||||CL^|||||||||
    O|1|4062500270|1406250027|CBUN|R||20140625160300|||||||||||||||||||||||
    R|1|CBUN106^01|R|||||||DM^Denis MOREL||20140625155341|SM^Saisie Manuelle
    R|2|CBUN108^01|Q|||||||DM^Denis MOREL||20140625155419|SM^Saisie Manuelle
    R|3|CBUN108^02|CAU|||||||DM^Denis MOREL||20140625155419|SM^Saisie Manuelle
    R|4|CBUN118^01|10000|||||||DM^Denis MOREL||20140625155442|SM^Saisie Manuelle
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "CBUN106",
                        "comments": [],
                        "date": datetime.datetime(2014, 6, 25, 15, 53, 41),
                        "instrument": "SM",
                        "operator": "DM",
                        "value": "R",
                    },
                    {
                        "code": "CBUN108",
                        "comments": [],
                        "date": datetime.datetime(2014, 6, 25, 15, 54, 19),
                        "instrument": "SM",
                        "operator": "DM",
                        "value": "Q;CAU",
                    },
                    {
                        "code": "CBUN118",
                        "comments": [],
                        "date": datetime.datetime(2014, 6, 25, 15, 54, 42),
                        "instrument": "SM",
                        "operator": "DM",
                        "value": "10000",
                    },
                ],
                "sample_id": "4062500270",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_with_collection_assay(self):
    worklist = self.decode(
        """
    H|~^&|||Midisya|||||CLARILAB|||||
    P|1|20091500000016|||BACTÉRIO^All_info|NOM DE NAISSANCE|19710629|F|||||DINDMA^DINDINAUD||||||||||||-TEST|||||||||
    O|1|110000000110^1^esccol|1100000001|^^^AST-N372^RES_ISOLAT|R||20200915170646|||||||||||||||||ATB||||||
    C|1|I|ceci est un commetaire ATB|ATB
    C|2|I|et ici la ligne 2|ATB
    R|1|ID|^^^^esccol||||||||||^
    R|2|^^an|^R^^^^||||||||||^
    R|3|^^am|^I^^^^||||||||||^
    R|4|^^cpr|^S^^^^||||||||||^
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "110000000110",
                "results": [
                    {
                        "code": "RESU_ATB",
                        "comments": ["ceci est un commetaire ATB", "et ici la ligne 2"],
                        "date": datetime.datetime(2020, 9, 15, 17, 6, 46),
                        "nom_antibiogramme": "AST-N372",
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AN",
                                        "diametre": "",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_AM",
                                        "diametre": "",
                                        "mic": "",
                                        "sensitivity": "I",
                                    },
                                    {
                                        "antibiotic": "A_CPR",
                                        "diametre": "",
                                        "mic": "",
                                        "sensitivity": "S",
                                    },
                                ],
                                "sub_code": "1",
                                "value": "G_ESCCOL",
                            }
                        ],
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_atb_with_comment(self):
    worklist = self.decode(
        """
    H|~^&|||Midisya|||||ADLAB|||||
    P|1|00751016|||DUPONT^MICHELLE|MARTIN|19391203|F|||||BONDOC^BONDOCTEUR Jean Marie||||||||||||20-RDC||
    O|1|5110101162^3^SAUR|1511010116|CBU^^^PMT33^RES_ISOLAT|S||20151101115000|||||||||||||||||ATB||||||
    C|1|I|Beta-lactamines: Phenotype meticilline resistant.|ATB
    C|2|I|Resistance a toutes les Beta-lactamines.|ATB
    C|3|I|Aminosides : phenotype KT.|ATB
    C|4|I|MLS : phenotype sauvage|ATB
    C|5|I||ATB
    C|6|I|***** BMR Bacterie Multi-Resistante *****|ATB
    C|7|I|En etablissements de soins des mesures de type "Precautions|ATB
    C|8|I|complementaires "Contact" sont necessaires.|ATB
    C|9|I|Recommandations nationales SF2H 2009.|ATB
    R|1|ID|^^^^SAUR||||||||||
    R|2|^^P|^R^^8^^0.12-0.12||||||||||
    R|3|^^AM|^R^^^^-||||||||||
    R|4|^^AMX|^R^^^^2-8||||||||||
    R|5|^^PIP|^R^^^^4-16||||||||||
    R|6|^^ME|^R^^^^2-2||||||||||
    R|7|^^COX|^R^^^^2-2||||||||||
    R|8|^^OXH|^R^^>2^^2-2||||||||||
    R|9|^^DOX|^R^^^^2-2||||||||||
    R|10|^^CZ|^R^^^^1-2||||||||||
    R|11|^^CF|^R^^^^8-32||||||||||
    R|12|^^CTZ|^R^^^^2-8||||||||||
    R|13|^^CEC|^R^^^^2-8||||||||||
    R|14|^^E|^S^^<=0.500^^1-2||||||||||
    R|15|^^CTX|^R^^^^-||||||||||
    R|16|^^CRO|^R^^^^1-2||||||||||
    R|17|^^CFH|^R^^^^1-2||||||||||
    R|18|^^CXM|^R^^^^4-8||||||||||
    R|19|^^FOX|^R^^>4^^4-4||||||||||
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "5110101162",
                "results": [
                    {
                        "code": "CBU",
                        "comments": [
                            "Beta-lactamines: Phenotype meticilline resistant.",
                            "Resistance a toutes les Beta-lactamines.",
                            "Aminosides : phenotype KT.",
                            "MLS : phenotype sauvage",
                            "",
                            "***** BMR Bacterie Multi-Resistante *****",
                            'En etablissements de soins des mesures de type "Precautions',
                            'complementaires "Contact" sont necessaires.',
                            "Recommandations nationales SF2H 2009.",
                        ],
                        "date": datetime.datetime(2015, 11, 1, 11, 50),
                        "nom_antibiogramme": "PMT33",
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_P",
                                        "diametre": "0.12-0.12",
                                        "mic": "8",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_AM",
                                        "diametre": "-",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_AMX",
                                        "diametre": "2-8",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_PIP",
                                        "diametre": "4-16",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_ME",
                                        "diametre": "2-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_COX",
                                        "diametre": "2-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_OXH",
                                        "diametre": "2-2",
                                        "mic": ">2",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_DOX",
                                        "diametre": "2-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CZ",
                                        "diametre": "1-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CF",
                                        "diametre": "8-32",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CTZ",
                                        "diametre": "2-8",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CEC",
                                        "diametre": "2-8",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_E",
                                        "diametre": "1-2",
                                        "mic": "<=0.500",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CTX",
                                        "diametre": "-",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CRO",
                                        "diametre": "1-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CFH",
                                        "diametre": "1-2",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_CXM",
                                        "diametre": "4-8",
                                        "mic": "",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_FOX",
                                        "diametre": "4-4",
                                        "mic": ">4",
                                        "sensitivity": "R",
                                    },
                                ],
                                "sub_code": "3",
                                "value": "G_SAUR",
                            }
                        ],
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_atb(self):
    worklist = self.decode(
        """
    H|~^&|||mwBAC|||||ADLAB|||||
    P|1|00314306|||NGxxxxx^GIxxxxx|NGxxxxx|19430712|F|||||SAxxxxx^SAxxxxxxxxx Bernard||||||||||||70|||||||||
    O|1|0022472030^1^esccol|2002247203|CBU^^^AST-N372^RES_ISOLAT|R||20200224141321|||||||||||||||||ATB||||||
    R|1|ID|^^^^esccol||||||||||
    R|2|^^sxt|^S^^<=20^^||||||||||
    R|3|^^ftn|^S^^<=16^^||||||||||
    R|4|^^fos|^S^^<=16^^||||||||||
    R|5|^^ofx|^R^^>=8^^||||||||||
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "0022472030",
                "results": [
                    {
                        "code": "CBU",
                        "comments": [],
                        "date": datetime.datetime(2020, 2, 24, 14, 13, 21),
                        "nom_antibiogramme": "AST-N372",
                        "value": [
                            {
                                "sub_code": "1",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_SXT",
                                        "diametre": "",
                                        "mic": "<=20",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_FTN",
                                        "diametre": "",
                                        "mic": "<=16",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_FOS",
                                        "diametre": "",
                                        "mic": "<=16",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_OFX",
                                        "diametre": "",
                                        "mic": ">=8",
                                        "sensitivity": "R",
                                    },
                                ],
                                "value": "G_ESCCOL",
                            }
                        ],
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_cytologie(self):
    worklist = self.decode(
        """
    H|~^&|||mwBAC|||||ADLAB|||||
    P|1|00314306|||NGxxxxx^GIxxxxx|NGxxxxx|19430712|F|||||SAxxxxx^SAxxxxxxxxx Bernard||||||||||||70|||||||||
    O|1|0022472030|2002247203|CYTU|R||20200224141321|||||||||||||||||||||||
    R|1|CYST|ABS|||||||OCL^||2020022417526|IQ2^Iris IQ200
    R|2|NSE|ABS|||||||OCL^||20200224175152|IQ2^Iris IQ200
    R|3|HYAL|ABS|||||||OCL^||20200224175153|IQ2^Iris IQ200
    R|4|TYRO|ABS|||||||OCL^||2020022417527|IQ2^Iris IQ200
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "0022472030",
                "results": [
                    {
                        "code": "CYST",
                        "comments": [],
                        "date": None,
                        "instrument": "IQ2",
                        "operator": "OCL",
                        "value": "ABS",
                    },
                    {
                        "code": "NSE",
                        "comments": [],
                        "date": datetime.datetime(2020, 2, 24, 17, 51, 52),
                        "instrument": "IQ2",
                        "operator": "OCL",
                        "value": "ABS",
                    },
                    {
                        "code": "HYAL",
                        "comments": [],
                        "date": datetime.datetime(2020, 2, 24, 17, 51, 53),
                        "instrument": "IQ2",
                        "operator": "OCL",
                        "value": "ABS",
                    },
                    {
                        "code": "TYRO",
                        "comments": [],
                        "date": None,
                        "instrument": "IQ2",
                        "operator": "OCL",
                        "value": "ABS",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_resultat_multiple(self):
    worklist = self.decode(
        """
    H|~^&|||Midisya|||||CLARILAB|||||
    P|1|20091500000016|||BACTERIO^All_info|NOM DE NAISSANCE|19710629|F|||||DINDMA^DINDINAUD||||||||||||-TEST|||||||||
    O|1|110000000110|1100000001|CBU|R||20200915170646|||||||||||||||||||||||
    R|1|CBUCC76^01|AN|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|2|CBUCU03^01|103|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|3|CBUCU06^01|PDE|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|4|CBUCU11^01|ESCO|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|5|CBUCU11^02|103|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|6|CBUCU16^01|KLPN|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    R|7|CBUCU16^02|104|||||||HDAC^HDAC||20200915173722|SM^Saisie Manuelle
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "110000000110",
                "results": [
                    {
                        "code": "CBUCC76",
                        "comments": [],
                        "date": datetime.datetime(2020, 9, 15, 17, 37, 22),
                        "instrument": "SM",
                        "operator": "HDAC",
                        "value": "AN",
                    },
                    {
                        "code": "CBUCU03",
                        "comments": [],
                        "date": datetime.datetime(2020, 9, 15, 17, 37, 22),
                        "instrument": "SM",
                        "operator": "HDAC",
                        "value": "103",
                    },
                    {
                        "code": "CBUCU06",
                        "comments": [],
                        "date": datetime.datetime(2020, 9, 15, 17, 37, 22),
                        "instrument": "SM",
                        "operator": "HDAC",
                        "value": "PDE",
                    },
                    {
                        "code": "CBUCU11",
                        "comments": [],
                        "date": datetime.datetime(2020, 9, 15, 17, 37, 22),
                        "instrument": "SM",
                        "operator": "HDAC",
                        "value": "ESCO;103",
                    },
                    {
                        "code": "CBUCU16",
                        "comments": [],
                        "date": datetime.datetime(2020, 9, 15, 17, 37, 22),
                        "instrument": "SM",
                        "operator": "HDAC",
                        "value": "KLPN;104",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_resultat_multiple_avec_commentaire(self):
    date = datetime.datetime(2021, 9, 22, 12, 16, 33)
    worklist = self.decode(
        """
    H|~^&|||Midisya|||||CLARILAB|||||
    P|1|21092200000023|||TEST FINAL^Mat 2||20001004|M|||||TESTJP^TESTOU||||||||||||null|||||||||
    P|2|21092200000024|||TEST FINAL^Mat 3||20001005|M|||||TESTJP^TESTOU||||||||||||null|||||||||
    O|1|4000000635BP|4000000635|MAT|R||20210922120255||||||||||||||||||F|||||
    R|1|PUSCO10^01|CJ|||||||SED^DEGRANGE Sébastien^SED^DEGRANGE Sébastien||20210922121633|SM^Saisie Manuelle
    R|2|PUSCO12^01|X|||||||SED^DEGRANGE Sébastien^SED^DEGRANGE Sébastien||20210922121633|SM^Saisie Manuelle
    C|1|I|A controler sur un nouveau prelevement|info_commentaire
    R|31|TERMINE^01|TERMINE||||||||||SM^Saisie Manuelle
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "4000000635BP",
                "results": [
                    {
                        "code": "PUSCO10",
                        "comments": [],
                        "date": date,
                        "instrument": "SM",
                        "operator": "SED",
                        "value": "CJ",
                    },
                    {
                        "code": "PUSCO12",
                        "comments": ["A controler sur un nouveau prelevement"],
                        "date": date,
                        "instrument": "SM",
                        "operator": "SED",
                        "value": "X",
                    },
                    {
                        "code": "TERMINE",
                        "comments": [],
                        "date": None,
                        "instrument": "SM",
                        "operator": "",
                        "value": "TERMINE",
                    },
                ],
            }
        ],
    }
    assert worklist == expected
