# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "mylaxml_v2"


_result_message = """
        <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
        <aiMessage>
            <header>
                <senderName>myla-1.0.0.11</senderName>
                <processingIdentifier>P</processingIdentifier>
                <version>1394-97</version>
                <dateTime>20100128164942</dateTime>
                <instrumentName>V2S</instrumentName>
                <serialNumber>123456789000</serialNumber>
            </header>
            <requestResult>
                <patientInformation>
                    <patientIdentifier>G406270/A</patientIdentifier>
                    <patientVisitNumber>G406270-123</patientVisitNumber>
                    <lastName>Robinson, Adele</lastName>
                    <physicianIdentifier>Dr. Ro</physicianIdentifier>
                    <physicianName>Dr. Robert</physicianName>
                    <location>9EAST</location>
                    <locationText>9EAST</locationText>
                    <comment>
                        <source>P</source>
                        <code>Age=7</code>
                        <text>Age=7</text>
                        <type>G</type>
                    </comment>
                </patientInformation>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>520000636208</specimenIdentifier>
                        <collectedDateTime>20091204124514</collectedDateTime>
                        <specimenType>Wound</specimenType>
                        <specimenTypeText>Wound</specimenTypeText>
                        <specimenSource>Left A</specimenSource>
                        <specimenSourceText>Left Arm</specimenSourceText>
                        <comment>
                            <source>P</source>
                            <code>S-GN</code>
                            <text>S-GN</text>
                            <type>G</type>
                        </comment>
                    </specimen>
                    <isolateNumber>1</isolateNumber>
                    <test>
                        <universalIdentifier>
                            <testIdentifier>URET</testIdentifier>
                            <testName>AST-GP55</testName>
                        </universalIdentifier>
                        <instrumentName>V2S</instrumentName>
                        <instrumentType>V2S</instrumentType>
                        <result>
                            <value>
                                <identification>
                                    <identificationConfidenceCode>ei</identificationConfidenceCode>
                                    <identificationConfidence>Excellent identification</identificationConfidence>
                                    <bioNumber>0003053003500000</bioNumber>
                                    <probability>99.0</probability>
                                    <significantTaxon>
                                        <code>pseaer</code>
                                        <name>Pseudomonas aeruginosa</name>
                                    </significantTaxon>
                                </identification>
                                <ast>
                                    <userAstCommentList>
                                        <comment>test</comment>
                                        <comment>Commentaire libre</comment>
                                    </userAstCommentList>
                                    <antibiotic>
                                        <code>Bla</code>
                                        <name>Beta-Lactamase</name>
                                        <suppressedDrug>true</suppressedDrug>
                                        <deducedDrug>false</deducedDrug>
                                        <highMic>
                                            <micSign></micSign>
                                            <micValue>Pos</micValue>
                                            <suppressedMic>false</suppressedMic>
                                        </highMic>
                                        <category>+</category>
                                        <nonExpertCategory>+</nonExpertCategory>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>peng</code>
                                        <name>Benzylpenicillin</name>
                                        <suppressedDrug>false</suppressedDrug>
                                        <deducedDrug>false</deducedDrug>
                                        <highMic>
                                            <micSign>&gt;=</micSign>
                                            <micValue>0.5</micValue>
                                            <suppressedMic>false</suppressedMic>
                                        </highMic>
                                        <category>R</category>
                                        <diameter>6</diameter>
                                        <nonExpertCategory>R</nonExpertCategory>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>icr</code>
                                        <name>Inducible Clindamycin Resistance</name>
                                        <suppressedDrug>true</suppressedDrug>
                                        <highMic>
                                            <micValue>Neg</micValue>
                                        </highMic>
                                        <category>Neg</category>
                                        <nonExpertCategory>Neg</nonExpertCategory>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>mxf</code>
                                        <name>mxf</name>
                                        <suppressedDrug>false</suppressedDrug>
                                        <deducedDrug>false</deducedDrug>
                                        <highMic>
                                            <micSign>&gt;=</micSign>
                                            <micValue>(-)</micValue>
                                            <suppressedMic>false</suppressedMic>
                                        </highMic>
                                        <category>(-)</category>
                                        <nonExpertCategory>(-)</nonExpertCategory>
                                    </antibiotic>
                                </ast>
                                <expertFinding>
                                    <expertConfidence>Consistent</expertConfidence>
                                    <resistanceMechanism>
                                        <drugFamily>GLYCOPEPTIDES</drugFamily>
                                        <phenotype>RESISTANT (TEC)</phenotype>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>RIFAMYCINES</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>QUINOLONES</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>TETRACYCLINES</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>BETA-LACTAMS</drugFamily>
                                        <phenotype>MODIFICATION OF PBP (mecA)</phenotype>
                                        <phenotype>ACQUIRED PENICILLINASE</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>FURANES</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>AMINOGLYCOSIDES</drugFamily>
                                        <phenotype>RESISTANT KAN TOB (ANT(4))</phenotype>
                                        <phenotype>WILD</phenotype>
                                        <phenotype>RESISTANT KAN (APH(3)-III)</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>PHENICOLS</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                    <resistanceMechanism>
                                        <drugFamily>MACROLIDES/LINCOSAMIDES/STREPTOGRAMINS</drugFamily>
                                        <phenotype>WILD</phenotype>
                                    </resistanceMechanism>
                                </expertFinding>
                            </value>
                            <resultStatus>F</resultStatus>
                            <startDateTime>20091210172230</startDateTime>
                            <resultDateTime>20091210235230</resultDateTime>
                            <bmxResultData>
                                <disposable>
                                    <disposableIdentifier>1201850201206984</disposableIdentifier>
                                    <reference>AST-GP55</reference>
                                    <disposableType>VITEK2-AST-CARD</disposableType>
                                    <lotNumber>120185020</lotNumber>
                                    <expirationDate>20120107</expirationDate>
                                    <disposableStartDateTime>20091210172230</disposableStartDateTime>
                                    <disposableFinalDateTime>20091210235230</disposableFinalDateTime>
                                    <disposableSetupTechnologist>LabTech</disposableSetupTechnologist>
                                    <disposableSetupTechnologistText>LabTech</disposableSetupTechnologistText>
                                </disposable>
                            </bmxResultData>
                        </result>
                    </test>
                </testOrder>
            </requestResult>
        </aiMessage>"""


def test_encode_order_with_identification(self):
    worklist = copy.deepcopy(self.base_worklist)
    worklist.samples[0].orders = [{"code": "FLUI", "action": "new", "priority": "A"}]
    worklist.samples[0].results = [
        {
            "code": "A",
            "value": "",
            "resu_json": {
                "germes": [{"Id": "G_klpnsp", "rang": 1}, {"Id": "G_promir", "rang": 2}]
            },
        }
    ]
    message = self.order(worklist=worklist)
    expected = """
        <?xml version="1.0" encoding="UTF-8"?>
        <lisMessage>
            <header>
                <version>1394-97</version>
                <dateTime>20130715141912</dateTime>
            </header>
            <request>
                <patientInformation>
                    <patientIdentifier>036666666</patientIdentifier>
                    <patientVisitNumber>ADM_CLI</patientVisitNumber>
                    <firstName>ANO</firstName>
                    <lastName>NYME</lastName>
                    <birthdate>20110513</birthdate>
                    <sex>F</sex>
                    <physicianIdentifier>PRESCRIBER</physicianIdentifier>
                    <physicianName>Prescriber</physicianName>
                    <admissionDate>20130511</admissionDate>
                    <location>237</location>
                    <locationText>237</locationText>
                    <hospitalService>LOC</hospitalService>
                    <hospitalServiceText>LOCATION</hospitalServiceText>
                    <hospitalInstitution>LAB</hospitalInstitution>
                    <hospitalInstitutionText>LAB</hospitalInstitutionText>
                </patientInformation>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>FLUI</specimenType>
                        <specimenTypeText>FLUI</specimenTypeText>
                        <specimenNature>FLUI</specimenNature>
                        <specimenNatureText>FLUI</specimenNatureText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <isolateNumber>1</isolateNumber>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>ID</testGroupCode>
                        </universalIdentifier>
                        <result>
                            <value>
                                <identification>
                                    <significantTaxon>
                                        <code>klpnsp</code>
                                    </significantTaxon>
                                </identification>
                            </value>
                        </result>
                    </test>
                </testOrder>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>FLUI</specimenType>
                        <specimenTypeText>FLUI</specimenTypeText>
                        <specimenNature>FLUI</specimenNature>
                        <specimenNatureText>FLUI</specimenNatureText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <isolateNumber>2</isolateNumber>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>ID</testGroupCode>
                        </universalIdentifier>
                    <result>
                        <value>
                            <identification>
                                <significantTaxon>
                                    <code>promir</code>
                                </significantTaxon>
                            </identification>
                        </value>
                    </result>
                    </test>
                </testOrder>
            </request>
        </lisMessage>
        """

    assert message == expected


def test_encode_order_with_antibiogram(self):
    self.configure(myla_v2_send_atb_to_myla=True)
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0]["results"][0]["sub_code"] = "1"
    worklist.samples[0]["results"][0]["value"] = [
        {
            "value": "GERME",
            "antibiogram": [
                {
                    "antibiotic": "TIC",
                    "mic": "3",
                    "sensitivity": "R",
                    "diametre": "",
                    "cutoff": "",
                },
                {
                    "antibiotic": "A_MEC",
                    "mic": "<0.1",
                    "sensitivity": "R",
                    "diametre": "",
                    "cutoff": "",
                    "antibiotic_texte_code": ("A_MEC", "Mecillinam 10µg", "L"),
                },
                {
                    "antibiotic": "TUC",
                    "mic": ">=5",
                    "sensitivity": "R",
                    "diametre": "",
                    "cutoff": "",
                },
                {
                    "antibiotic": "TZP",
                    "mic": ">5",
                    "sensitivity": "S",
                    "diametre": "",
                    "cutoff": "",
                },
                {
                    "antibiotic": "IPM",
                    "mic": "<=0.5",
                    "sensitivity": "S",
                    "diametre": "",
                    "cutoff": "",
                },
                {
                    "antibiotic": "AN",
                    "mic": "",
                    "sensitivity": "S",
                    "diametre": "",
                    "cutoff": "",
                },
                {
                    "antibiotic": "CIP",
                    "mic": "<=1",
                    "sensitivity": "",
                    "diametre": "",
                    "cutoff": "",
                },
            ],
        }
    ]
    message = self.order(worklist=worklist)
    expected = """
        <?xml version="1.0" encoding="UTF-8"?>
            <lisMessage>
                <header>
                    <version>1394-97</version>
                    <dateTime>20130715141912</dateTime>
                </header>
                <request>
                    <patientInformation>
                        <patientIdentifier>036666666</patientIdentifier>
                        <patientVisitNumber>ADM_CLI</patientVisitNumber>
                        <firstName>ANO</firstName>
                        <lastName>NYME</lastName>
                        <birthdate>20110513</birthdate>
                        <sex>F</sex>
                        <physicianIdentifier>PRESCRIBER</physicianIdentifier>
                        <physicianName>Prescriber</physicianName>
                        <admissionDate>20130511</admissionDate>
                        <location>237</location>
                        <locationText>237</locationText>
                        <hospitalService>LOC</hospitalService>
                        <hospitalServiceText>LOCATION</hospitalServiceText>
                        <hospitalInstitution>LAB</hospitalInstitution>
                        <hospitalInstitutionText>LAB</hospitalInstitutionText>
                    </patientInformation>
                    <testOrder>
                        <specimen>
                            <specimenIdentifier>123456</specimenIdentifier>
                            <specimenType>A</specimenType>
                            <specimenTypeText>A</specimenTypeText>
                            <specimenNature>A</specimenNature>
                            <specimenNatureText>A</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                            <specimenType>B</specimenType>
                            <specimenTypeText>B</specimenTypeText>
                            <specimenNature>B</specimenNature>
                            <specimenNatureText>B</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                        </specimen>
                        <isolateNumber/>
                        <test>
                            <universalIdentifier>
                                <testGroupCode>ID</testGroupCode>
                            </universalIdentifier>
                            <result>
                                <value>
                                    <identification>
                                        <significantTaxon>
                                            <code>GERME</code>
                                            <name/>
                                        </significantTaxon>
                                    </identification>
                                    <ast>
                                      <antibiotic>
                                        <code>TIC</code>
                                        <name/>
                                        <highMic/>
                                        <category>R</category>
                                        <nonExpertCategory>R</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>MEC</code>
                                        <name>Mecillinam 10µg</name>
                                        <highMic>
                                          <micSign>&lt;</micSign>
                                          <micValue>0.1</micValue>
                                        </highMic>
                                        <category>R</category>
                                        <nonExpertCategory>R</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>TUC</code>
                                        <name/>
                                        <highMic>
                                          <micSign>&gt;=</micSign>
                                        </highMic>
                                        <category>R</category>
                                        <nonExpertCategory>R</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>TZP</code>
                                        <name/>
                                        <highMic>
                                          <micSign>&gt;</micSign>
                                          <micValue>5</micValue>
                                        </highMic>
                                        <category>S</category>
                                        <nonExpertCategory>S</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>IPM</code>
                                        <name/>
                                        <highMic>
                                          <micSign>&lt;=</micSign>
                                        </highMic>
                                        <category>S</category>
                                        <nonExpertCategory>S</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>AN</code>
                                        <name/>
                                        <highMic/>
                                        <category>S</category>
                                        <nonExpertCategory>S</nonExpertCategory>
                                      </antibiotic>
                                      <antibiotic>
                                        <code>CIP</code>
                                        <name/>
                                        <highMic>
                                          <micSign>&lt;=</micSign>
                                        </highMic>
                                        <category/>
                                        <nonExpertCategory/>
                                      </antibiotic>
                                    </ast>
                                  </value>
                            </result>
                        </test>
                    </testOrder>
                </request>
            </lisMessage>
            """
    assert message == expected


def test_encode_order_with_su_bloodculture(self):
    worklist = copy.deepcopy(self.base_worklist)
    worklist.samples[0].orders = [
        {"code": "BFA", "action": "new", "priority": "A"},
        {"code": "BFN", "action": "new", "priority": "A"},
    ]
    worklist.samples[0].results = [
        {"code": "SPECIMENNATURE_A", "value": "NATURE"},
        {"code": "SPECIMENSOURCE_A", "value": "SOURCE"},
    ]
    worklist.samples[0]["specimen"] = "SU"
    message = self.order(worklist=worklist)
    expected = """
      <?xml version="1.0" encoding="UTF-8"?>
        <lisMessage>
            <header>
                <version>1394-97</version>
                <dateTime>20130715141912</dateTime>
            </header>
            <request>
                <patientInformation>
                    <patientIdentifier>036666666</patientIdentifier>
                    <patientVisitNumber>ADM_CLI</patientVisitNumber>
                    <firstName>ANO</firstName>
                    <lastName>NYME</lastName>
                    <birthdate>20110513</birthdate>
                    <sex>F</sex>
                    <physicianIdentifier>PRESCRIBER</physicianIdentifier>
                    <physicianName>Prescriber</physicianName>
                    <admissionDate>20130511</admissionDate>
                    <location>237</location>
                    <locationText>237</locationText>
                    <hospitalService>LOC</hospitalService>
                    <hospitalServiceText>LOCATION</hospitalServiceText>
                    <hospitalInstitution>LAB</hospitalInstitution>
                    <hospitalInstitutionText>LAB</hospitalInstitutionText>
                </patientInformation>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>BFA</specimenType>
                        <specimenTypeText>BFA</specimenTypeText>
                        <specimenNature>NATURE</specimenNature>
                        <specimenNatureText>NATURE</specimenNatureText>
                        <specimenSource>SOURCE</specimenSource>
                        <specimenSourceText>SOURCE</specimenSourceText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>SU</testGroupCode>
                        </universalIdentifier>
                    </test>
                </testOrder>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>BFN</specimenType>
                        <specimenTypeText>BFN</specimenTypeText>
                        <specimenNature>NATURE</specimenNature>
                        <specimenNatureText>NATURE</specimenNatureText>
                        <specimenSource>SOURCE</specimenSource>
                        <specimenSourceText>SOURCE</specimenSourceText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>SU</testGroupCode>
                        </universalIdentifier>
                    </test>
                </testOrder>
            </request>
        </lisMessage>
          """
    assert message == expected


def test_encode_order_with_bc_bloodculture(self):
    self.configure(myla_v2_hemoc_delai_incubation="15")
    worklist = copy.deepcopy(self.base_worklist)
    worklist.samples[0].orders = [
        {"code": "BFA", "action": "new", "priority": "A"},
        {"code": "BFN", "action": "new", "priority": "A"},
    ]
    worklist.samples[0].results = [
        {"code": "SPECIMENNATURE_A", "value": "NATURE"},
        {"code": "SPECIMENSOURCE_A", "value": "SOURCE"},
    ]
    worklist.samples[0]["specimen"] = "BC"
    message = self.order(worklist=worklist)
    expected = """
      <?xml version="1.0" encoding="UTF-8"?>
        <lisMessage>
            <header>
                <version>1394-97</version>
                <dateTime>20130715141912</dateTime>
            </header>
            <request>
                <patientInformation>
                    <patientIdentifier>036666666</patientIdentifier>
                    <patientVisitNumber>ADM_CLI</patientVisitNumber>
                    <firstName>ANO</firstName>
                    <lastName>NYME</lastName>
                    <birthdate>20110513</birthdate>
                    <sex>F</sex>
                    <physicianIdentifier>PRESCRIBER</physicianIdentifier>
                    <physicianName>Prescriber</physicianName>
                    <admissionDate>20130511</admissionDate>
                    <location>237</location>
                    <locationText>237</locationText>
                    <hospitalService>LOC</hospitalService>
                    <hospitalServiceText>LOCATION</hospitalServiceText>
                    <hospitalInstitution>LAB</hospitalInstitution>
                    <hospitalInstitutionText>LAB</hospitalInstitutionText>
                </patientInformation>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>BFA</specimenType>
                        <specimenTypeText>BFA</specimenTypeText>
                        <specimenNature>NATURE</specimenNature>
                        <specimenNatureText>NATURE</specimenNatureText>
                        <specimenSource>SOURCE</specimenSource>
                        <specimenSourceText>SOURCE</specimenSourceText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>BC</testGroupCode>
                        </universalIdentifier>
                        <expectedDuration>15</expectedDuration>
                    </test>
                </testOrder>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>123456</specimenIdentifier>
                        <specimenType>BFN</specimenType>
                        <specimenTypeText>BFN</specimenTypeText>
                        <specimenNature>NATURE</specimenNature>
                        <specimenNatureText>NATURE</specimenNatureText>
                        <specimenSource>SOURCE</specimenSource>
                        <specimenSourceText>SOURCE</specimenSourceText>
                        <collectedDateTime>20130513114242</collectedDateTime>
                    </specimen>
                    <test>
                        <universalIdentifier>
                            <testGroupCode>BC</testGroupCode>
                        </universalIdentifier>
                        <expectedDuration>15</expectedDuration>
                    </test>
                </testOrder>
            </request>
        </lisMessage>
          """
    assert message == expected


def test_encode_order_location_service(self):
    self.configure(myla_v2_send_service_xml_location=True)
    message = self.order()
    expected = """
        <?xml version="1.0" encoding="UTF-8"?>
            <lisMessage>
                <header>
                    <version>1394-97</version>
                    <dateTime>20130715141912</dateTime>
                </header>
                <request>
                    <patientInformation>
                        <patientIdentifier>036666666</patientIdentifier>
                        <patientVisitNumber>ADM_CLI</patientVisitNumber>
                        <firstName>ANO</firstName>
                        <lastName>NYME</lastName>
                        <birthdate>20110513</birthdate>
                        <sex>F</sex>
                        <physicianIdentifier>PRESCRIBER</physicianIdentifier>
                        <physicianName>Prescriber</physicianName>
                        <admissionDate>20130511</admissionDate>
                        <location>LOC</location>
                        <locationText>LOC</locationText>
                        <hospitalService>LOC</hospitalService>
                        <hospitalServiceText>LOCATION</hospitalServiceText>
                        <hospitalInstitution>LAB</hospitalInstitution>
                        <hospitalInstitutionText>LAB</hospitalInstitutionText>
                    </patientInformation>
                    <testOrder>
                        <specimen>
                            <specimenIdentifier>123456</specimenIdentifier>
                            <specimenType>A</specimenType>
                            <specimenTypeText>A</specimenTypeText>
                            <specimenNature>A</specimenNature>
                            <specimenNatureText>A</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                            <specimenType>B</specimenType>
                            <specimenTypeText>B</specimenTypeText>
                            <specimenNature>B</specimenNature>
                            <specimenNatureText>B</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                        </specimen>
                        <isolateNumber>1</isolateNumber>
                        <test>
                            <universalIdentifier>
                                <testGroupCode>ID</testGroupCode>
                            </universalIdentifier>
                            <result>
                                <value>
                                    <identification>
                                        <significantTaxon>
                                            <code>1</code>
                                        </significantTaxon>
                                    </identification>
                                </value>
                            </result>
                        </test>
                    </testOrder>
                    <testOrder>
                        <specimen>
                            <specimenIdentifier>123456</specimenIdentifier>
                            <specimenType>A</specimenType>
                            <specimenTypeText>A</specimenTypeText>
                            <specimenNature>A</specimenNature>
                            <specimenNatureText>A</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                            <specimenType>B</specimenType>
                            <specimenTypeText>B</specimenTypeText>
                            <specimenNature>B</specimenNature>
                            <specimenNatureText>B</specimenNatureText>
                            <collectedDateTime>20130513114242</collectedDateTime>
                        </specimen>
                        <isolateNumber>2</isolateNumber>
                        <test>
                            <universalIdentifier>
                                <testGroupCode>ID</testGroupCode>
                            </universalIdentifier>
                            <result>
                                <value>
                                    <identification>
                                        <significantTaxon>
                                            <code>2</code>
                                        </significantTaxon>
                                    </identification>
                                </value>
                            </result>
                        </test>
                    </testOrder>
                </request>
            </lisMessage>
            """
    assert message == expected


def test_decode_result(self):
    self.configure(
        myla_v2_atb_commentaire_automatique=True,
        myla_v2_ignore_suppressed_drug=True,
        myla_v2_diameter=True,
    )
    date = datetime.datetime(2009, 12, 10, 23, 52, 30)
    worklist = self.decode(_result_message)
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "ATB_BIOART", "value": ["test", "Commentaire libre"]},
                    {"code": "lotNumber", "value": "120185020"},
                    {
                        "code": "Wound",
                        "comments": ["test", "Commentaire libre"],
                        "date": date,
                        "instrument": "123456789000",
                        "nom_antibiogramme": "URET",
                        "phenotypes": [
                            "GLYCOPEPTIDES-RESISTANT (TEC)",
                            "GLYCOPEPTIDES-WILD",
                            "RIFAMYCINES-WILD",
                            "QUINOLONES-WILD",
                            "TETRACYCLINES-WILD",
                            "BETA-LACTAMS-MODIFICATION OF PBP " "(mecA)",
                            "BETA-LACTAMS-ACQUIRED PENICILLINASE",
                            "FURANES-WILD",
                            "AMINOGLYCOSIDES-RESISTANT KAN TOB " "(ANT(4))",
                            "AMINOGLYCOSIDES-WILD",
                            "AMINOGLYCOSIDES-RESISTANT KAN " "(APH(3)-III)",
                            "PHENICOLS-WILD",
                            "MACROLIDES/LINCOSAMIDES/STREPTOGRAMINS-WILD",
                        ],
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_PENG",
                                        "diametre": "6",
                                        "mic": ">=0.5",
                                        "sensitivity": "R",
                                    }
                                ],
                                "sub_code": "1",
                                "value": "G_PSEAER",
                            }
                        ],
                    },
                ],
                "sample_id": "520000636208",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_with_instrument_name(self):
    self.configure(
        myla_v2_atb_commentaire_automatique=True,
        myla_v2_ignore_suppressed_drug=True,
        myla_v2_diameter=True,
        myla_v2_instrument_name=True,
    )
    date = datetime.datetime(2009, 12, 10, 23, 52, 30)
    worklist = self.decode(_result_message)
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "ATB_BIOART", "value": ["test", "Commentaire libre"]},
                    {"code": "lotNumber", "value": "120185020"},
                    {
                        "code": "Wound",
                        "comments": ["test", "Commentaire libre"],
                        "date": date,
                        "instrument": "V2S",
                        "nom_antibiogramme": "URET",
                        "phenotypes": [
                            "GLYCOPEPTIDES-RESISTANT (TEC)",
                            "GLYCOPEPTIDES-WILD",
                            "RIFAMYCINES-WILD",
                            "QUINOLONES-WILD",
                            "TETRACYCLINES-WILD",
                            "BETA-LACTAMS-MODIFICATION OF PBP " "(mecA)",
                            "BETA-LACTAMS-ACQUIRED PENICILLINASE",
                            "FURANES-WILD",
                            "AMINOGLYCOSIDES-RESISTANT KAN TOB " "(ANT(4))",
                            "AMINOGLYCOSIDES-WILD",
                            "AMINOGLYCOSIDES-RESISTANT KAN " "(APH(3)-III)",
                            "PHENICOLS-WILD",
                            "MACROLIDES/LINCOSAMIDES/STREPTOGRAMINS-WILD",
                        ],
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_PENG",
                                        "diametre": "6",
                                        "mic": ">=0.5",
                                        "sensitivity": "R",
                                    }
                                ],
                                "sub_code": "1",
                                "value": "G_PSEAER",
                            }
                        ],
                    },
                ],
                "sample_id": "520000636208",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_identification(self):
    date = datetime.datetime(2014, 9, 17, 9, 36, 25)
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
          <header>
            <version>1394-97</version>
            <dateTime>20161214090017</dateTime>
            <serialNumber>000009C01C1F</serialNumber>
          </header>
          <requestResult>
            <testOrder>
              <specimen>
                <specimenIdentifier>140010953665</specimenIdentifier>
                <collectedDateTime>20140916081400</collectedDateTime>
                <receivedDateTime>20140916081508</receivedDateTime>
                <specimenType>URINE</specimenType>
                <specimenNature>URINE</specimenNature>
                <specimenNatureText>URINE</specimenNatureText>
              </specimen>
              <isolateNumber>1</isolateNumber>
              <test>
                <universalIdentifier>
                  <testGroupCode>ID</testGroupCode>
                  <testIdentifier>MALDI-TOF</testIdentifier>
                  <testName>test MALDI-TOF</testName>
                </universalIdentifier>
                <positionOnDisposable>C1</positionOnDisposable>
                <instrumentName>VITEKMSACQ01</instrumentName>
                <instrumentType>MSID</instrumentType>
                <instrumentSerialNumber>50526</instrumentSerialNumber>
                <result>
                  <value>
                    <identification>
                      <identificationConfidenceCode>ID_GOOD</identificationConfidenceCode>
                      <identificationConfidence>Bonne identification</identificationConfidence>
                      <probability>99.9</probability>
                      <significantTaxon>
                        <code>staaur</code>
                        <name>Staphylococcus Aureus</name>
                      </significantTaxon>
                    </identification>
                  </value>
                  <resultStatus>F</resultStatus>
                  <resultDateTime>20140917093625</resultDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>604</disposableIdentifier>
                      <reference>DS140140797</reference>
                      <disposableType>AXIMA_SLIDE_REF</disposableType>
                      <disposableSetupTechnologist>aj</disposableSetupTechnologist>
                    </disposable>
                    <disposable>
                      <disposableIdentifier>1_10033319560</disposableIdentifier>
                      <reference>VITEK MS-CHCA</reference>
                      <disposableType>MATRIX</disposableType>
                      <lotNumber>10033319560</lotNumber>
                      <disposableFinalDateTime>20140917091425</disposableFinalDateTime>
                      <disposableSetupTechnologist>aj</disposableSetupTechnologist>
                    </disposable>
                    <extraResultData>694</extraResultData>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
            <testOrder>
              <specimen>
                <specimenIdentifier>140010953665</specimenIdentifier>
                <collectedDateTime>20140916081400</collectedDateTime>
                <receivedDateTime>20140916081508</receivedDateTime>
                <specimenType>URINE</specimenType>
                <specimenNature>URINE</specimenNature>
                <specimenNatureText>URINE</specimenNatureText>
              </specimen>
              <isolateNumber>2</isolateNumber>
              <test>
                <universalIdentifier>
                  <testGroupCode>ID</testGroupCode>
                  <testIdentifier>MALDI-TOF</testIdentifier>
                  <testName>test MALDI-TOF</testName>
                </universalIdentifier>
                <positionOnDisposable>C1</positionOnDisposable>
                <instrumentName>VITEKMSACQ01</instrumentName>
                <instrumentType>MSID</instrumentType>
                <instrumentSerialNumber>50526</instrumentSerialNumber>
                <result>
                  <value>
                    <identification>
                      <identificationConfidenceCode>ID_GOOD</identificationConfidenceCode>
                      <identificationConfidence>Bonne identification</identificationConfidence>
                      <probability>99.9</probability>
                      <significantTaxon>
                        <code>stasap</code>
                        <name>Staphylococcus saprophyticus</name>
                      </significantTaxon>
                    </identification>
                  </value>
                  <resultStatus>F</resultStatus>
                  <resultDateTime>20140917093625</resultDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>604</disposableIdentifier>
                      <reference>DS140140797</reference>
                      <disposableType>AXIMA_SLIDE_REF</disposableType>
                      <disposableSetupTechnologist>aj</disposableSetupTechnologist>
                    </disposable>
                    <disposable>
                      <disposableIdentifier>1_10033319560</disposableIdentifier>
                      <reference>VITEK MS-CHCA</reference>
                      <disposableType>MATRIX</disposableType>
                      <lotNumber>10033319560</lotNumber>
                      <disposableFinalDateTime>20140917091425</disposableFinalDateTime>
                      <disposableSetupTechnologist>aj</disposableSetupTechnologist>
                    </disposable>
                    <extraResultData>694</extraResultData>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
          </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "GERME_1_URINE",
                        "instrument": "000009C01C1F",
                        "value": "G_STAAUR",
                    },
                    {
                        "code": "IDENT_URINE",
                        "comments": [],
                        "date": date,
                        "instrument": "000009C01C1F",
                        "nom_antibiogramme": "MALDI-TOF",
                        "phenotypes": [],
                        "value": {
                            "germes": [
                                {"id": "G_STAAUR", "rang": 1},
                                {"id": "G_STASAP", "rang": 2},
                            ],
                            "seq": "0",
                            "type_resultat": "identification_germes",
                        },
                    },
                    {
                        "code": "GERME_2_URINE",
                        "instrument": "000009C01C1F",
                        "value": "G_STASAP",
                    },
                ],
                "sample_id": "140010953665",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_bloodculture(self):
    date = datetime.datetime(2015, 1, 7, 12, 10, 27)
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
          <header>
            <version>1394-97</version>
            <dateTime>20150107121220</dateTime>
            <instrumentName>BTA-1 le mans</instrumentName>
            <serialNumber>COM10_1</serialNumber>
          </header>
          <requestResult>
            <patientInformation>
              <patientIdentifier>0101600039794</patientIdentifier>
              <lastName>Z_LABO_DAMIEN</lastName>
              <birthdate>19810908</birthdate>
              <sex>M</sex>
              <address2>20000101</address2>
              <physicianIdentifier>ZZ</physicianIdentifier>
              <physicianName>SANS PRESCRIPTION MEDICALE</physicianName>
              <admissionDate>20000101</admissionDate>
              <dischargeDate>20150122</dischargeDate>
              <location>ZZZ</location>
            </patientInformation>
            <testOrder>
              <specimen>
                <specimenIdentifier>35180010201</specimenIdentifier>
                <collectedDateTime>20150107094100</collectedDateTime>
                <receivedDateTime>20150107112723</receivedDateTime>
                <specimenType>HEMOBA</specimenType>
                <specimenNature>HEMOBA</specimenNature>
                <specimenNatureText>HEMOBA</specimenNatureText>
              </specimen>
              <test>
                <universalIdentifier>
                  <testGroupCode>BC</testGroupCode>
                </universalIdentifier>
                <instrumentSectionId>3C60</instrumentSectionId>
                <instrumentName>BTA-1 le mans</instrumentName>
                <instrumentType>bta</instrumentType>
                <instrumentSerialNumber>COM10_1</instrumentSerialNumber>
                <result>
                  <value>
                    <bloodCulture>
                      <dateResultDetermined>20150107121027</dateResultDetermined>
                      <timeToDetectionInHours>0.1</timeToDetectionInHours>
                      <result>Pos</result>
                    </bloodCulture>
                  </value>
                  <abnormalFlags>8</abnormalFlags>
                  <resultStatus>F</resultStatus>
                  <startDateTime>20150107120726</startDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>ARGPL5TR</disposableIdentifier>
                      <reference>BFA+</reference>
                      <disposableType>BOTTLE</disposableType>
                      <disposableStartDateTime>20150107120726</disposableStartDateTime>
                      <disposableFinalDateTime>20170503164955</disposableFinalDateTime>
                      <disposableSetupTechnologist>CF</disposableSetupTechnologist>
                    </disposable>
                    <volume>0</volume>
                    <volumeUnit>mL</volumeUnit>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
          </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "BFA+_SECTION-ID",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "3C60",
                    },
                    {
                        "code": "BFA+_IDENT",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "ARGPL5TR",
                    },
                    {
                        "code": "BFA+_VOLUME",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "0",
                    },
                    {
                        "code": "BFA+_START_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20150107120726",
                    },
                    {
                        "code": "BFA+_DISPOSABLE_START_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20150107120726",
                    },
                    {
                        "code": "BFA+_DISPOSABLE_FINAL_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20170503164955",
                    },
                    {
                        "code": "BOTTLE_TYPE",
                        "instrument": "BTA-1 le mans",
                        "value": "BFA+",
                    },
                    {
                        "code": "BFA+_RESULT",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "operator": "CF",
                        "value": "Pos",
                    },
                    {
                        "code": "BFA+_ABNORMAL_FLAG",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "8",
                    },
                    {
                        "code": "BFA+_TIME_TO_DETECTION_POSITIVITY",
                        "instrument": "BTA-1 le mans",
                        "value": "00:06",
                    },
                    {
                        "code": "BFA+_TIME_TO_DETECTION",
                        "instrument": "BTA-1 le mans",
                        "value": "0.1",
                    },
                    {
                        "code": "BFA+_DETERMINED_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20150107121027",
                    },
                ],
                "sample_id": "35180010201",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_bloodculture_unk(self):
    date = datetime.datetime(2015, 1, 8, 11, 7, 37)
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
          <header>
            <version>1394-97</version>
            <dateTime>20150108110737</dateTime>
            <instrumentName>BTA-1 le mans</instrumentName>
            <serialNumber>COM10_1</serialNumber>
          </header>
          <requestResult>
            <patientInformation>
              <patientIdentifier>0101600039794</patientIdentifier>
              <lastName>Z_LABO_DAMIEN</lastName>
              <birthdate>19810908</birthdate>
              <sex>M</sex>
              <address2>20000101</address2>
              <physicianIdentifier>ZZ</physicianIdentifier>
              <physicianName>SANS PRESCRIPTION MEDICALE</physicianName>
              <admissionDate>20000101</admissionDate>
              <dischargeDate>20150122</dischargeDate>
              <location>ZZZ</location>
            </patientInformation>
            <testOrder>
              <specimen>
                <specimenIdentifier>35180010209</specimenIdentifier>
                <collectedDateTime>20150108110000</collectedDateTime>
                <receivedDateTime>20150108110522</receivedDateTime>
                <specimenType>HEMOAN</specimenType>
                <specimenNature>HEMOAN</specimenNature>
                <specimenNatureText>HEMOAN</specimenNatureText>
              </specimen>
              <test>
                <universalIdentifier>
                  <testGroupCode>BC</testGroupCode>
                </universalIdentifier>
                <instrumentSectionId>1B41</instrumentSectionId>
                <instrumentName>BTA-1 le mans</instrumentName>
                <instrumentType>bta</instrumentType>
                <instrumentSerialNumber>COM10_1</instrumentSerialNumber>
                <result>
                  <value>
                    <bloodCulture>
                      <dateResultDetermined>20150108110737</dateResultDetermined>
                      <timeToDetectionInHours>0</timeToDetectionInHours>
                      <result>Unk</result>
                    </bloodCulture>
                  </value>
                  <abnormalFlags>6</abnormalFlags>
                  <resultStatus>I</resultStatus>
                  <startDateTime>20150108110619</startDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>NRGKXWX4</disposableIdentifier>
                      <reference>BFN+</reference>
                      <disposableType>BOTTLE</disposableType>
                      <disposableStartDateTime>20150108110619</disposableStartDateTime>
                    </disposable>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
          </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "BFN+_SECTION-ID",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "1B41",
                    },
                    {
                        "code": "BFN+_IDENT",
                        "date": date,
                        "instrument": "BTA-1 le mans",
                        "value": "NRGKXWX4",
                    },
                    {
                        "code": "BFN+_START_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20150108110619",
                    },
                    {
                        "code": "BFN+_DISPOSABLE_START_DATETIME",
                        "instrument": "BTA-1 le mans",
                        "value": "20150108110619",
                    },
                    {
                        "code": "BOTTLE_TYPE",
                        "instrument": "BTA-1 le mans",
                        "value": "BFN+",
                    },
                ],
                "sample_id": "35180010209",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_atb_adagio(self):
    self.configure(myla_v2_prefixe_atb_adagio="ADAGIO")
    date = datetime.datetime(2020, 6, 9, 14, 34, 42)
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
            <header>
                <version>1394-97</version>
                <dateTime>20200609143502</dateTime>
                <instrumentName>ADAGIO</instrumentName>
                <serialNumber>ADAGIO</serialNumber>
            </header>
            <requestResult>
                <patientInformation>
                    <patientIdentifier>C0040301085</patientIdentifier>
                    <lastName>TEST BACEXPRESS</lastName>
                    <firstName>MCA</firstName>
                    <birthdate>19620914</birthdate>
                    <sex>F</sex>
                    <address3>AGFA</address3>
                    <physicianIdentifier>AGFA</physicianIdentifier>
                    <physicianName>AGFA NE PAS SUPPRIMER</physicianName>
                    <admissionDate>20200609</admissionDate>
                    <dischargeDate>20210609</dischargeDate>
                    <location>NC</location>
                    <hospitalService>GRAT</hospitalService>
                    <hospitalInstitution>BMQ_9</hospitalInstitution>
                </patientInformation>
                <testOrder>
                    <specimen>
                        <specimenIdentifier>290060978801</specimenIdentifier>
                        <collectedDateTime>20200609131200</collectedDateTime>
                        <collectionEndDateTime>20200609131200</collectionEndDateTime>
                        <relevantClinicalInformation>ECBU</relevantClinicalInformation>
                        <specimenType>ECBU</specimenType>
                        <specimenTypeText>ECBU</specimenTypeText>
                        <specimenNature>ECBU</specimenNature>
                        <specimenNatureText>ECBU</specimenNatureText>
                        <specimenSource>ECBU</specimenSource>
                        <specimenSourceText>ECBU</specimenSourceText>
                    </specimen>
                    <isolateNumber>1</isolateNumber>
                    <test>
                        <universalIdentifier>
                            <testIdentifier>ADAGIO</testIdentifier>
                            <testName>ADAGIO</testName>
                        </universalIdentifier>
                        <instrumentName>ADAGIO</instrumentName>
                        <instrumentType>ASTGENERIC</instrumentType>
                        <instrumentSerialNumber>d3135ebb-464c-4f10-b84b-d5725b337a61</instrumentSerialNumber>
                        <result>
                            <value>
                                <identification>
                                    <significantTaxon>
                                        <code>pseaer</code>
                                        <name>Pseudomonas aeruginosa</name>
                                    </significantTaxon>
                                </identification>
                                <ast>
                                    <antibiotic>
                                        <code>tic</code>
                                        <name>Ticarcilline</name>
                                        <category>S</category>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>tcc</code>
                                        <name>Ticarcilline/acide clavulanique</name>
                                        <category>S</category>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>pip</code>
                                        <name>Pipéracilline</name>
                                        <category>S</category>
                                    </antibiotic>
                                    <antibiotic>
                                        <code>tzp</code>
                                        <name>Pipéracilline/tazobactam</name>
                                        <category>S</category>
                                    </antibiotic>
                                </ast>
                            </value>
                            <resultStatus>F</resultStatus>
                            <action>
                                <actionName>validate</actionName>
                                <actionOperator>LESLE</actionOperator>
                            </action>
                            <resultDateTime>20200609143442</resultDateTime>
                            <userComment>
                                <comment>
                                    <text>SBLACT</text>
                                    <type>PHE</type>
                                </comment>
                            </userComment>
                        </result>
                    </test>
                </testOrder>
            </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "ECBU",
                        "comments": [],
                        "date": date,
                        "instrument": "ADAGIO",
                        "nom_antibiogramme": "ADAGIO",
                        "phenotypes": [],
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "ADAGIO_TIC",
                                        "mic": "-",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "ADAGIO_TCC",
                                        "mic": "-",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "ADAGIO_PIP",
                                        "mic": "-",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "ADAGIO_TZP",
                                        "mic": "-",
                                        "sensitivity": "S",
                                    },
                                ],
                                "sub_code": "1",
                                "value": "G_PSEAER",
                            }
                        ],
                    }
                ],
                "sample_id": "290060978801",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_no_result(self):
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
          <header>
            <version>1394-97</version>
            <dateTime>20150107120906</dateTime>
            <instrumentName>VITEKMSACQ01</instrumentName>
            <serialNumber>50063</serialNumber>
          </header>
          <requestResult>
            <patientInformation>
              <patientIdentifier>!oRPHaN!</patientIdentifier>
              <patientVisitNumber>!oRPHaN!</patientVisitNumber>
              <sex>U</sex>
              <comment>
                <text/>
              </comment>
            </patientInformation>
            <testOrder>
              <specimen>
                <specimenIdentifier>00210114590frezet</specimenIdentifier>
                <receivedDateTime>20150106141223</receivedDateTime>
              </specimen>
              <isolateNumber>1</isolateNumber>
              <test>
                <universalIdentifier>
                  <testGroupCode>ID</testGroupCode>
                  <testIdentifier>MALDI-TOF</testIdentifier>
                  <testName>test MALDI-TOF</testName>
                </universalIdentifier>
                <positionOnDisposable>B2</positionOnDisposable>
                <instrumentName>VITEKMSACQ01</instrumentName>
                <instrumentType>MSID</instrumentType>
                <instrumentSerialNumber>50063</instrumentSerialNumber>
                <result>
                  <value>
                    <identification>
                      <identificationConfidenceCode>ID_GOOD</identificationConfidenceCode>
                      <identificationConfidence>Bonne identification</identificationConfidence>
                      <probability>99.9</probability>
                      <significantTaxon>
                        <code>stasim</code>
                        <name>Staphylococcus simulans</name>
                      </significantTaxon>
                    </identification>
                  </value>
                  <resultStatus>F</resultStatus>
                  <resultDateTime>20150107104631</resultDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>2621</disposableIdentifier>
                      <reference>DS141829378</reference>
                      <disposableType>AXIMA_SLIDE_REF</disposableType>
                      <disposableSetupTechnologist>mpo</disposableSetupTechnologist>
                    </disposable>
                    <disposable>
                      <disposableIdentifier>1_1003457840</disposableIdentifier>
                      <reference>VITEK MS-CHCA</reference>
                      <disposableType>MATRIX</disposableType>
                      <lotNumber>1003457840</lotNumber>
                      <disposableFinalDateTime>20150107102036</disposableFinalDateTime>
                      <disposableSetupTechnologist>mpo</disposableSetupTechnologist>
                    </disposable>
                    <extraResultData>4459</extraResultData>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
          </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [{"sample_id": "00210114590frezet", "type": "patient"}],
    }
    assert worklist == expected


def test_decode_result_bmr(self):
    self.configure(myla_v2_bmr="BÊTA-LACTAMINES")
    date = datetime.datetime(2015, 1, 7, 0, 53, 43)
    worklist = self.decode(
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no"?>
        <aiMessage>
          <header>
            <version>1394-97</version>
            <dateTime>20150113145521</dateTime>
            <instrumentName>SELCA MAINE VITEK2-1</instrumentName>
            <serialNumber>000009C01C1F</serialNumber>
          </header>
          <requestResult>
            <patientInformation>
              <patientIdentifier>0100100011283</patientIdentifier>
              <lastName>BACTERIO_ESSAI1</lastName>
              <birthdate>19810101</birthdate>
              <sex>F</sex>
              <address2>20000101</address2>
              <physicianIdentifier>ZZ</physicianIdentifier>
              <physicianName>SANS PRESCRIPTION MEDICALE</physicianName>
              <admissionDate>20000101</admissionDate>
              <dischargeDate>20150128</dischargeDate>
              <location>ZZZ</location>
            </patientInformation>
            <testOrder>
              <specimen>
                <specimenIdentifier>01180010247</specimenIdentifier>
                <collectedDateTime>20150113144700</collectedDateTime>
                <receivedDateTime>20150113145321</receivedDateTime>
                <specimenType>APU1</specimenType>
                <specimenNature>APU1</specimenNature>
                <specimenNatureText>APU1</specimenNatureText>
              </specimen>
              <isolateNumber>1</isolateNumber>
              <isolateRelativeIdentifier>6426995</isolateRelativeIdentifier>
              <test>
                <universalIdentifier>
                  <testGroupCode>SU</testGroupCode>
                  <testIdentifier>AST-N235</testIdentifier>
                  <testName>AST-N235</testName>
                </universalIdentifier>
                <instrumentName>SELCA MAINE VITEK2-1</instrumentName>
                <instrumentType>V2S</instrumentType>
                <instrumentSerialNumber>000009C01C1F</instrumentSerialNumber>
                <result>
                  <value>
                    <identification>
                      <significantTaxon>
                        <code>esccol</code>
                        <name>Escherichia coli</name>
                      </significantTaxon>
                    </identification>
                    <ast>
                      <antibiotic>
                        <code>am</code>
                        <name>Ampicilline</name>
                        <highMic>
                          <micSign>&gt;=</micSign>
                          <micValue>32</micValue>
                        </highMic>
                        <category>R</category>
                        <nonExpertCategory>R</nonExpertCategory>
                      </antibiotic>
                    </ast>
                    <expertFinding>
                      <expertConfidence>Expertise concordante</expertConfidence>
                      <resistanceMechanism>
                        <drugFamily>BÊTA-LACTAMINES</drugFamily>
                        <phenotype>HYPERPRODUCTION SHV1</phenotype>
                        <phenotype>BÊTA-LACTAMASE À SPECTRE ÉTENDU</phenotype>
                      </resistanceMechanism>
                      <resistanceMechanism>
                        <drugFamily>FOSFOMYCINE</drugFamily>
                        <phenotype>SAUVAGE</phenotype>
                      </resistanceMechanism>
                      <resistanceMechanism>
                        <drugFamily>AMINOSIDES</drugFamily>
                        <phenotype>SAUVAGE</phenotype>
                      </resistanceMechanism>
                      <resistanceMechanism>
                        <drugFamily>QUINOLONES</drugFamily>
                        <phenotype>RÉSISTANCE PARTIELLE</phenotype>
                      </resistanceMechanism>
                      <resistanceMechanism>
                        <drugFamily>TRIMÉTHOPRIME/SULFAMIDES</drugFamily>
                        <phenotype>RÉSISTANT</phenotype>
                      </resistanceMechanism>
                      <resistanceMechanism>
                        <drugFamily>FURANES</drugFamily>
                        <phenotype>SAUVAGE</phenotype>
                      </resistanceMechanism>
                    </expertFinding>
                  </value>
                  <resultStatus>F</resultStatus>
                  <startDateTime>20150106160843</startDateTime>
                  <resultDateTime>20150107005343</resultDateTime>
                  <bmxResultData>
                    <disposable>
                      <disposableIdentifier>6353095401210713</disposableIdentifier>
                      <reference>AST-N235</reference>
                      <disposableType>VITEK2-AST-CARD</disposableType>
                      <lotNumber>635309540</lotNumber>
                      <expirationDate>20150605</expirationDate>
                      <disposableStartDateTime>20150106160843</disposableStartDateTime>
                      <disposableFinalDateTime>20150107005343</disposableFinalDateTime>
                      <disposableSetupTechnologist>Angéli</disposableSetupTechnologist>
                      <disposableSetupTechnologistText>Angélique Guibert</disposableSetupTechnologistText>
                    </disposable>
                  </bmxResultData>
                </result>
              </test>
            </testOrder>
          </requestResult>
        </aiMessage>"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "lotNumber", "value": "635309540"},
                    {
                        "code": "APU1",
                        "comments": [],
                        "date": date,
                        "instrument": "000009C01C1F",
                        "nom_antibiogramme": "AST-N235",
                        "phenotypes": [
                            "BÊTA-LACTAMINES-HYPERPRODUCTION " "SHV1",
                            "BÊTA-LACTAMINES-BÊTA-LACTAMASE À " "SPECTRE ÉTENDU",
                            "FOSFOMYCINE-SAUVAGE",
                            "AMINOSIDES-SAUVAGE",
                            "QUINOLONES-RÉSISTANCE PARTIELLE",
                            "TRIMÉTHOPRIME/SULFAMIDES-RÉSISTANT",
                            "FURANES-SAUVAGE",
                        ],
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "BMR_HYPERPRODUCTION "
                                        "SHV1;BMR_BÊTA-LACTAMASE "
                                        "À "
                                        "SPECTRE "
                                        "ÉTENDU",
                                        "mic": "#",
                                        "sensitivity": "BMR",
                                    },
                                    {
                                        "antibiotic": "A_AM",
                                        "mic": ">=32",
                                        "sensitivity": "R",
                                    },
                                ],
                                "sub_code": "1",
                                "value": "G_ESCCOL",
                            }
                        ],
                    },
                ],
                "sample_id": "01180010247",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_user_comment(self):
    self.configure(myla_v2_commentaire_user=True)
    date = datetime.datetime(2021, 1, 14, 4, 27, 36)
    worklist = self.decode(
        """
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<aiMessage>
    <header>
        <senderName>myla</senderName>
        <version>1394-97</version>
        <dateTime>20210114105117</dateTime>
        <instrumentName>VITEK2 gauche</instrumentName>
        <serialNumber>00001B1B5084</serialNumber>
    </header>
    <requestResult>
        <patientInformation>
            <patientIdentifier>101120000097</patientIdentifier>
            <lastName>DIAS</lastName>
            <firstName>Maria</firstName>
            <birthdate>19480425</birthdate>
            <sex>F</sex>
            <physicianIdentifier>BUSSBE</physicianIdentifier>
            <physicianName>BUSSI</physicianName>
            <admissionDate>20210113</admissionDate>
            <dischargeDate>20210210</dischargeDate>
            <hospitalService>KALISIL</hospitalService>
            <hospitalServiceText>KALISIL</hospitalServiceText>
            <hospitalInstitution>BIOCLICLARI</hospitalInstitution>
            <hospitalInstitutionText>BIOCLICLARI</hospitalInstitutionText>
        </patientInformation>
        <testOrder>
            <specimen>
                <specimenIdentifier>140210112047AA</specimenIdentifier>
                <collectedDateTime>20210112091300</collectedDateTime>
                <collectionEndDateTime>20210112091300</collectionEndDateTime>
                <specimenType>URIN</specimenType>
                <specimenTypeText>URIN</specimenTypeText>
                <specimenNature>URIN</specimenNature>
                <specimenNatureText>URIN</specimenNatureText>
            </specimen>
            <isolateNumber>1</isolateNumber>
            <isolateRelativeIdentifier>91814</isolateRelativeIdentifier>
            <test>
                <universalIdentifier>
                    <testGroupCode>SU</testGroupCode>
                    <testIdentifier>AST-P606</testIdentifier>
                    <testName>AST-P606</testName>
                </universalIdentifier>
                <instrumentName>VITEK2 gauche</instrumentName>
                <instrumentType>V2S</instrumentType>
                <instrumentSerialNumber>00001B1B5084</instrumentSerialNumber>
                <result>
                    <value>
                        <identification>
                            <identificationConfidenceCode>ID_EXCELLENT</identificationConfidenceCode>
                            <identificationConfidence>Excellent identification</identificationConfidence>
                            <bioNumber>114002765753471</bioNumber>
                            <probability>99.0</probability>
                            <significantTaxon>
                                <code>strfae</code>
                                <name>Enterococcus faecalis</name>
                            </significantTaxon>
                        </identification>
                    </value>
                 <resultStatus>F</resultStatus>
                <startDateTime>20210113172236</startDateTime>
                <resultDateTime>20210114042736</resultDateTime>
                <userComment>
                    <comment>
                        <source>L</source>
                        <code>NTFE</code>
                        <text>Le résultat sensible n'est valable que pour les cystites</text>
                        <type>G</type>
                    </comment>
                    <comment>
                        <source>L</source>
                        <code>NTFE</code>
                        <text>2eme commentaire</text>
                        <type>G</type>
                    </comment>
                </userComment>
                </result>
            </test>
        </testOrder>
    </requestResult>
</aiMessage>
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "GERME_1_URIN",
                        "instrument": "00001B1B5084",
                        "value": "G_STRFAE",
                    },
                    {
                        "code": "IDENT_URIN",
                        "comments": [
                            "Le résultat sensible n'est valable "
                            "que pour les cystites",
                            "2eme commentaire",
                        ],
                        "date": date,
                        "instrument": "00001B1B5084",
                        "nom_antibiogramme": "AST-P606",
                        "phenotypes": [],
                        "value": {
                            "germes": [{"id": "G_STRFAE", "rang": 1}],
                            "seq": "0",
                            "type_resultat": "identification_germes",
                        },
                    },
                ],
                "sample_id": "140210112047AA",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
