# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "sedimax"


def test_encode_order(self):
    _order_message = "W|-|123456^NYME ANO|"
    message = self.order()
    assert message == _order_message


def test_decode_result(self):
    date = datetime.datetime(2015, 2, 3, 11, 28)
    worklist = self.decode(
        """S|2M2014080481|146|9903000202|0|SEDIMAX Essai homme|2|1|hama|2015/02/03|11:28:13|1|0|1.00|AMAS WBC +++|RBC^++^^12.40^p/HPF^54.56^p/ul^8.27^^0|WBC^++++^^198.30^p/HPF^872.52^p/ul^132.20^^0|CRY^+++^^21.46^p/HPF^94.42^p/ul^14.31^^0|.CRY^+^^0.00^p/HPF^0.00^p/ul^0.00^^0|.CaOxm^+++^^19.54^p/HPF^86.00^p/ul^13.03^^1|.CaOxd^+^^1.81^p/HPF^7.99^p/ul^1.21^^1|.TRI^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|.URI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.U-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.P-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|HYA^+^^0.68^p/HPF^2.97^p/ul^0.45^^1|PAT^++++^^2.33^p/HPF^10.23^p/ul^1.55^^0|.PAT^+^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-GRA^+^^0.45^p/HPF^1.98^p/ul^0.30^^1|.C-RBC^++^^0.73^p/HPF^3.23^p/ul^0.49^^1|.C-WBC^+++^^1.14^p/HPF^5.02^p/ul^0.76^^1|NEC^+^^1.20^p/HPF^5.28^p/ul^0.80^^0|EPI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|YEA^-^^0.30^p/HPF^1.32^p/ul^0.20^^0|BAC^++^^76.20^p/HPF^335.28^p/ul^50.80^^0|MUC^-^^2.50^p/HPF^11.00^p/ul^1.67^^0|SPRM^+^^8.42^p/HPF^37.03^p/ul^5.61^^1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "9903000202",
                "rack": "2-1",
                "results": [
                    {
                        "code": "COMMENT",
                        "date": date,
                        "value": "AMAS WBC +++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "RBC1",
                        "date": date,
                        "value": "++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "RBC3",
                        "date": date,
                        "value": "54.56",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "WBC1",
                        "date": date,
                        "value": "++++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "WBC3",
                        "date": date,
                        "value": "872.52",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "NEC1",
                        "date": date,
                        "value": "+",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "NEC3",
                        "date": date,
                        "value": "5.28",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "EPI1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "EPI3",
                        "date": date,
                        "value": "0.00",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "YEA1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "YEA3",
                        "date": date,
                        "value": "1.32",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "BAC1",
                        "date": date,
                        "value": "++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "BAC3",
                        "date": date,
                        "value": "335.28",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "MUC1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "MUC3",
                        "date": date,
                        "value": "11.00",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "SPRM1",
                        "date": date,
                        "value": "+",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "SPRM3",
                        "date": date,
                        "value": "37.03",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "CRISTAL",
                        "date": date,
                        "value": ".CaOx+++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "CYLINDRE",
                        "date": date,
                        "value": ".C-GRA+;.C-RBC++;.C-WBC+++;HYA+",
                        "flags": [],
                        "operator": "hama",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2015, 2, 3, 16, 30)
    worklist = self.decode(
        """S|2M2014080481|171|1103006502|0|QC_HIGH|8|2|hama|2015/02/03|16:30:33|1|0|1.00|Test failed!|RBC^-^^0.35^p/HPF^1.52^p/ul^0.23^^0|WBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "1103006502",
                "control_lot": "1103006502",
                "rack": "8-2",
                "results": [
                    {"code": "RBC1", "date": date, "value": "-", "flags": []},
                    {"code": "RBC3", "date": date, "value": "1.52", "flags": []},
                    {"code": "WBC1", "date": date, "value": "-", "flags": []},
                    {"code": "WBC3", "date": date, "value": "0.00", "flags": []},
                ],
            }
        ],
    }
    assert worklist == expected


def test_result_sans_cx_cly(self):
    date = datetime.datetime(2015, 2, 3, 18, 23)
    worklist = self.decode(
        """S|2M2014080481|176|9903000302|0|-|14|2|hama|2015/02/03|18:23:20|1|0|1.00||RBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|WBC^+++^^49.00^p/HPF^215.60^p/ul^32.67^^0|CRY^-^^0.50^p/HPF^2.20^p/ul^0.33^^0|.CRY^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|.CaOxm^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|.CaOxd^-^^0.30^p/HPF^1.32^p/ul^0.20^^0|.TRI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.URI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.U-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.P-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|HYA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-GRA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-RBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-WBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|NEC^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|EPI^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|YEA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|BAC^++^^103.80^p/HPF^456.72^p/ul^69.20^^0|MUC^-^^31.30^p/HPF^137.72^p/ul^20.87^^0|SPRM^-^^0.00^p/HPF^0.00^p/ul^0.00^^0"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "9903000302",
                "rack": "14-2",
                "results": [
                    {
                        "code": "RBC1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "RBC3",
                        "date": date,
                        "value": "0.00",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "WBC1",
                        "date": date,
                        "value": "+++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "WBC3",
                        "date": date,
                        "value": "215.60",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "NEC1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "NEC3",
                        "date": date,
                        "value": "0.44",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "EPI1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "EPI3",
                        "date": date,
                        "value": "0.44",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "YEA1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "YEA3",
                        "date": date,
                        "value": "0.00",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "BAC1",
                        "date": date,
                        "value": "++",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "BAC3",
                        "date": date,
                        "value": "456.72",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "MUC1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "MUC3",
                        "date": date,
                        "value": "137.72",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "SPRM1",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "SPRM3",
                        "date": date,
                        "value": "0.00",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "CRISTAL",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                    {
                        "code": "CYLINDRE",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "hama",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_result_na(self):
    date = datetime.datetime(2015, 2, 3, 11, 28)
    worklist = self.decode(
        """S||146|9903000202|0|SEDIMAX Essai homme|2|2|isa|2015/02/03|11:28:13|1|0|1.00||CRY^-^^0.00^p/HPF^0.00^p/ul^0.00^^1|.CRY^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.CaOxm^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.CaOxd^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.TRI^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.URI^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.U-AMO^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|.P-AMO^N/A^^0.00^p/HPF^0.00^p/ul^0.00^^0|HYA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-GRA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-RBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-WBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "9903000202",
                "rack": "2-2",
                "results": [
                    {
                        "code": "CRISTAL",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "isa",
                    },
                    {
                        "code": "CYLINDRE",
                        "date": date,
                        "value": "-",
                        "flags": [],
                        "operator": "isa",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_result_s2(self):
    date = datetime.datetime(2015, 2, 6, 11, 12)
    worklist = self.decode(
        """S2|2M2014080481|234|9909000102|0|alarme rouge|7|2|isa|2015/02/06|11:12:26|1|1|1.00||0|0^-1|1^Automatic validated^isa^isa^isa^-|2|||||||RBC^-^^0.20^p/HPF^0.88^p/ul^0.13^^0|||||WBC^++++^^300.00^p/HPF^1320.00^p/ul^200.00^^1|||||CRY^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.CRY^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.CaOxm^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.CaOxd^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.TRI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.URI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.U-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.P-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||HYA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.PAT^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.C-GRA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.C-RBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||.C-WBC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||NEC^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|||||EPI^++++^^29.55^p/HPF^130.02^p/ul^19.70^^1|||||YEA^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||BAC^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|||||MUC^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|||||SPRM^-^^0.00^p/HPF^0.00^p/ul^0.00^^0||||"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "rack": "7-2",
                "sample_id": "9909000102",
                "results": [
                    {
                        "code": "RBC1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "RBC3",
                        "date": date,
                        "value": "0.88",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "WBC1",
                        "date": date,
                        "value": "++++",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "WBC3",
                        "date": date,
                        "value": "1320.00",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "NEC1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "NEC3",
                        "date": date,
                        "value": "0.44",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "EPI1",
                        "date": date,
                        "value": "++++",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "EPI3",
                        "date": date,
                        "value": "130.02",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "YEA1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "YEA3",
                        "date": date,
                        "value": "0.00",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "BAC1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "BAC3",
                        "date": date,
                        "value": "0.00",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "MUC1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "MUC3",
                        "date": date,
                        "value": "0.44",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "SPRM1",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "SPRM3",
                        "date": date,
                        "value": "0.00",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "CRISTAL",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                    {
                        "code": "CYLINDRE",
                        "date": date,
                        "value": "-",
                        "flags": ["CROWDED"],
                        "operator": "isa",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_all_result(self):

    self.configure(all_resu=True)
    date = datetime.datetime(2015, 2, 3, 11, 28)
    worklist = self.decode(
        """S|2M2014080481|146|9903000202|0|SEDIMAX Essai homme|2|1|hama|2015/02/03|11:28:13|1|0|1.00|AMAS WBC +++|RBC^++^^12.40^p/HPF^54.56^p/ul^8.27^^0|WBC^++++^^198.30^p/HPF^872.52^p/ul^132.20^^0|CRY^+++^^21.46^p/HPF^94.42^p/ul^14.31^^0|.CRY^+^^0.00^p/HPF^0.00^p/ul^0.00^^0|.CaOxm^+++^^19.54^p/HPF^86.00^p/ul^13.03^^1|.CaOxd^+^^1.81^p/HPF^7.99^p/ul^1.21^^1|.TRI^-^^0.10^p/HPF^0.44^p/ul^0.07^^0|.URI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.U-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|.P-AMO^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|HYA^+^^0.68^p/HPF^2.97^p/ul^0.45^^1|PAT^++++^^2.33^p/HPF^10.23^p/ul^1.55^^0|.PAT^+^^0.00^p/HPF^0.00^p/ul^0.00^^0|.C-GRA^+^^0.45^p/HPF^1.98^p/ul^0.30^^1|.C-RBC^++^^0.73^p/HPF^3.23^p/ul^0.49^^1|.C-WBC^+++^^1.14^p/HPF^5.02^p/ul^0.76^^1|NEC^+^^1.20^p/HPF^5.28^p/ul^0.80^^0|EPI^-^^0.00^p/HPF^0.00^p/ul^0.00^^0|YEA^-^^0.30^p/HPF^1.32^p/ul^0.20^^0|BAC^++^^76.20^p/HPF^335.28^p/ul^50.80^^0|MUC^-^^2.50^p/HPF^11.00^p/ul^1.67^^0|SPRM^+^^8.42^p/HPF^37.03^p/ul^5.61^^1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "9903000202",
                "rack": "2-1",
                "results": [
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "COMMENT",
                        "flags": [],
                        "value": "AMAS WBC +++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "RBC1",
                        "flags": [],
                        "value": "++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "RBC3",
                        "flags": [],
                        "value": "54.56",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "WBC1",
                        "flags": [],
                        "value": "++++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "WBC3",
                        "flags": [],
                        "value": "872.52",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "CRY1",
                        "flags": [],
                        "value": "+++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "CRY3",
                        "flags": [],
                        "value": "94.42",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CRY1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CRY3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CaOxm1",
                        "flags": [],
                        "value": "+++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CaOxm3",
                        "flags": [],
                        "value": "86.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CaOxd1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".CaOxd3",
                        "flags": [],
                        "value": "7.99",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".TRI1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".TRI3",
                        "flags": [],
                        "value": "0.44",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".URI1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".URI3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".U-AMO1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".U-AMO3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".P-AMO1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".P-AMO3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "HYA1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "HYA3",
                        "flags": [],
                        "value": "2.97",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "PAT1",
                        "flags": [],
                        "value": "++++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "PAT3",
                        "flags": [],
                        "value": "10.23",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".PAT1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".PAT3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-GRA1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-GRA3",
                        "flags": [],
                        "value": "1.98",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-RBC1",
                        "flags": [],
                        "value": "++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-RBC3",
                        "flags": [],
                        "value": "3.23",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-WBC1",
                        "flags": [],
                        "value": "+++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": ".C-WBC3",
                        "flags": [],
                        "value": "5.02",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "NEC1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "NEC3",
                        "flags": [],
                        "value": "5.28",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "EPI1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "EPI3",
                        "flags": [],
                        "value": "0.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "YEA1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "YEA3",
                        "flags": [],
                        "value": "1.32",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "BAC1",
                        "flags": [],
                        "value": "++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "BAC3",
                        "flags": [],
                        "value": "335.28",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "MUC1",
                        "flags": [],
                        "value": "-",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "MUC3",
                        "flags": [],
                        "value": "11.00",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "SPRM1",
                        "flags": [],
                        "value": "+",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "SPRM3",
                        "flags": [],
                        "value": "37.03",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "CRISTAL",
                        "flags": [],
                        "value": ".CaOx+++",
                    },
                    {
                        "date": date,
                        "operator": "hama",
                        "code": "CYLINDRE",
                        "flags": [],
                        "value": ".C-GRA+;.C-RBC++;.C-WBC+++;HYA+",
                    },
                ],
            }
        ],
    }
    assert worklist == expected
