# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "hl7_ihe_pam_adt"


def test_decode_a28_vali(self):
    worklist = self.decode(
        """
        MSH|^~\\&|SENDER|SENDER|RECEIVER|RECEIVER|20220725103501||ADT^A28^ADT_A05|19061903|P|2.5^FRA^2.5||||||UNICODE UTF-8|FR
    EVN||20220725103501
    PID|1||276037510669380^^^ASIP-SANTE-INS-NIR&1.2.250.1.213.1.4.8&ISO^INS||ANO^Pauline^^^^^D~ANO^Nyme^Nyme Pauline Anne^^Mme^^L||20000215|F|||29 AV LALALA^3ème étage^TOULOUSE^^31000^FRA^H^^29064~^^TOULOUSE^^31000^FRA^BDL^^29064||^PRN^PH^^^^^^^^^0478745656~^PRN^CP^^^^^^^^^0652849184~^NET^Internet^anonyme@mail.com|^PRN^CP^^^^^^^^^0789124578~^PRN^PH^^^^^^^^^0589124578~^NET^Internet^pro@mail.com|fr|M||123456789^^^AUT-AFFECTATION^PI||||||||FRA^FRANCE^ISO 3166 alpha-3||||N||VALI|20220725103501
    PD1||U||||||||||N
    PV1|1|N
    ZFD|||N|N|INSI|20220725162642|CN|20250131000000
    OBX|1|NM|3141-9^BODY WEIGHT^LN||75|kg|||||R|||20131222163908||331234567^DUPOND^Pierre^^^Dr^^^INPS&1.2.250.1.71.4.2.1&ISO^^^^ADELI
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "RECEIVER",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "AUT-AFFECTATION",
                    "identifier": "123456789",
                    "oid": "",
                },
                "address": "29 AV LALALA~3ème étage",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "",
                "birthdate": datetime.datetime(2000, 2, 15, 0, 0),
                "birthdate_modified": "N",
                "birthplace": "TOULOUSE",
                "birthplace_code": "29064",
                "breed_code": "",
                "citizenships": ["FRA"],
                "city": "TOULOUSE",
                "country": "FRA",
                "county_code": "29064",
                "data_protection": "N",
                "death_indicator": "N",
                "deathdate": None,
                "email": "anonyme@mail.com",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2022, 7, 25, 10, 35, 1),
                    "type_code": "A28",
                    "type_label": "Create patient",
                },
                "first_name": "Nyme",
                "further_names": ["Nyme", "Pauline", "Anne"],
                "gestation_weeks": "",
                "height": "",
                "identity_attribut": "normale",
                "identity_document": "CN",
                "identity_document_expiration_date": datetime.datetime(
                    2025, 1, 31, 0, 0
                ),
                "identity_obtaining_mode": "INSI",
                "identity_status": "Qualifiée",
                "identity_unknow_indicator": "",
                "identity_update_date": datetime.datetime(2022, 7, 25, 10, 35, 1),
                "ins_number": "276037510669380",
                "insi_query_date": datetime.datetime(2022, 7, 25, 16, 26, 42),
                "language": "fr",
                "last_name": "ANO",
                "living_arrangement": "U",
                "lunar_date": "",
                "marital_status": "M",
                "mobile": "0652849184",
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.8",
                "patient_class": "N",
                "patient_id": "",
                "phone": "0478745656",
                "phones": ["0478745656", "0652849184"],
                "postal_code": "31000",
                "pro_email": "pro@mail.com",
                "pro_mobile": "0789124578",
                "pro_phone": "0589124578",
                "production_class_code": "",
                "sample_id": "",
                "sex": "F",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "Mme",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "Pauline",
                "used_last_name": "ANO",
                "veterans_military_status": "",
                "weight": "75",
            }
        ],
        "sender_id": "SENDER",
    }
    assert worklist == expected


def test_decode_a28_prov(self):
    worklist = self.decode(
        """
        MSH|^~\\&|SENDER|SENDER|RECEIVER|RECEIVER|20220725103501||ADT^A28^ADT_A05|19061903|P|2.5^FRA^2.5||||||UNICODE UTF-8|FR
    EVN||20220725103501
    PID|1||123456789^^^AUT-AFFECTATION^PI||ANO^Pauline^^^^^D~ANO^Nyme^Nyme Pauline Anne^^Mme^^L||20000215|F|||29 AV LALALA^3ème étage^TOULOUSE^^31000^FRA^H^^29064~^^TOULOUSE^^31000^FRA^BDL^^29064||^PRN^CP^^^^^^^^^0624504745~^NET^Internet^anonyme@mail.com||fr|M||||||||||FRA^FRANCE^ISO 3166 alpha-3||||N||PROV|20220725103501
    PD1||U||||||||||N
    PV1|1|N
    ZFD|||N|N|SM
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "RECEIVER",
        "samples": [
            {
                "address": "29 AV LALALA~3ème étage",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "",
                "birthdate": datetime.datetime(2000, 2, 15, 0, 0),
                "birthdate_modified": "N",
                "birthplace": "TOULOUSE",
                "birthplace_code": "29064",
                "breed_code": "",
                "citizenships": ["FRA"],
                "city": "TOULOUSE",
                "country": "FRA",
                "county_code": "29064",
                "data_protection": "N",
                "death_indicator": "N",
                "deathdate": None,
                "email": "anonyme@mail.com",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2022, 7, 25, 10, 35, 1),
                    "type_code": "A28",
                    "type_label": "Create patient",
                },
                "first_name": "Nyme",
                "further_names": ["Nyme", "Pauline", "Anne"],
                "gestation_weeks": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "SM",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "",
                "identity_update_date": datetime.datetime(2022, 7, 25, 10, 35, 1),
                "ins_number": "",
                "insi_query_date": None,
                "language": "fr",
                "last_name": "ANO",
                "living_arrangement": "U",
                "lunar_date": "",
                "marital_status": "M",
                "mobile": "0624504745",
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "N",
                "patient_id": "123456789",
                "phone": "",
                "phones": ["0624504745"],
                "postal_code": "31000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "F",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "Mme",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "Pauline",
                "used_last_name": "ANO",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "SENDER",
    }
    assert worklist == expected


def test_decode_a31_ins_nia_to_ins_nir(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20210318151910||ADT^A31^ADT_A05|20210318151910|P|2.5^FRA^2.10||||||UNICODE UTF-8
    EVN||20210318151910
    PID|1||1900068^^^&350000121&M^PI~260058815400244^^^ASIP-SANTE-INS-NIA&1.2.250.1.213.1.4.9&ISO^INS-NIA~260058815400233^^^ASIP-SANTE-INS-NIR&1.2.250.1.213.1.4.8&ISO^INS||^MARIE-CECILE^^^^^D~DARK^JEANNE^JEANNE MARIE CECILE^^Mme^^L||19600530|F|||^^^^^FRA^BDL^^88154|||||S|||||||||1|||||N||VALI|20210318151910
    """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "address": "",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "1",
                "birthdate": datetime.datetime(1960, 5, 30, 0, 0),
                "birthplace": "",
                "birthplace_code": "88154",
                "breed_code": "",
                "citizenships": [],
                "city": "",
                "country": "",
                "county_code": "",
                "death_indicator": "N",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2021, 3, 18, 15, 19, 10),
                    "type_code": "A31",
                    "type_label": "Update patient",
                },
                "first_name": "JEANNE",
                "further_names": ["JEANNE", "MARIE", "CECILE"],
                "identity_attribut": "normale",
                "identity_status": "Qualifiée",
                "identity_unknow_indicator": "",
                "identity_update_date": datetime.datetime(2021, 3, 18, 15, 19, 10),
                "ins_number": "260058815400233",
                "language": "",
                "last_name": "DARK",
                "marital_status": "S",
                "mobile": "",
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.8",
                "patient_id": "1900068",
                "phone": "",
                "phones": [],
                "postal_code": "",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "F",
                "species_code": "",
                "strain": "",
                "title": "Mme",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "MARIE-CECILE",
                "used_last_name": "",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a31_update_demographics(self):
    worklist = self.decode(
        """
        MSH|^~\\&|MBMLV|MBMLV|PAM HM|PAM HM|20211214131412||ADT^A31^ADT_A05|19067567|P|2.5^FRA^2.5||||||8859/1|FR
    EVN||20211214131412
    PID|1||7654457^^^MBMLV&&ISO^PI~276037510669380^^^ASIP-SANTE-INSNIA&1.2.250.1.213.1.4.9&ISO^INS-NIA||JOLI^BERNARD^^^M^^D^A~JOLI^BERNARD^BERNARD GASTON^^M^^L^A||19480213|M|||10 RUE COSTE^^LYON^^69000^FRA^H||^PRN^CP^^^^^^^^^0698877665~^NET^Internet^bernard.joli@email.com|||S||||||||||||||N||PROV|20211202153106
    ROL||UC|ODRP^^^^^|10003069100^GIARD^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^L^^^RPPS^^^^^^^^^^69300
    ROL||AD|RT^^^^^|1158775^DEBOUZIE^^^^^^^MBMLV&1.2.250.1.300.1.1.1.168.1.324&OX^L^^^RI^^^^^^^^^^69300
    ROL||UC|RT^^^^^|10002682531^VOLA^Marco^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^L^^^RPPS^^^^^^^^^^69677
    NK1|1|JOLI^Raphael^^^^^L^A|CHD|^^^^|^PRN^CP^^^^^^^^^0612233445||K|20211202|||||||||||||||||||||||||454300^^^Mediboard&1.2.250.1.2.3.4&OX^PN||||||N
    NK1|2|THOMAS^Evelyne^^^^^L^A|FND|^^^^|^PRN^CP^^^^^^^^^0677493184||C|20211202|||||||||||||||||||||||||454311^^^Mediboard&1.2.250.1.2.3.4&OX^PN||||||N
    PV1|1|N
    ZFD|||N|N|SM
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PAM HM",
        "samples": [
            {
                "address": "10 RUE COSTE~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "",
                "birthdate": datetime.datetime(1948, 2, 13, 0, 0),
                "birthdate_modified": "N",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "LYON",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "N",
                "deathdate": None,
                "email": "bernard.joli@email.com",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2021, 12, 14, 13, 14, 12),
                    "type_code": "A31",
                    "type_label": "Update patient",
                },
                "first_name": "BERNARD",
                "further_names": ["BERNARD", "GASTON"],
                "gestation_weeks": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "SM",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "",
                "identity_update_date": datetime.datetime(2021, 12, 2, 15, 31, 6),
                "ins_number": "276037510669380",
                "insi_query_date": None,
                "language": "",
                "last_name": "JOLI",
                "lunar_date": "",
                "marital_status": "S",
                "mobile": "0698877665",
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.9",
                "patient_class": "N",
                "patient_id": "7654457",
                "phone": "",
                "phones": ["0698877665"],
                "physicians": [
                    {
                        "action_code": "UC",
                        "address": "",
                        "begin_date": None,
                        "city": "",
                        "code": "10003069100",
                        "code_type": "RPPS",
                        "codification": "L",
                        "country": "",
                        "county_code": "",
                        "email": "",
                        "end_date": None,
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "GIARD",
                        "mobile": "",
                        "oid": "1.2.250.1.71.4.2.1",
                        "organization_unit_type": "",
                        "phone": "",
                        "postal_code": "",
                        "provider_type": "",
                        "role_action_reason": "",
                        "role_duration": "",
                        "title": "",
                        "type": "official",
                    },
                    {
                        "action_code": "AD",
                        "address": "",
                        "begin_date": None,
                        "city": "",
                        "code": "1158775",
                        "code_type": "RI",
                        "codification": "L",
                        "country": "",
                        "county_code": "",
                        "email": "",
                        "end_date": None,
                        "first_name": "",
                        "further_names": [],
                        "last_name": "DEBOUZIE",
                        "mobile": "",
                        "oid": "1.2.250.1.300.1.1.1.168.1.324",
                        "organization_unit_type": "",
                        "phone": "",
                        "postal_code": "",
                        "provider_type": "",
                        "role_action_reason": "",
                        "role_duration": "",
                        "title": "",
                        "type": "referred",
                    },
                    {
                        "action_code": "UC",
                        "address": "",
                        "begin_date": None,
                        "city": "",
                        "code": "10002682531",
                        "code_type": "RPPS",
                        "codification": "L",
                        "country": "",
                        "county_code": "",
                        "email": "",
                        "end_date": None,
                        "first_name": "Marco",
                        "further_names": [],
                        "last_name": "VOLA",
                        "mobile": "",
                        "oid": "1.2.250.1.71.4.2.1",
                        "organization_unit_type": "",
                        "phone": "",
                        "postal_code": "",
                        "provider_type": "",
                        "role_action_reason": "",
                        "role_duration": "",
                        "title": "",
                        "type": "referred",
                    },
                ],
                "postal_code": "69000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "relations": [
                    {
                        "address": "~",
                        "ambulatory_status": "",
                        "birth_place": "",
                        "birthdate": None,
                        "birthplace": "",
                        "birthplace_code": "",
                        "citizenship": "",
                        "city": "",
                        "contact_address": "",
                        "contact_city": "",
                        "contact_country": "",
                        "contact_county_code": "",
                        "contact_email": "",
                        "contact_first_name": "",
                        "contact_further_names": [],
                        "contact_last_name": "",
                        "contact_mobile": "",
                        "contact_name_type_code": "",
                        "contact_phone": "",
                        "contact_postal_code": "",
                        "contact_prefix": "",
                        "contact_reason": "",
                        "contact_ssn": "",
                        "country": "",
                        "county_code": "",
                        "email": "",
                        "employee_number": "",
                        "end_date": None,
                        "first_name": "Raphael",
                        "further_names": [],
                        "handicap": "",
                        "identifier": "454300",
                        "identity_attribut": "normale",
                        "job_code": "",
                        "job_status": "",
                        "job_title": "",
                        "language": "",
                        "last_name": "JOLI",
                        "living_arrangement": "",
                        "living_dependency": "",
                        "marital_status": "",
                        "mobile": "0612233445",
                        "mother_first_name": "",
                        "mother_further_names": [],
                        "mother_last_name": "",
                        "mother_name_type_code": "",
                        "mother_prefix": "",
                        "nationality": "",
                        "oid": "1.2.250.1.2.3.4",
                        "organization_identifier": "",
                        "organization_name": "",
                        "organization_oid": "",
                        "phone": "",
                        "postal_code": "",
                        "pro_email": "",
                        "pro_mobile": "",
                        "pro_phone": "",
                        "protection_indicator": "",
                        "publicity_code": "",
                        "relationship": "CHD",
                        "role": "K",
                        "sex": "",
                        "start_date": datetime.datetime(2021, 12, 2, 0, 0),
                        "student_indicator": "",
                        "title": "",
                        "used_first_name": "",
                        "used_last_name": "",
                        "vip_indicator": "N",
                    },
                    {
                        "address": "~",
                        "ambulatory_status": "",
                        "birth_place": "",
                        "birthdate": None,
                        "birthplace": "",
                        "birthplace_code": "",
                        "citizenship": "",
                        "city": "",
                        "contact_address": "",
                        "contact_city": "",
                        "contact_country": "",
                        "contact_county_code": "",
                        "contact_email": "",
                        "contact_first_name": "",
                        "contact_further_names": [],
                        "contact_last_name": "",
                        "contact_mobile": "",
                        "contact_name_type_code": "",
                        "contact_phone": "",
                        "contact_postal_code": "",
                        "contact_prefix": "",
                        "contact_reason": "",
                        "contact_ssn": "",
                        "country": "",
                        "county_code": "",
                        "email": "",
                        "employee_number": "",
                        "end_date": None,
                        "first_name": "Evelyne",
                        "further_names": [],
                        "handicap": "",
                        "identifier": "454311",
                        "identity_attribut": "normale",
                        "job_code": "",
                        "job_status": "",
                        "job_title": "",
                        "language": "",
                        "last_name": "THOMAS",
                        "living_arrangement": "",
                        "living_dependency": "",
                        "marital_status": "",
                        "mobile": "0677493184",
                        "mother_first_name": "",
                        "mother_further_names": [],
                        "mother_last_name": "",
                        "mother_name_type_code": "",
                        "mother_prefix": "",
                        "nationality": "",
                        "oid": "1.2.250.1.2.3.4",
                        "organization_identifier": "",
                        "organization_name": "",
                        "organization_oid": "",
                        "phone": "",
                        "postal_code": "",
                        "pro_email": "",
                        "pro_mobile": "",
                        "pro_phone": "",
                        "protection_indicator": "",
                        "publicity_code": "",
                        "relationship": "FND",
                        "role": "C",
                        "sex": "",
                        "start_date": datetime.datetime(2021, 12, 2, 0, 0),
                        "student_indicator": "",
                        "title": "",
                        "used_first_name": "",
                        "used_last_name": "",
                        "vip_indicator": "N",
                    },
                ],
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "M",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "BERNARD",
                "used_last_name": "JOLI",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "MBMLV",
    }
    assert worklist == expected


def test_decode_a47_update_identifier(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20210318151910||ADT^A47^ADT_A30|20210318151910|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20210318151910
    PID|1||1900068^^^&350000121&M^PI~260058815400244^^^ASIP-SANTE-INS-NIR&1.2.250.1.213.1.4.8&ISO^INS-NIR||^MARIE-CECILE^^^^^D~DARK^JEANNE^JEANNE MARIE CECILE^^Mme^^L||19600530|F|||^^^^^FRA^BDL^^88154|||||S|||||||||1|||||N||VALI
    MRG|260058815400233^^^ASIP-SANTE-INS-NIR&1.2.250.1.213.1.4.8&ISO^INS
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "address": "",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "1",
                "birthdate": datetime.datetime(1960, 5, 30, 0, 0),
                "birthplace": "",
                "birthplace_code": "88154",
                "breed_code": "",
                "citizenships": [],
                "city": "",
                "country": "",
                "county_code": "",
                "death_indicator": "N",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2021, 3, 18, 15, 19, 10),
                    "type_code": "A47",
                    "type_label": "Update patient identifiers",
                },
                "first_name": "JEANNE",
                "further_names": ["JEANNE", "MARIE", "CECILE"],
                "identity_attribut": "normale",
                "identity_status": "Qualifiée",
                "identity_unknow_indicator": "",
                "identity_update_date": None,
                "ins_number": "260058815400244",
                "language": "",
                "last_name": "DARK",
                "marital_status": "S",
                "mobile": "",
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.8",
                "old_ins_number": "260058815400233",
                "old_ipp": "",
                "patient_id": "1900068",
                "phone": "",
                "phones": [],
                "postal_code": "",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "F",
                "species_code": "",
                "strain": "",
                "title": "Mme",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "MARIE-CECILE",
                "used_last_name": "",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a47_delete_identifier(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20210318151910||ADT^A47^ADT_A30|20210318151910|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20210318151910
    PID|1||1900068^^^&350000121&M^PI~""^^^ASIP-SANTE-INSNIR&1.2.250.1.213.1.4.8&ISO^INS||^MARIE-CECILE^^^^^D~DARK^JEANNE^JEANNE MARIE CECILE^^Mme^^L||19600530|F|||^^^^^FRA^BDL^^88154|||||S|||||||||1|||||N||VALI
    MRG|260058815400233^^^ASIP-SANTE-INS-NIR&1.2.250.1.213.1.4.8&ISO^INS
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "address": "",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "1",
                "birthdate": datetime.datetime(1960, 5, 30, 0, 0),
                "birthplace": "",
                "birthplace_code": "88154",
                "breed_code": "",
                "citizenships": [],
                "city": "",
                "country": "",
                "county_code": "",
                "death_indicator": "N",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2021, 3, 18, 15, 19, 10),
                    "type_code": "A47",
                    "type_label": "Update patient identifiers",
                },
                "first_name": "JEANNE",
                "further_names": ["JEANNE", "MARIE", "CECILE"],
                "identity_attribut": "normale",
                "identity_status": "Qualifiée",
                "identity_unknow_indicator": "",
                "identity_update_date": None,
                "ins_number": '""',
                "language": "",
                "last_name": "DARK",
                "marital_status": "S",
                "mobile": "",
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.8",
                "old_ins_number": "260058815400233",
                "old_ipp": "",
                "patient_id": "1900068",
                "phone": "",
                "phones": [],
                "postal_code": "",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "F",
                "species_code": "",
                "strain": "",
                "title": "Mme",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "MARIE-CECILE",
                "used_last_name": "",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a40_merge_two_patients(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20211209155945||ADT^A40^ADT_A39|PM263.HL7|P|2.5^FRA^2.10|||||FRA|8859/15|FRA
    EVN||20211209155851||||20211209155851
    PID|||123456^^^PAM_ABCD^PI||^^^^Mr^^D~DUMONT^TEST^^^^^L||19720511|M|||^^^^^FRA^H|||||||||||||||||||||PROV
    MRG|123459^^^PAM_ABCD^PI||||||DUMONT^TEST^^^^^D~DUMONT^TEST^^^^^L
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "address": "~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "",
                "birthdate": datetime.datetime(1972, 5, 11, 0, 0),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2021, 12, 9, 15, 58, 51),
                    "recorded_date": datetime.datetime(2021, 12, 9, 15, 58, 51),
                    "type_code": "A40",
                    "type_label": "Merge two patients",
                },
                "first_name": "TEST",
                "further_names": [],
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "",
                "identity_update_date": None,
                "ins_number": "",
                "language": "",
                "last_name": "DUMONT",
                "marital_status": "",
                "mobile": "",
                "multiple_birth_indicator": "",
                "oid": "",
                "old_ins_number": "",
                "old_ipp": "123459",
                "patient_id": "123456",
                "phone": "",
                "phones": [],
                "postal_code": "",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a01_patient_admission(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814110244||ADT^A01^ADT_A01|20200814110244|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814110244||||20200814110243
    PID|||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Leroy^Martine^Joséphine Pierrette^^Mme^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA||^NET^Internet^flo.flo@hotmail.fr|||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||0856290692987546123^^^ASIP-SANTE-INS-C||||||||||N
    PV1||I|8798^160^130-2^140024886|RM|||2500377731^Dubois^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||146|||||||2500085980^Lambert^Serge^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI||VN1740^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200814110100|||||||V
    ZBE|MOV3161^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814110243||INSERT|N||Urgences^^^^^^UF^^^8782|Réanimation^^^^^^UF^^^8781|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFV|140027210|3^Ambulance privée^HL70430||20200814120000|20200814130000|2 RUE DE BLON^^VIRE^^14500^FRA^ORI~9 RUE DE BROSSARD^^PONT L EVEQUE^^14130^FRA^DST
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "130-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "flo.flo@hotmail.fr",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 11, 2, 43),
                    "recorded_date": datetime.datetime(2020, 8, 14, 11, 2, 44),
                    "type_code": "A01",
                    "type_label": "Admit inpatient",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140024886",
                "hospital_service": "146",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692463229276888",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8798",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "assigning_authority": "ASIP-SANTE-INS-C",
                    "first_name": "Martine",
                    "further_names": ["Joséphine", "Pierrette"],
                    "identifier": "0856290692987546123",
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "oid": "",
                    "prefix": "Mme",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3161",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Réanimation",
                    "nursing_ward_organization_id": "8781",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 14, 11, 2, 43),
                    "ward_assigning_authority": "",
                    "ward_name": "Urgences",
                    "ward_organization_id": "8782",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "2500377731",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "Dubois",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "2500085980",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Serge",
                        "further_names": [],
                        "last_name": "Lambert",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "35000",
                "previous_facility": {
                    "archive_number": "",
                    "custom_exit_mode": "",
                    "dst_address": "9 RUE DE BROSSARD~",
                    "dst_city": "PONT L EVEQUE",
                    "dst_country": "FRA",
                    "dst_county_code": "",
                    "dst_postal_code": "14130",
                    "entry_date": None,
                    "name": "140027210",
                    "nda": "",
                    "ori_address": "2 RUE DE BLON~",
                    "ori_city": "VIRE",
                    "ori_country": "FRA",
                    "ori_county_code": "",
                    "ori_postal_code": "14500",
                    "psy_end_date": datetime.datetime(2020, 8, 14, 13, 0),
                    "psy_start_date": datetime.datetime(2020, 8, 14, 12, 0),
                    "rimp_code": "",
                    "rimp_label": "",
                    "transport_mode": "3",
                    "transport_support_code": "",
                    "transport_support_label": "",
                },
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "160",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 14, 11, 1),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "146",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1740",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a03_patient_discharge(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814112847||ADT^A03^ADT_A03|20200814112847|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814112847||||20200814112847
    PID|||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Leroy^^^^^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA||^NET^Internet^flo.flo@hotmail.fr|||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||20200821100000|Y|N
    PV1||I|8795^310^310-1^140000233^O|RM|||2500377731^Dubois^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||146|||||||2500085980^Lambert^Serge^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI||VN1740^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200814110100|20200821120000||||||V
    ZBE|MOV3165^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814112847||INSERT|N||Urgences^^^^^^UF^^^8782|Réanimation^^^^^^UF^^^8781|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFV|140027210|3^Ambulance privée^HL70430||20200814120000|20200814130000|2 RUE DE BLON^^VIRE^^14500^FRA^ORI~9 RUE DE BROSSARD^^PONT L EVEQUE^^14130^FRA^DST
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-1",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "Y",
                "deathdate": datetime.datetime(2020, 8, 21, 10, 0),
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "flo.flo@hotmail.fr",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 11, 28, 47),
                    "recorded_date": datetime.datetime(2020, 8, 14, 11, 28, 47),
                    "type_code": "A03",
                    "type_label": "Discharge patient",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140000233",
                "hospital_service": "146",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692463229276888",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3165",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Réanimation",
                    "nursing_ward_organization_id": "8781",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 14, 11, 28, 47),
                    "ward_assigning_authority": "",
                    "ward_name": "Urgences",
                    "ward_organization_id": "8782",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "2500377731",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "Dubois",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "2500085980",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Serge",
                        "further_names": [],
                        "last_name": "Lambert",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "35000",
                "previous_facility": {
                    "archive_number": "",
                    "custom_exit_mode": "",
                    "dst_address": "9 RUE DE BROSSARD~",
                    "dst_city": "PONT L EVEQUE",
                    "dst_country": "FRA",
                    "dst_county_code": "",
                    "dst_postal_code": "14130",
                    "entry_date": None,
                    "name": "140027210",
                    "nda": "",
                    "ori_address": "2 RUE DE BLON~",
                    "ori_city": "VIRE",
                    "ori_country": "FRA",
                    "ori_county_code": "",
                    "ori_postal_code": "14500",
                    "psy_end_date": datetime.datetime(2020, 8, 14, 13, 0),
                    "psy_start_date": datetime.datetime(2020, 8, 14, 12, 0),
                    "rimp_code": "",
                    "rimp_label": "",
                    "transport_mode": "3",
                    "transport_support_code": "",
                    "transport_support_label": "",
                },
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "310",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 14, 11, 1),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": datetime.datetime(2020, 8, 21, 12, 0),
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "146",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1740",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a04_outpatient(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817145654||ADT^A04^ADT_A01|20200817145654|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817145654||||20200817145654
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||O||C||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1742^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200817145600|||||||V
    ZBE|MOV3179^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817145654||INSERT|N||ORL^^^^^^UF^^^6276|Cardiologie interventionnelle^^^^^^UF^^^8780|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFP|4|35
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1339",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 14, 56, 54),
                    "recorded_date": datetime.datetime(2020, 8, 17, 14, 56, 54),
                    "type_code": "A04",
                    "type_label": "Register outpatient",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3179",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Cardiologie " "interventionnelle",
                    "nursing_ward_organization_id": "8780",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 14, 56, 54),
                    "ward_assigning_authority": "",
                    "ward_name": "ORL",
                    "ward_organization_id": "6276",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "O",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "4",
                    "socio_professional_category": "35",
                },
                "room": "",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "C",
                    "admit_date": datetime.datetime(2020, 8, 17, 14, 56),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1742",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a05_preadmit_patient(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814120223||ADT^A05^ADT_A05|20200814120223|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814120223||||20200814120223
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1337^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|||VN1741^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||10100026011^Ledy^Tifenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1741^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN||||||||||||||||||||||||||||||||V
    PV2||||||||20200827120000
    ZBE|MOV3169^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814120223||INSERT|N||Ophtalmomogie^^^^^^UF^^^6275|Rhumatologie^^^^^^UF^^^8792|MH^Changement de responsabilité hébergement et médicale
    ZFA|INEXISTANT|||N||N|N
    ZFP|4|35
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1337",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 12, 2, 23),
                    "recorded_date": datetime.datetime(2020, 8, 14, 12, 2, 23),
                    "type_code": "A05",
                    "type_label": "Pre-admit patient",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3169",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Rhumatologie",
                    "nursing_ward_organization_id": "8792",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "MH",
                    "start_date": datetime.datetime(2020, 8, 14, 12, 2, 23),
                    "ward_assigning_authority": "",
                    "ward_name": "Ophtalmomogie",
                    "ward_organization_id": "6275",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "I",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100026011",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Tifenn",
                        "further_names": [],
                        "last_name": "Ledy",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "4",
                    "socio_professional_category": "35",
                },
                "room": "",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "accommodation_code": "",
                    "account_status": "",
                    "actuel_lenght_of_inpatient_stay": "",
                    "admission_level_of_care_code": "",
                    "admission_type": "",
                    "admit_date": None,
                    "admit_reason": "",
                    "admit_source": "",
                    "advance_directive_code": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "baby_detained_indicator": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "billing_media_code": "",
                    "charge_price_indicator": "",
                    "clinic_organization_name": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "employment_illness_related_indicator": "",
                    "estimated_lenght_of_inpatient_stay": "",
                    "expected_admit_date": datetime.datetime(2020, 8, 27, 12, 0),
                    "expected_discharge_date": None,
                    "expected_discharge_disposition": "",
                    "expected_loa_return_date": None,
                    "expected_number_of_insurance_plans": "",
                    "expected_preadmission_testing_date": None,
                    "expected_surgery_date": None,
                    "financial_class": "",
                    "first_similar_illness_date": None,
                    "hospital_service": "",
                    "interest_code": "",
                    "living_will_code": "",
                    "military_non_availability_code": "",
                    "military_partnership_code": "",
                    "mode_of_arrival_code": "",
                    "newborn_baby_indicator": "",
                    "notify_clergy_code": "",
                    "organ_donor_code": "",
                    "patient_charge_ajustment_code": "",
                    "patient_condition_code": "",
                    "patient_status_code": "",
                    "patient_status_effective_date": None,
                    "patient_type": "",
                    "patient_valuables": "",
                    "patient_valuables_location": "",
                    "pending_location": "",
                    "preadmit_number": "VN1741",
                    "preadmit_number_oid": "GZL_INTEROP",
                    "preadmit_test_indicator": "",
                    "precaution_code": "",
                    "previous_service_date": None,
                    "previous_treatment_date": None,
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "purge_status_code": "",
                    "re_admission_indicator": "",
                    "recreational_drug_use_code": "",
                    "recurring_service_code": "",
                    "referral_source_code": "",
                    "retention_indicator": "",
                    "servicing_facility": "",
                    "signature_on_file_date": None,
                    "special_program_code": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_reason": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_description": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1741",
                    "visit_number_oid": "GZL_INTEROP",
                    "visit_priority_code": "",
                    "visit_protection_indicator": "",
                    "visit_publicity_code": "",
                    "visit_user_code": "",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a06_patient_to_inpatient(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817150057||ADT^A06^ADT_A06|20200817150057|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817150057||||20200817150057
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8780^220^221-1^140017971^O|C||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1742^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200817145600|||||||V
    ZBE|MOV3180^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817150057||INSERT|N||ORL^^^^^^UF^^^6276|Cardiologie interventionnelle^^^^^^UF^^^8780|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1339",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "221-1",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 15, 0, 57),
                    "recorded_date": datetime.datetime(2020, 8, 17, 15, 0, 57),
                    "type_code": "A06",
                    "type_label": "Change patient class to inpatient",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140017971",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "language": "",
                "last_name": "PIGEON",
                "location": "8780",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3180",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Cardiologie " "interventionnelle",
                    "nursing_ward_organization_id": "8780",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 15, 0, 57),
                    "ward_assigning_authority": "",
                    "ward_name": "ORL",
                    "ward_organization_id": "6276",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "I",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "220",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "C",
                    "admit_date": datetime.datetime(2020, 8, 17, 14, 56),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1742",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a07_patient_to_outpatient(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817150549||ADT^A07^ADT_A06|20200817150549|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817150549||||20200817150549
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||O|8780^221^221-2^140026410^O|C||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1742^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200817145600|||||||V
    ZBE|MOV3181^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817150549||INSERT|N||ORL^^^^^^UF^^^6276|Cardiologie interventionnelle^^^^^^UF^^^8780|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1339",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "221-2",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "recorded_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "type_code": "A07",
                    "type_label": "Change patient class to outpatient",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140026410",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "language": "",
                "last_name": "PIGEON",
                "location": "8780",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3181",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Cardiologie " "interventionnelle",
                    "nursing_ward_organization_id": "8780",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "ward_assigning_authority": "",
                    "ward_name": "ORL",
                    "ward_organization_id": "6276",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "O",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "221",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "C",
                    "admit_date": datetime.datetime(2020, 8, 17, 14, 56),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1742",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a02_patient_transfer(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200917085508||ADT^A02^ADT_A02|20200917085508|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200917085508||||20200917085508
    PID|||DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI~0856290692465859963229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH||PIGEON^Florian^^^^^L|Leroy^^^^^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA|||||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^221^221-2^140000027|RM||8798^161^221-1^140028044^U|10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10001882199^Arsène^Isabelle^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||225|||||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1746^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200819115700|||||||V
    ZBE|MOV3188^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200917085508||INSERT|N||Médecine interne^^^^^^UF^^^8786|Urologie^^^^^^UF^^^4043|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFV|140027210^20200923120000|3^Ambulance privée^HL70430||20200924120000|20200925120000|2 RUE DE BLON^^VIRE^^14500^FRA^ORI~5 RUE DE L'HOPITAL^^AUNAY SUR ODON^^14260^FRA^DST||||5
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "221-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 9, 17, 8, 55, 8),
                    "recorded_date": datetime.datetime(2020, 9, 17, 8, 55, 8),
                    "type_code": "A02",
                    "type_label": "Transfer patient",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140000027",
                "hospital_service": "225",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692465859963229276888",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3188",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Urologie",
                    "nursing_ward_organization_id": "4043",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 9, 17, 8, 55, 8),
                    "ward_assigning_authority": "",
                    "ward_name": "Médecine interne",
                    "ward_organization_id": "8786",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10001882199",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Isabelle",
                        "further_names": [],
                        "last_name": "Arsène",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "35000",
                "previous_facility": {
                    "archive_number": "",
                    "custom_exit_mode": "",
                    "dst_address": "5 RUE DE L'HOPITAL~",
                    "dst_city": "AUNAY SUR ODON",
                    "dst_country": "FRA",
                    "dst_county_code": "",
                    "dst_postal_code": "14260",
                    "entry_date": datetime.datetime(2020, 9, 23, 12, 0),
                    "name": "140027210",
                    "nda": "",
                    "ori_address": "2 RUE DE BLON~",
                    "ori_city": "VIRE",
                    "ori_country": "FRA",
                    "ori_county_code": "",
                    "ori_postal_code": "14500",
                    "psy_end_date": datetime.datetime(2020, 9, 25, 12, 0),
                    "psy_start_date": datetime.datetime(2020, 9, 24, 12, 0),
                    "rimp_code": "5",
                    "rimp_label": "",
                    "transport_mode": "3",
                    "transport_support_code": "",
                    "transport_support_label": "",
                },
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "221",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 19, 11, 57),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "225",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1746",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a54_change_attending_doctor(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817135418||ADT^A54^ADT_A54|20200817135418|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817135418||||20200817135418
    PID|||0360661704582664776241^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53790^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19850930004708|M|||Avenue du Cagnard^^Cavaillon^^84300^FRA|||||||AN1332^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^261^240-2^140018029|R|||2500338139^Bonnet^Marin^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||152|||||||10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1732^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721113500|||||||V
    ZBE|MOV3178^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817135418||INSERT|N||Pneumologie^^^^^^UF^^^8788|Médecine interne^^^^^^UF^^^8786|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1332",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Cagnard~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "240-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1985, 9, 30, 0, 47, 8),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Cavaillon",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 13, 54, 18),
                    "recorded_date": datetime.datetime(2020, 8, 17, 13, 54, 18),
                    "type_code": "A54",
                    "type_label": "Change attending doctor",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140018029",
                "hospital_service": "152",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0360661704582664776241",
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3178",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Médecine interne",
                    "nursing_ward_organization_id": "8786",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 13, 54, 18),
                    "ward_assigning_authority": "",
                    "ward_name": "Pneumologie",
                    "ward_organization_id": "8788",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53790",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "2500338139",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Marin",
                        "further_names": [],
                        "last_name": "Bonnet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "postal_code": "84300",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "261",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "R",
                    "admit_date": datetime.datetime(2020, 7, 21, 11, 35),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "152",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1732",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a21_leave_of_absence(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817131907||ADT^A21^ADT_A21|20200817131907|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817131907||||20200821083000
    PID|||0790247896538546942685^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53789^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19841020033643|M|||Impasse Joseph Laulom^^Mont-de-Marsan^^40000^FRA|||||||AN1331^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|4044^231^310-2^140000076|U|||10100409951^Leperdit^Gérard^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||225|||||||10002105400^Loison^Laurenne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1734^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721144100|||||||V
    PV2|||||||||||||||||||||||||||||||||||||||||||||||20200821163000
    ZBE|MOV3175^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817131907||INSERT|N||Gériatrie^^^^^^UF^^^6262|Rhumatologie^^^^^^UF^^^8792|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFP|1|37
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1331",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Impasse Joseph Laulom~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1984, 10, 20, 3, 36, 43),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Mont-de-Marsan",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 21, 8, 30),
                    "recorded_date": datetime.datetime(2020, 8, 17, 13, 19, 7),
                    "type_code": "A21",
                    "type_label": "Leave of absence",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140000076",
                "hospital_service": "225",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0790247896538546942685",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "4044",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3175",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Rhumatologie",
                    "nursing_ward_organization_id": "8792",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 13, 19, 7),
                    "ward_assigning_authority": "",
                    "ward_name": "Gériatrie",
                    "ward_organization_id": "6262",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53789",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100409951",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Gérard",
                        "further_names": [],
                        "last_name": "Leperdit",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002105400",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Laurenne",
                        "further_names": [],
                        "last_name": "Loison",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "40000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "1",
                    "socio_professional_category": "37",
                },
                "room": "231",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "accommodation_code": "",
                    "account_status": "",
                    "actuel_lenght_of_inpatient_stay": "",
                    "admission_level_of_care_code": "",
                    "admission_type": "U",
                    "admit_date": datetime.datetime(2020, 7, 21, 14, 41),
                    "admit_reason": "",
                    "admit_source": "",
                    "advance_directive_code": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "baby_detained_indicator": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "billing_media_code": "",
                    "charge_price_indicator": "",
                    "clinic_organization_name": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "employment_illness_related_indicator": "",
                    "estimated_lenght_of_inpatient_stay": "",
                    "expected_admit_date": None,
                    "expected_discharge_date": None,
                    "expected_discharge_disposition": "",
                    "expected_loa_return_date": datetime.datetime(2020, 8, 21, 16, 30),
                    "expected_number_of_insurance_plans": "",
                    "expected_preadmission_testing_date": None,
                    "expected_surgery_date": None,
                    "financial_class": "",
                    "first_similar_illness_date": None,
                    "hospital_service": "225",
                    "interest_code": "",
                    "living_will_code": "",
                    "military_non_availability_code": "",
                    "military_partnership_code": "",
                    "mode_of_arrival_code": "",
                    "newborn_baby_indicator": "",
                    "notify_clergy_code": "",
                    "organ_donor_code": "",
                    "patient_charge_ajustment_code": "",
                    "patient_condition_code": "",
                    "patient_status_code": "",
                    "patient_status_effective_date": None,
                    "patient_type": "",
                    "patient_valuables": "",
                    "patient_valuables_location": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "precaution_code": "",
                    "previous_service_date": None,
                    "previous_treatment_date": None,
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "purge_status_code": "",
                    "re_admission_indicator": "",
                    "recreational_drug_use_code": "",
                    "recurring_service_code": "",
                    "referral_source_code": "",
                    "retention_indicator": "",
                    "servicing_facility": "",
                    "signature_on_file_date": None,
                    "special_program_code": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_reason": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_description": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1734",
                    "visit_number_oid": "GZL_INTEROP",
                    "visit_priority_code": "",
                    "visit_protection_indicator": "",
                    "visit_publicity_code": "",
                    "visit_user_code": "",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a22_return_from_leave(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817131928||ADT^A22^ADT_A21|20200817131928|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817131928||||20200821170000
    PID|||0790247896538546942685^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53789^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19841020033643|M|||Impasse Joseph Laulom^^Mont-de-Marsan^^40000^FRA|||||||AN1331^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|4044^231^310-2^140000076|U|||10100409951^Leperdit^Gérard^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||225|||||||10002105400^Loison^Laurenne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1734^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721144100|||||||V
    PV2|||||||||||||||||||||||||||||||||||||||||||||||20200821163000
    ZBE|MOV3176^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817131928||INSERT|N||Gériatrie^^^^^^UF^^^6262|Rhumatologie^^^^^^UF^^^8792|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFP|1|37
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1331",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Impasse Joseph Laulom~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1984, 10, 20, 3, 36, 43),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Mont-de-Marsan",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 21, 17, 0),
                    "recorded_date": datetime.datetime(2020, 8, 17, 13, 19, 28),
                    "type_code": "A22",
                    "type_label": "Return from leave of absence",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140000076",
                "hospital_service": "225",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0790247896538546942685",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "4044",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3176",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Rhumatologie",
                    "nursing_ward_organization_id": "8792",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 13, 19, 28),
                    "ward_assigning_authority": "",
                    "ward_name": "Gériatrie",
                    "ward_organization_id": "6262",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53789",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100409951",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Gérard",
                        "further_names": [],
                        "last_name": "Leperdit",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002105400",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Laurenne",
                        "further_names": [],
                        "last_name": "Loison",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "40000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "1",
                    "socio_professional_category": "37",
                },
                "room": "231",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "accommodation_code": "",
                    "account_status": "",
                    "actuel_lenght_of_inpatient_stay": "",
                    "admission_level_of_care_code": "",
                    "admission_type": "U",
                    "admit_date": datetime.datetime(2020, 7, 21, 14, 41),
                    "admit_reason": "",
                    "admit_source": "",
                    "advance_directive_code": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "baby_detained_indicator": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "billing_media_code": "",
                    "charge_price_indicator": "",
                    "clinic_organization_name": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "employment_illness_related_indicator": "",
                    "estimated_lenght_of_inpatient_stay": "",
                    "expected_admit_date": None,
                    "expected_discharge_date": None,
                    "expected_discharge_disposition": "",
                    "expected_loa_return_date": datetime.datetime(2020, 8, 21, 16, 30),
                    "expected_number_of_insurance_plans": "",
                    "expected_preadmission_testing_date": None,
                    "expected_surgery_date": None,
                    "financial_class": "",
                    "first_similar_illness_date": None,
                    "hospital_service": "225",
                    "interest_code": "",
                    "living_will_code": "",
                    "military_non_availability_code": "",
                    "military_partnership_code": "",
                    "mode_of_arrival_code": "",
                    "newborn_baby_indicator": "",
                    "notify_clergy_code": "",
                    "organ_donor_code": "",
                    "patient_charge_ajustment_code": "",
                    "patient_condition_code": "",
                    "patient_status_code": "",
                    "patient_status_effective_date": None,
                    "patient_type": "",
                    "patient_valuables": "",
                    "patient_valuables_location": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "precaution_code": "",
                    "previous_service_date": None,
                    "previous_treatment_date": None,
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "purge_status_code": "",
                    "re_admission_indicator": "",
                    "recreational_drug_use_code": "",
                    "recurring_service_code": "",
                    "referral_source_code": "",
                    "retention_indicator": "",
                    "servicing_facility": "",
                    "signature_on_file_date": None,
                    "special_program_code": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_reason": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_description": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1734",
                    "visit_number_oid": "GZL_INTEROP",
                    "visit_priority_code": "",
                    "visit_protection_indicator": "",
                    "visit_publicity_code": "",
                    "visit_user_code": "",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a44_move_account_information(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817133153||ADT^A44^ADT_A43|20200817133153|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817133153
    PID|||DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI~0856290692465859963229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH||PIGEON^Florian^^^^^L|Leroy^^^^^^L|19990217|M|||StreetWork^^Rennes^^35000^FRA|||||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN
    MRG|DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": None,
                    "recorded_date": datetime.datetime(2020, 8, 17, 13, 31, 53),
                    "type_code": "A44",
                    "type_label": "Move account information",
                },
                "first_name": "Florian",
                "further_names": [],
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "",
                "identity_update_date": None,
                "ins_number": "0856290692465859963229276888",
                "language": "",
                "last_name": "PIGEON",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "old_ins_number": "",
                "old_ipp": "DDS-53798",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "postal_code": "35000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a01_with_garantor_and_insurance(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814110244||ADT^A01^ADT_A01|20200814110244|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814110244||||20200814110243
    PID|||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^Henry Paul^^Mr^^L|Leroy^^^^^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA||^PRN^PH^^^^^^^^^0524504745~^PRN^CP^^^^^^^^^0624504745~^NET^Internet^flo.flo@hotmail.fr|||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8798^160^130-2^140024886|RM|||2500377731^Dubois^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||146|||||||2500085980^Lambert^Serge^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI||VN1740^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200814110100|||||||V
    ZBE|MOV3161^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814110243||INSERT|N||Urgences^^^^^^UF^^^8782|Réanimation^^^^^^UF^^^8781|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFV|140027210|3^Ambulance privée^HL70430||20200814120000|20200814130000|2 RUE DE BLON^^VIRE^^14500^FRA^ORI~9 RUE DE BROSSARD^^PONT L EVEQUE^^14130^FRA^DST
    ZFM|8
    ZFD|||N
    GT1||123456789^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH|PIGEON^Nadine^Henriette^^Mme^^L||StreetWork^^Rennes^^35000^FRA^^35000|^PRN^CP^^^^^^^^^0612345678~^NET^Internet^nad.pig@hotmail.fr|^PRN^CP^^^^^^^^^0798745632|||ASS|Parent|6000000000000000|20000101010101|20221231235959|R|Martin^David^Paul^Mr^^L|3 rue du fond^Batiment C^Lille^^59000^FRA^^^59000^^^^20101010101010^20200220202020|^PRN^PH^^^^^^^^^0598745650|0000|Cadre|Orga|abcd|7894|||95123|98|5|1236987^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH|Mariée|20160521080010|||||FRA|ZP||||||FRA||PIGEON^Jacques^^^Mr^^L|^PRN^CP^^^^^^^^^0612345697|Raison|Epoux|Technicienne|CODE|Laboratoire Machin^^^^^Assigning^D^^^UFG445184||Status|Class 1||Orléans|N
    IN1||AMC|AMC123^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH|||||||||20201010101010|20211010101010|A^20201030|Y|PIGEON^Florian^Henry Paul^^Mr^^L|CO||StreetWork^^Rennes^^35000^FRA|Y|||||||||||10||||AB|841815456|||||||||1||||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO
    IN2||||||||||||||||||||||||||||FRJ^Y|||||||||||||||||||||||||||||||||||^PRN^CP^^^^^^^^^0624504745~^NET^Internet^flo.flo@hotmail.fr
    IN3|||||PC^100
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "130-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "flo.flo@hotmail.fr",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 11, 2, 43),
                    "recorded_date": datetime.datetime(2020, 8, 14, 11, 2, 44),
                    "type_code": "A01",
                    "type_label": "Admit inpatient",
                },
                "first_name": "Florian",
                "further_names": ["Henry", "Paul"],
                "gestation_weeks": "",
                "guarantor": {
                    "address": "StreetWork~",
                    "address_effective_date": None,
                    "address_expiration_date": None,
                    "address_type": "",
                    "assigning_authority": "ASIP-SANTE-INS-C",
                    "billing_hold_flag": "abcd",
                    "birth_place": "Orléans",
                    "charge_ajustement_code": "95123",
                    "city": "Rennes",
                    "contact_email": "",
                    "contact_first_name": "Jacques",
                    "contact_further_names": [],
                    "contact_last_name": "PIGEON",
                    "contact_mobile": "0612345697",
                    "contact_name_type_code": "normale",
                    "contact_phone": "",
                    "contact_prefix": "Mr",
                    "contact_reason": "Raison",
                    "contact_relationship": "Epoux",
                    "country": "FRA",
                    "county_code": "",
                    "credit_rating_code": "7894",
                    "date_begin": datetime.datetime(2000, 1, 1, 1, 1, 1),
                    "date_end": datetime.datetime(2022, 12, 31, 23, 59, 59),
                    "death_date": None,
                    "death_flag": "",
                    "email": "nad.pig@hotmail.fr",
                    "employee_id_number": "0000",
                    "employement_status": "Cadre",
                    "employement_stop_date": None,
                    "employer_address": "3 rue du fond~Batiment C",
                    "employer_address_effective_date": datetime.datetime(
                        2010, 10, 10, 10, 10, 10
                    ),
                    "employer_address_expiration_date": datetime.datetime(
                        2020, 2, 20, 20, 20, 20
                    ),
                    "employer_address_type": "",
                    "employer_assigning_authority": "ASIP-SANTE-INS-C",
                    "employer_city": "Lille",
                    "employer_country": "FRA",
                    "employer_county_code": "59000",
                    "employer_email": "",
                    "employer_first_name": "",
                    "employer_further_names": [],
                    "employer_identifier": "1236987",
                    "employer_last_name": "",
                    "employer_mobile": "",
                    "employer_name_type_code": "",
                    "employer_oid": "1.2.250.1.213.1.4.2",
                    "employer_organization_assigning_authority": "Assigning",
                    "employer_organization_identifier": "UFG445184",
                    "employer_organization_name": "Laboratoire Machin",
                    "employer_phone": "0598745650",
                    "employer_postal_code": "59000",
                    "employer_prefix": "",
                    "financial_class": "Class 1",
                    "first_name": "Nadine",
                    "further_names": ["Henriette"],
                    "hire_effective_date": datetime.datetime(2016, 5, 21, 8, 0, 10),
                    "household_annual_income": "98",
                    "household_size": "5",
                    "identifier": "123456789",
                    "job_code": "CODE",
                    "job_status": "Status",
                    "job_title": "Technicienne",
                    "last_name": "PIGEON",
                    "living_arrangement": "ZP",
                    "marital_status_code": "Mariée",
                    "mobile": "0612345678",
                    "name_type_code": "normale",
                    "nationality": "FRA",
                    "oid": "1.2.250.1.213.1.4.2",
                    "organization_name": "Orga",
                    "phone": "",
                    "postal_code": "35000",
                    "prefix": "Mme",
                    "primary_language": "FRA",
                    "priority": "R",
                    "pro_email": "",
                    "pro_mobile": "0798745632",
                    "pro_phone": "",
                    "relationship": "Parent",
                    "ssn": "6000000000000000",
                    "type": "ASS",
                    "vip_indicator": "N",
                },
                "hospital": "140024886",
                "hospital_service": "146",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692463229276888",
                "insi_query_date": None,
                "insurance": {
                    "authorization_date": datetime.datetime(2020, 10, 30, 0, 0),
                    "authorization_name": "A",
                    "beneficiary_status": "CO",
                    "company_assigning_authority": "ASIP-SANTE-INS-C",
                    "company_identifier": "AMC123",
                    "company_oid": "1.2.250.1.213.1.4.2",
                    "company_plan_code": "AB",
                    "event_number": "841815456",
                    "exemption_from_copayment": "Y",
                    "insurance_nature": "10",
                    "insured_address": "StreetWork~",
                    "insured_address_effective_date": None,
                    "insured_address_expiration_date": None,
                    "insured_address_type": "",
                    "insured_assigning_authority": "ASIP-SANTE-INS-C",
                    "insured_city": "Rennes",
                    "insured_country": "FRA",
                    "insured_county_code": "",
                    "insured_email": "flo.flo@hotmail.fr",
                    "insured_first_name": "Florian",
                    "insured_further_names": ["Henry", "Paul"],
                    "insured_identifier": "0856290692463229276888",
                    "insured_last_name": "PIGEON",
                    "insured_mobile": "0624504745",
                    "insured_name_type_code": "normale",
                    "insured_oid": "1.2.250.1.213.1.4.2",
                    "insured_phone": "",
                    "insured_postal_code": "35000",
                    "insured_prefix": "Mr",
                    "justificative_nature": "1",
                    "money_or_percentage_indicator": "PC",
                    "money_or_percentage_quantity": "100",
                    "plan_effective_date": datetime.datetime(2020, 10, 10, 10, 10, 10),
                    "plan_expiration_date": datetime.datetime(2021, 10, 10, 10, 10, 10),
                    "plan_id": "AMC",
                    "room_coverage_amount": "Y",
                    "room_coverage_type": "FRJ",
                    "third_party_payer": "Y",
                },
                "language": "",
                "last_name": "PIGEON",
                "location": "8798",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "0624504745",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3161",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Réanimation",
                    "nursing_ward_organization_id": "8781",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 14, 11, 2, 43),
                    "ward_assigning_authority": "",
                    "ward_name": "Urgences",
                    "ward_organization_id": "8782",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "0524504745",
                "phones": ["0524504745", "0624504745"],
                "physicians": [
                    {
                        "code": "2500377731",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "Dubois",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "2500085980",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Serge",
                        "further_names": [],
                        "last_name": "Lambert",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "35000",
                "previous_facility": {
                    "archive_number": "",
                    "custom_exit_mode": "",
                    "dst_address": "9 RUE DE BROSSARD~",
                    "dst_city": "PONT L EVEQUE",
                    "dst_country": "FRA",
                    "dst_county_code": "",
                    "dst_postal_code": "14130",
                    "entry_date": None,
                    "name": "140027210",
                    "nda": "",
                    "ori_address": "2 RUE DE BLON~",
                    "ori_city": "VIRE",
                    "ori_country": "FRA",
                    "ori_county_code": "",
                    "ori_postal_code": "14500",
                    "psy_end_date": datetime.datetime(2020, 8, 14, 13, 0),
                    "psy_start_date": datetime.datetime(2020, 8, 14, 12, 0),
                    "rimp_code": "",
                    "rimp_label": "",
                    "transport_mode": "3",
                    "transport_support_code": "",
                    "transport_support_label": "",
                },
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "160",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "Mr",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 14, 11, 1),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "146",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1740",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_z99_update(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200818164147||ADT^Z99^ADT_A01|20200818164147|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200818164147||||20200817150549
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||O|8780^221^221-2^140026410^O|C||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1742^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200817145600|||||||V
    ZBE|MOV3181^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817150549||UPDATE|N|A07|ORL^^^^^^UF^^^6276|Cardiologie interventionnelle^^^^^^UF^^^8780|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFP|4|35
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1339",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "221-2",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "recorded_date": datetime.datetime(2020, 8, 18, 16, 41, 47),
                    "type_code": "Z99",
                    "type_label": "Admission correction",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140026410",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8780",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "UPDATE",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "N",
                    "identifier": "MOV3181",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Cardiologie " "interventionnelle",
                    "nursing_ward_organization_id": "8780",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A07",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "ward_assigning_authority": "",
                    "ward_name": "ORL",
                    "ward_organization_id": "6276",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "O",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "4",
                    "socio_professional_category": "35",
                },
                "room": "221",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "C",
                    "admit_date": datetime.datetime(2020, 8, 17, 14, 56),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1742",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a11_cancel_admission(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200818164147||ADT^A11^ADT_A09|20200818164147|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200818164147||||20200817150549
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1339^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||O|8780^221^221-2^140026410^O|C||||10100161156^Closet^Julien^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1742^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200817145600|||||||V
    ZBE|MOV4691^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20210721102819||CANCEL|Y|A01|ORL^^^^^^UF^^^6276|Cardiologie interventionnelle^^^^^^UF^^^8780|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFP|4|35
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1339",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "221-2",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 15, 5, 49),
                    "recorded_date": datetime.datetime(2020, 8, 18, 16, 41, 47),
                    "type_code": "A11",
                    "type_label": "Cancel admission",
                },
                "first_name": "Florian",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140026410",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8780",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV4691",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Cardiologie " "interventionnelle",
                    "nursing_ward_organization_id": "8780",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A01",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2021, 7, 21, 10, 28, 19),
                    "ward_assigning_authority": "",
                    "ward_name": "ORL",
                    "ward_organization_id": "6276",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "O",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100161156",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Julien",
                        "further_names": [],
                        "last_name": "Closet",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "professional_infos": {
                    "socio_professional_activity": "4",
                    "socio_professional_category": "35",
                },
                "room": "221",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "C",
                    "admit_date": datetime.datetime(2020, 8, 17, 14, 56),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1742",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a13_cancel_discharge(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814114533||ADT^A13^ADT_A01|20200814114533|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814114533||||20200814112847
    PID|||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Floriant^^^^^L|Leroy^^^^^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA||^NET^Internet^flo.flo@hotmail.fr|||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^310^310-1^140000233^O|RM|||2500377731^Dubois^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||146|||||||2500085980^Lambert^Serge^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI||VN1740^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200814110100|||||||V
    ZBE|MOV3165^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814112847||CANCEL|Y|A03|Urgences^^^^^^UF^^^8782|Réanimation^^^^^^UF^^^8781|HMS^Changement conjoint des trois responsabilités.
    ZFA|INEXISTANT|||N||N|N
    ZFV|140027210|3^Ambulance privée^HL70430||20200814120000|20200814130000|2 RUE DE BLON^^VIRE^^14500^FRA^ORI~9 RUE DE BROSSARD^^PONT L EVEQUE^^14130^FRA^DST
    ZFM|8
    ZFD|||N
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-1",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthdate_modified": "",
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "dmp": {
                    "access_authorization": "N",
                    "access_authorization_collecting_date": None,
                    "breakage_mode_opposition": "N",
                    "closing_date": None,
                    "collecting_date": None,
                    "control_center_mode_opposition": "N",
                    "dmp_status": "INEXISTANT",
                    "opposition_collecting_date": None,
                },
                "email": "flo.flo@hotmail.fr",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 11, 28, 47),
                    "recorded_date": datetime.datetime(2020, 8, 14, 11, 45, 33),
                    "type_code": "A13",
                    "type_label": "Cancel discharge",
                },
                "first_name": "Floriant",
                "further_names": [],
                "gestation_weeks": "",
                "hospital": "140000233",
                "hospital_service": "146",
                "identity_attribut": "normale",
                "identity_document": "",
                "identity_document_expiration_date": None,
                "identity_obtaining_mode": "",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692463229276888",
                "insi_query_date": None,
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "lunar_date": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3165",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Réanimation",
                    "nursing_ward_organization_id": "8781",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A03",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 14, 11, 28, 47),
                    "ward_assigning_authority": "",
                    "ward_name": "Urgences",
                    "ward_organization_id": "8782",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "2500377731",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "Dubois",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "2500085980",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Serge",
                        "further_names": [],
                        "last_name": "Lambert",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "8",
                    "exit_mode": "",
                    "origin_mode": "",
                },
                "postal_code": "35000",
                "previous_facility": {
                    "archive_number": "",
                    "custom_exit_mode": "",
                    "dst_address": "9 RUE DE BROSSARD~",
                    "dst_city": "PONT L EVEQUE",
                    "dst_country": "FRA",
                    "dst_county_code": "",
                    "dst_postal_code": "14130",
                    "entry_date": None,
                    "name": "140027210",
                    "nda": "",
                    "ori_address": "2 RUE DE BLON~",
                    "ori_city": "VIRE",
                    "ori_country": "FRA",
                    "ori_county_code": "",
                    "ori_postal_code": "14500",
                    "psy_end_date": datetime.datetime(2020, 8, 14, 13, 0),
                    "psy_start_date": datetime.datetime(2020, 8, 14, 12, 0),
                    "rimp_code": "",
                    "rimp_label": "",
                    "transport_mode": "3",
                    "transport_support_code": "",
                    "transport_support_label": "",
                },
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "310",
                "sample_id": "",
                "sex": "M",
                "sms_consent": "N",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 14, 11, 1),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "146",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1740",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a38_cancel_pre_admit(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814140134||ADT^A38^ADT_A38|20200814140134|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814140134||||20200814120223
    PID|||DDS-53798^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L|Martin^^^^^^L|19930610213200|M|||Avenue du Maréchal Leclerc^^Hyères^^83400^FRA|||||||AN1337^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I||||||10100026011^Ledy^Tifenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|||||||||||VN1741^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN||||||||||||||||||||||||||||||||V
    ZBE|MOV3169^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814120223||CANCEL|Y|A05|Ophtalmomogie^^^^^^UF^^^6275|Rhumatologie^^^^^^UF^^^8792|MH^Changement de responsabilité hébergement et médicale
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1337",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Maréchal Leclerc~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1993, 6, 10, 21, 32),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Hyères",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 12, 2, 23),
                    "recorded_date": datetime.datetime(2020, 8, 14, 14, 1, 34),
                    "type_code": "A38",
                    "type_label": "Cancel pre-admit",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_status": "",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "",
                "language": "",
                "last_name": "PIGEON",
                "location": "",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Martin",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3169",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Rhumatologie",
                    "nursing_ward_organization_id": "8792",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A05",
                    "scope": "MH",
                    "start_date": datetime.datetime(2020, 8, 14, 12, 2, 23),
                    "ward_assigning_authority": "",
                    "ward_name": "Ophtalmomogie",
                    "ward_organization_id": "6275",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "I",
                "patient_id": "DDS-53798",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100026011",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Tifenn",
                        "further_names": [],
                        "last_name": "Ledy",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    }
                ],
                "postal_code": "83400",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "",
                    "admit_date": None,
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1741",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a12_cancel_transfer(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200814112552||ADT^A12^ADT_A12|20200814112552|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200814112552||||20200814111309
    PID|||0856290692463229276888^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53799^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Floriant^^^^^L|Leroy^^^^^^L|19990217000000|M|||StreetWork^^Rennes^^35000^FRA||^NET^Internet^flo.flo@hotmail.fr|||||AN1338^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^310^310-1^140000233^O|RM||8795^310^310-1^140000233^O|2500377731^Dubois^Anne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||146|||||||2500085980^Lambert^Serge^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^ADELI||VN1740^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200814110100|||||||V
    ZBE|MOV3164^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200814111309||CANCEL|Y|A02|Urgences^^^^^^UF^^^8782|Réanimation^^^^^^UF^^^8781|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1338",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "StreetWork~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-1",
                "bed_status": "O",
                "birth_order": "",
                "birthdate": datetime.datetime(1999, 2, 17, 0, 0),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Rennes",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "flo.flo@hotmail.fr",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 14, 11, 13, 9),
                    "recorded_date": datetime.datetime(2020, 8, 14, 11, 25, 52),
                    "type_code": "A12",
                    "type_label": "Cancel transfer",
                },
                "first_name": "Floriant",
                "further_names": [],
                "hospital": "140000233",
                "hospital_service": "146",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0856290692463229276888",
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "marital_status": "",
                "mobile": "",
                "mother_identity": {
                    "first_name": "",
                    "further_names": [],
                    "last_name": "Leroy",
                    "name_type_code": "normale",
                    "prefix": "",
                },
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3164",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Réanimation",
                    "nursing_ward_organization_id": "8781",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A02",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 14, 11, 13, 9),
                    "ward_assigning_authority": "",
                    "ward_name": "Urgences",
                    "ward_organization_id": "8782",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53799",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "2500377731",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Anne",
                        "further_names": [],
                        "last_name": "Dubois",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "2500085980",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Serge",
                        "further_names": [],
                        "last_name": "Lambert",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "postal_code": "35000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "310",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "RM",
                    "admit_date": datetime.datetime(2020, 8, 14, 11, 1),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "146",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1740",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a55_cancel_change_attending_doctor(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817143621||ADT^A55^ADT_A52|20200817143621|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817143621||||20200817135418
    PID|||0360661704582664776241^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53790^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19850930004708|M|||Avenue du Cagnard^^Cavaillon^^84300^FRA|||||||AN1332^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^261^240-2^140018029|R|||10100409951^Leperdit^Gérard^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||152|||||||10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1732^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721113500|||||||V
    ZBE|MOV3178^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817135418||INSERT|Y||Pneumologie^^^^^^UF^^^8788|Médecine interne^^^^^^UF^^^8786|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1332",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Cagnard~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "240-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1985, 9, 30, 0, 47, 8),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Cavaillon",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 13, 54, 18),
                    "recorded_date": datetime.datetime(2020, 8, 17, 14, 36, 21),
                    "type_code": "A55",
                    "type_label": "Cancel change attending doctor",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140018029",
                "hospital_service": "152",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0360661704582664776241",
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3178",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Médecine interne",
                    "nursing_ward_organization_id": "8786",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 13, 54, 18),
                    "ward_assigning_authority": "",
                    "ward_name": "Pneumologie",
                    "ward_organization_id": "8788",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53790",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100409951",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Gérard",
                        "further_names": [],
                        "last_name": "Leperdit",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "postal_code": "84300",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "261",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "R",
                    "admit_date": datetime.datetime(2020, 7, 21, 11, 35),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "152",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1732",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a52_cancel_leave_of_absence(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817115143||ADT^A52^ADT_A52|20200817115143|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817115143||||20200817114209
    PID|||0360661704582664776241^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53790^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19850930004708|M|||Avenue du Cagnard^^Cavaillon^^84300^FRA|||||||AN1332^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|8795^261^240-2^140018029|R|||10100409951^Leperdit^Gérard^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||152|||||||10002135423^Hamel^Maïwenn^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1732^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721113500|||||||V
    ZBE|MOV3173^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817114209||CANCEL|Y|A21|Pneumologie^^^^^^UF^^^8788|Médecine interne^^^^^^UF^^^8786|C^Correction ou changement du statut administratif du patient sans génération de mouvement
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1332",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Avenue du Cagnard~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "240-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1985, 9, 30, 0, 47, 8),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Cavaillon",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 11, 42, 9),
                    "recorded_date": datetime.datetime(2020, 8, 17, 11, 51, 43),
                    "type_code": "A52",
                    "type_label": "Cancel leave of absence",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140018029",
                "hospital_service": "152",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0360661704582664776241",
                "language": "",
                "last_name": "PIGEON",
                "location": "8795",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3173",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Médecine interne",
                    "nursing_ward_organization_id": "8786",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A21",
                    "scope": "C",
                    "start_date": datetime.datetime(2020, 8, 17, 11, 42, 9),
                    "ward_assigning_authority": "",
                    "ward_name": "Pneumologie",
                    "ward_organization_id": "8788",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53790",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100409951",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Gérard",
                        "further_names": [],
                        "last_name": "Leperdit",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002135423",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Maïwenn",
                        "further_names": [],
                        "last_name": "Hamel",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "postal_code": "84300",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "261",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "account_status": "",
                    "admission_type": "R",
                    "admit_date": datetime.datetime(2020, 7, 21, 11, 35),
                    "admit_source": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "charge_price_indicator": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "financial_class": "",
                    "hospital_service": "152",
                    "interest_code": "",
                    "patient_type": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "re_admission_indicator": "",
                    "servicing_facility": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1732",
                    "visit_number_oid": "GZL_INTEROP",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_a53_cancel_return_from_leave_of_absence(self):
    worklist = self.decode(
        """
        MSH|^~\\&|Gazelle|PAM_FR|PatientManager|PAM_FR|20200817134502||ADT^A53^ADT_A52|20200817134502|P|2.5^FRA^2.9||||||UNICODE UTF-8
    EVN||20200817134502||||20200817131928
    PID|||0790247896538546942685^^^ASIP-SANTE-INS-C&1.2.250.1.213.1.4.2&ISO^NH~DDS-53789^^^DDS&2.16.840.1.113883.2.8.3.8&ISO^PI||PIGEON^Florian^^^^^L||19841020033643|M|||Impasse Joseph Laulom^^Mont-de-Marsan^^40000^FRA|||||||AN1331^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^AN|||||||||||||N
    PV1||I|4044^231^310-2^140000076|U|||10100409951^Leperdit^Gérard^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS|10003786596^Adrien^Marina^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||225|||||||10002105400^Loison^Laurenne^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1 I&ISO^D^^^RPPS||VN1734^^^GZL_INTEROP&2.16.840.1.113883.2.8.3.7&ISO^VN|||||||||||||||||||||||||20200721144100|||||||V
    PV2|||||||||||||||||||||||||||||||||||||||||||||||20200821163000
    ZBE|MOV3176^GZL_INTEROP^2.16.840.1.113883.2.8.3.7^ISO|20200817131928||CANCEL|Y|A22|Gériatrie^^^^^^UF^^^6262|Rhumatologie^^^^^^UF^^^8792|HMS^Changement conjoint des trois responsabilités.
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "PatientManager",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "GZL_INTEROP",
                    "identifier": "AN1331",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                },
                "address": "Impasse Joseph Laulom~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "310-2",
                "bed_status": "",
                "birth_order": "",
                "birthdate": datetime.datetime(1984, 10, 20, 3, 36, 43),
                "birthplace": "",
                "birthplace_code": "",
                "breed_code": "",
                "citizenships": [],
                "city": "Mont-de-Marsan",
                "country": "FRA",
                "county_code": "",
                "death_indicator": "",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2020, 8, 17, 13, 19, 28),
                    "recorded_date": datetime.datetime(2020, 8, 17, 13, 45, 2),
                    "type_code": "A53",
                    "type_label": "Cancel return from leave of absence",
                },
                "first_name": "Florian",
                "further_names": [],
                "hospital": "140000076",
                "hospital_service": "225",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "N",
                "identity_update_date": None,
                "ins_number": "0790247896538546942685",
                "language": "",
                "last_name": "PIGEON",
                "location": "4044",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "CANCEL",
                    "assigning_authority": "GZL_INTEROP",
                    "historic_indicator": "Y",
                    "identifier": "MOV3176",
                    "nursing_ward_assigning_authority": "",
                    "nursing_ward_name": "Rhumatologie",
                    "nursing_ward_organization_id": "8792",
                    "oid": "2.16.840.1.113883.2.8.3.7",
                    "original_trigger": "A22",
                    "scope": "HMS",
                    "start_date": datetime.datetime(2020, 8, 17, 13, 19, 28),
                    "ward_assigning_authority": "",
                    "ward_name": "Gériatrie",
                    "ward_organization_id": "6262",
                },
                "multiple_birth_indicator": "",
                "oid": "1.2.250.1.213.1.4.2",
                "patient_class": "I",
                "patient_id": "DDS-53789",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "10100409951",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Gérard",
                        "further_names": [],
                        "last_name": "Leperdit",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10003786596",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Marina",
                        "further_names": [],
                        "last_name": "Adrien",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "10002105400",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Laurenne",
                        "further_names": [],
                        "last_name": "Loison",
                        "oid": "1.2.250.1.71.4.2.1 I",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "postal_code": "40000",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "231",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "",
                "visit_infos": {
                    "accommodation_code": "",
                    "account_status": "",
                    "actuel_lenght_of_inpatient_stay": "",
                    "admission_level_of_care_code": "",
                    "admission_type": "U",
                    "admit_date": datetime.datetime(2020, 7, 21, 14, 41),
                    "admit_reason": "",
                    "admit_source": "",
                    "advance_directive_code": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "baby_detained_indicator": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "billing_media_code": "",
                    "charge_price_indicator": "",
                    "clinic_organization_name": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": None,
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "employment_illness_related_indicator": "",
                    "estimated_lenght_of_inpatient_stay": "",
                    "expected_admit_date": None,
                    "expected_discharge_date": None,
                    "expected_discharge_disposition": "",
                    "expected_loa_return_date": datetime.datetime(2020, 8, 21, 16, 30),
                    "expected_number_of_insurance_plans": "",
                    "expected_preadmission_testing_date": None,
                    "expected_surgery_date": None,
                    "financial_class": "",
                    "first_similar_illness_date": None,
                    "hospital_service": "225",
                    "interest_code": "",
                    "living_will_code": "",
                    "military_non_availability_code": "",
                    "military_partnership_code": "",
                    "mode_of_arrival_code": "",
                    "newborn_baby_indicator": "",
                    "notify_clergy_code": "",
                    "organ_donor_code": "",
                    "patient_charge_ajustment_code": "",
                    "patient_condition_code": "",
                    "patient_status_code": "",
                    "patient_status_effective_date": None,
                    "patient_type": "",
                    "patient_valuables": "",
                    "patient_valuables_location": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "precaution_code": "",
                    "previous_service_date": None,
                    "previous_treatment_date": None,
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "purge_status_code": "",
                    "re_admission_indicator": "",
                    "recreational_drug_use_code": "",
                    "recurring_service_code": "",
                    "referral_source_code": "",
                    "retention_indicator": "",
                    "servicing_facility": "",
                    "signature_on_file_date": None,
                    "special_program_code": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_reason": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "",
                    "visit_description": "",
                    "visit_indicator": "V",
                    "visit_number": "VN1734",
                    "visit_number_oid": "GZL_INTEROP",
                    "visit_priority_code": "",
                    "visit_protection_indicator": "",
                    "visit_publicity_code": "",
                    "visit_user_code": "",
                },
            }
        ],
        "sender_id": "Gazelle",
    }
    assert worklist == expected


def test_decode_multi_codes_physicians_pv1(self):
    worklist = self.decode(
        """
        MSH|^~\\&|1.2.250.1.355.100.70.47|171|BREUIL|SCP ALTILABO Taulhac|20230607102616||ADT^A03^ADT_A03|95626034|P|2.5^FRA^2.10||||AL|FRA|8859/1|FR||
EVN||20230607095259|||david.ramos^DSI RAMOS David^^^^^^^171^D^^^EI|20230607103000|
PID|1||1111111^^^171^PI||THOR^TEST^TEST^^MR^^L||19900101000000|M|||Rue de Midgarde^^LYON 02^^69002^100^H~^^STE FOY LES LYON^^69110^100^BDL^^69202|||||||23002455^^^171^AN|||||69110 STE FOY LES LYON||1|||||N||PROV|||||||
PV1|1|I|SSR1^129^129^430007450&430007450&N||||CHALCOR^ATTENDING^Corentin^^^^^^171^D^^^EI~430007450^ATTENDING^Corentin^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^D^^^ADELI~10101211778^ATTENDING^Corentin^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^D^^^RPPS|10101211778^PRESCRIBER^Corentin^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^D^^^RPPS||||||||P|430007450^ADMITTING^Corentin^^^^^^ASIP-SANTE-PS&1.2.250.1.71.4.2.1&ISO^D^^^ADELI~10101211778^ADMITTING^Corentin||23002455^^^171^VN||03||||||||||||||||||||D|||20230607094700|20230607103000||||||V|
PV2|||||||||||||||||||||||||||||||||||||||||||||||||
ZBE|36078462^171|20230607103000||INSERT|N||174 - HC -  M�decine g�n�rale^^^^^430007450&430007450&N^UF^^^MCO|Etage 1 SSR^^^^^430007450&430007450&N^UF^^^SSR1|
ZFM||8|||
        """
    )
    expected = {
        "context": "order",
        "receiver_id": "BREUIL",
        "samples": [
            {
                "account_number": {
                    "assigning_authority": "171",
                    "identifier": "23002455",
                    "oid": "",
                },
                "address": "Rue de Midgarde~",
                "address_effective_date": None,
                "address_expiration_date": None,
                "bed": "129",
                "bed_status": "",
                "birth_order": "1",
                "birthdate": datetime.datetime(1990, 1, 1, 0, 0),
                "birthplace": "STE FOY LES LYON",
                "birthplace_code": "69202",
                "breed_code": "",
                "citizenships": [],
                "city": "LYON 02",
                "country": "100",
                "county_code": "",
                "death_indicator": "N",
                "deathdate": None,
                "email": "",
                "event": {
                    "occured_date": datetime.datetime(2023, 6, 7, 10, 30),
                    "recorded_date": datetime.datetime(2023, 6, 7, 9, 52, 59),
                    "type_code": "A03",
                    "type_label": "Discharge patient",
                },
                "first_name": "TEST",
                "further_names": ["TEST"],
                "hospital": "430007450",
                "hospital_service": "",
                "identity_attribut": "normale",
                "identity_status": "Provisoire",
                "identity_unknow_indicator": "",
                "identity_update_date": None,
                "ins_number": "",
                "language": "",
                "last_name": "THOR",
                "location": "SSR1",
                "marital_status": "",
                "mobile": "",
                "movements": {
                    "action": "INSERT",
                    "assigning_authority": "171",
                    "historic_indicator": "N",
                    "identifier": "36078462",
                    "nursing_ward_assigning_authority": "430007450",
                    "nursing_ward_name": "Etage 1 SSR",
                    "nursing_ward_organization_id": "SSR1",
                    "oid": "",
                    "original_trigger": "",
                    "scope": "",
                    "start_date": datetime.datetime(2023, 6, 7, 10, 30),
                    "ward_assigning_authority": "430007450",
                    "ward_name": "174 - HC -  M�decine g�n�rale",
                    "ward_organization_id": "MCO",
                },
                "multiple_birth_indicator": "",
                "oid": "",
                "patient_class": "I",
                "patient_id": "1111111",
                "phone": "",
                "phones": [],
                "physicians": [
                    {
                        "code": "CHALCOR",
                        "code_type": "EI",
                        "codification": "D",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "ATTENDING",
                        "oid": "",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "430007450",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "ATTENDING",
                        "oid": "1.2.250.1.71.4.2.1",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10101211778",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "ATTENDING",
                        "oid": "1.2.250.1.71.4.2.1",
                        "title": "",
                        "type": "attending",
                    },
                    {
                        "code": "10101211778",
                        "code_type": "RPPS",
                        "codification": "D",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "PRESCRIBER",
                        "oid": "1.2.250.1.71.4.2.1",
                        "title": "",
                        "type": "prescriber",
                    },
                    {
                        "code": "430007450",
                        "code_type": "ADELI",
                        "codification": "D",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "ADMITTING",
                        "oid": "1.2.250.1.71.4.2.1",
                        "title": "",
                        "type": "admitting",
                    },
                    {
                        "code": "10101211778",
                        "code_type": "",
                        "codification": "",
                        "first_name": "Corentin",
                        "further_names": [],
                        "last_name": "ADMITTING",
                        "oid": "",
                        "title": "",
                        "type": "admitting",
                    },
                ],
                "pmsi": {
                    "destination_mode": "",
                    "entry_mode": "",
                    "exit_mode": "8",
                    "origin_mode": "",
                },
                "postal_code": "69002",
                "pro_email": "",
                "pro_mobile": "",
                "pro_phone": "",
                "production_class_code": "",
                "room": "129",
                "sample_id": "",
                "sex": "M",
                "species_code": "",
                "strain": "",
                "title": "MR",
                "tribal_citizenship": "",
                "type": "patient",
                "used_first_name": "",
                "used_last_name": "",
                "veterans_military_status": "69110 STE FOY LES LYON",
                "visit_infos": {
                    "accommodation_code": "",
                    "account_status": "D",
                    "actuel_lenght_of_inpatient_stay": "",
                    "admission_level_of_care_code": "",
                    "admission_type": "",
                    "admit_date": datetime.datetime(2023, 6, 7, 9, 47),
                    "admit_reason": "",
                    "admit_source": "",
                    "advance_directive_code": "",
                    "alternate_visit_id": "",
                    "alternate_visit_id_oid": "",
                    "ambulatory_status": "",
                    "baby_detained_indicator": "",
                    "bad_debt_agency_code": "",
                    "bad_debt_recovery_amount": "",
                    "bad_debt_tranfer_amount": "",
                    "billing_media_code": "",
                    "charge_price_indicator": "03",
                    "clinic_organization_name": "",
                    "contract_amount": "",
                    "contract_code": "",
                    "contract_effective_date": None,
                    "contract_period": "",
                    "courtesy_code": "",
                    "credit_rating": "",
                    "current_patient_balance": "",
                    "delete_account_date": None,
                    "delete_account_indicator": "",
                    "diet_type": "",
                    "discharge_date": datetime.datetime(2023, 6, 7, 10, 30),
                    "discharge_disposition": "",
                    "discharge_to_location": "",
                    "employment_illness_related_indicator": "",
                    "estimated_lenght_of_inpatient_stay": "",
                    "expected_admit_date": None,
                    "expected_discharge_date": None,
                    "expected_discharge_disposition": "",
                    "expected_loa_return_date": None,
                    "expected_number_of_insurance_plans": "",
                    "expected_preadmission_testing_date": None,
                    "expected_surgery_date": None,
                    "financial_class": "",
                    "first_similar_illness_date": None,
                    "hospital_service": "",
                    "interest_code": "",
                    "living_will_code": "",
                    "military_non_availability_code": "",
                    "military_partnership_code": "",
                    "mode_of_arrival_code": "",
                    "newborn_baby_indicator": "",
                    "notify_clergy_code": "",
                    "organ_donor_code": "",
                    "patient_charge_ajustment_code": "",
                    "patient_condition_code": "",
                    "patient_status_code": "",
                    "patient_status_effective_date": None,
                    "patient_type": "",
                    "patient_valuables": "",
                    "patient_valuables_location": "",
                    "pending_location": "",
                    "preadmit_number": "",
                    "preadmit_number_oid": "",
                    "preadmit_test_indicator": "",
                    "precaution_code": "",
                    "previous_service_date": None,
                    "previous_treatment_date": None,
                    "prior_patient_location": "",
                    "prior_temporary_location": "",
                    "purge_status_code": "",
                    "re_admission_indicator": "",
                    "recreational_drug_use_code": "",
                    "recurring_service_code": "",
                    "referral_source_code": "",
                    "retention_indicator": "",
                    "servicing_facility": "",
                    "signature_on_file_date": None,
                    "special_program_code": "",
                    "temporary_location": "",
                    "total_adjustments": "",
                    "total_charges": "",
                    "total_payments": "",
                    "transfer_reason": "",
                    "transfer_to_bad_debt_code": "",
                    "transfer_to_bad_debt_date": None,
                    "vip_indicator": "P",
                    "visit_description": "",
                    "visit_indicator": "V",
                    "visit_number": "23002455",
                    "visit_number_oid": "171",
                    "visit_priority_code": "",
                    "visit_protection_indicator": "",
                    "visit_publicity_code": "",
                    "visit_user_code": "",
                },
            }
        ],
        "sender_id": "1.2.250.1.355.100.70.47",
    }
    assert worklist == expected
