# -*- coding: utf8 -*-
from __future__ import unicode_literals

import csv

from six import StringIO

from driverng import MessageV2, Worklist
from driverng.splitted import Multiple, Splitted, String


class CovidResultsBase(Splitted):

    SEPARATOR = ","


class CovidResult(object):
    FIELDS = [
        String("include"),
        String("color"),
        String("pos"),
        String("name"),
        Multiple("results", (String("resu"),), separator=","),
    ]

    def parse(self, line):
        fields = self.FIELDS
        for i, field in enumerate(fields):
            if isinstance(field, Multiple):
                setattr(self, field.name, line[i:])
                break
            else:
                setattr(self, field.name, line[i])


class CovidResultsMultiple(list):
    _MESSAGE_TYPE_MAP = {MessageV2.RESULT: CovidResult}

    def add(self, type_message=None, **kwargs):
        obj = self._MESSAGE_TYPE_MAP[type_message](**kwargs)
        self.append(obj)
        return obj

    def parse(self, data):
        buf = StringIO(data)
        reader = csv.reader(buf, delimiter=str(";"))
        for line in reader:
            if not len(line):
                continue
            if len(line) > 5:
                obj = self.add(type_message=MessageV2.RESULT)
                obj.parse(line)


class Driver(MessageV2):
    SPEC = {
        "code": "covid_results_csv",
        "label": "Covid Resultats CSV (Lifecycleur ROCHE)",
    }

    def parse(self, data):
        obj = CovidResultsMultiple()
        obj.parse(data)
        return obj

    def decode_message(self, message):
        worklist = Worklist(context="result")
        RESULTS_CODES = ()
        for m in message:
            if m.include.strip() == "Include" and m.color.strip() == "Color":
                RESULTS_CODES = m.results
                continue
            if RESULTS_CODES:
                sample = worklist.get_or_create(
                    sample_id=m.name, rack="COVID-{}".format(m.pos), type="patient"
                )
                for index, result in enumerate(m.results):
                    if RESULTS_CODES[index] and result:
                        sample.results.add(
                            code=RESULTS_CODES[index].strip(),
                            value=result.replace(",", "."),
                        )
        return worklist
